"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtQuick import *


class QQuickTextDocument(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qquicktextdocument.html

    **Detailed Description**

    This class provides access to the **QTextDocument**  of QQuickTextEdit
    elements. This is provided to allow usage of the **Rich Text Processing**
    functionalities of Qt. You are not allowed to modify the document, but it
    can be used to output content, for example with **QTextDocumentWriter** ),
    or provide additional formatting, for example with **QSyntaxHighlighter** .

    The class has to be used from C++ directly, using the property of the
    **TextEdit** .

    Warning: The **QTextDocument**  provided is used internally by **Qt Quick**
    elements to provide text manipulation primitives. You are not allowed to
    perform any modification of the internal state of the **QTextDocument** . If
    you do, the element in question may stop functioning or crash.
    """

    def __init__(self, parent: QQuickItem) -> None:
        """
        https://doc.qt.io/qt-6/qquicktextdocument.html#QQuickTextDocument

        **QQuickTextDocument::QQuickTextDocument(QQuickItem * parent )**

        Constructs a QQuickTextDocument object with **parent** as the parent
        object.
        """
        ...

    def textDocument(self) -> QtGui.QTextDocument:
        """
        https://doc.qt.io/qt-6/qquicktextdocument.html#textDocument

        **QTextDocument *QQuickTextDocument::textDocument() const**

        Returns a pointer to the **QTextDocument**  object.
        """
        ...
