"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from ._functions import PYQT_SIGNAL as PYQT_SIGNAL
from ._functions import PYQT_SLOT as PYQT_SLOT
from ._QGeoAddress import QGeoAddress as QGeoAddress
from ._QGeoAreaMonitorInfo import QGeoAreaMonitorInfo as QGeoAreaMonitorInfo
from ._QGeoAreaMonitorSource import QGeoAreaMonitorSource as QGeoAreaMonitorSource
from ._QGeoShape import QGeoShape as QGeoShape
from ._QGeoCircle import QGeoCircle as QGeoCircle
from ._QGeoCoordinate import QGeoCoordinate as QGeoCoordinate
from ._QGeoLocation import QGeoLocation as QGeoLocation
from ._QGeoPath import QGeoPath as QGeoPath
from ._QGeoPolygon import QGeoPolygon as QGeoPolygon
from ._QGeoPositionInfo import QGeoPositionInfo as QGeoPositionInfo
from ._QGeoPositionInfoSource import QGeoPositionInfoSource as QGeoPositionInfoSource
from ._QGeoRectangle import QGeoRectangle as QGeoRectangle
from ._QGeoSatelliteInfo import QGeoSatelliteInfo as QGeoSatelliteInfo
from ._QGeoSatelliteInfoSource import QGeoSatelliteInfoSource as QGeoSatelliteInfoSource
from ._QNmeaPositionInfoSource import QNmeaPositionInfoSource as QNmeaPositionInfoSource
from ._QNmeaSatelliteInfoSource import (
    QNmeaSatelliteInfoSource as QNmeaSatelliteInfoSource,
)
