"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtSql import *


class QSqlDriverCreatorBase(PyQt6.sip.wrapper):
    """
    https://doc.qt.io/qt-6/qsqldrivercreatorbase.html

    **Detailed Description**

    Reimplement **createObject** () to return an instance of the specific
    **QSqlDriver**  subclass that you want to provide.

    See **QSqlDatabase::registerSqlDriver** () for details.

    **See also** **QSqlDriverCreator** .
    """

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QSqlDriverCreatorBase") -> None:
        ...

    def createObject(self) -> "QSqlDriver":
        """
        https://doc.qt.io/qt-6/qsqldrivercreatorbase.html#createObject

        **[pure virtual] QSqlDriver *QSqlDriverCreatorBase::createObject()
        const**

        Reimplement this function to returns a new instance of a **QSqlDriver**
        subclass.
        """
        ...
