"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtCore import *


class QTransposeProxyModel(QAbstractProxyModel):
    """
    https://doc.qt.io/qt-6/qtransposeproxymodel.html

    **Detailed Description**

    This model will make the rows of the source model become columns of the
    proxy model and vice-versa.

    If the model is a tree, the parents will be transposed as well. For example,
    if an index in the source model had parent `index(2,0)`, it will have parent
    `index(0,2)` in the proxy.
    """

    def __init__(self, parent: typing.Optional[QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#QTransposeProxyModel-1

        **QTransposeProxyModel::QTransposeProxyModel(QObject * parent =
        nullptr)**

        Constructs a new proxy model with the given **parent**.
        """
        ...

    def sort(self, column: int, order: Qt.SortOrder = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#sort

        **[override virtual] void QTransposeProxyModel::sort(int column ,
        Qt::SortOrder order = Qt::AscendingOrder)**

        Reimplements: **QAbstractProxyModel::sort** (int column, Qt::SortOrder
        order).

        This method will perform no action. Use a **QSortFilterProxyModel**  on
        top of this one if you require sorting.
        """
        ...

    def moveColumns(
        self,
        sourceParent: QModelIndex,
        sourceColumn: int,
        count: int,
        destinationParent: QModelIndex,
        destinationChild: int,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#moveColumns

        **[override virtual] bool QTransposeProxyModel::moveColumns(const
        QModelIndex & sourceParent , int sourceRow , int count , const
        QModelIndex & destinationParent , int destinationChild )**

        Reimplements: **QAbstractItemModel::moveColumns** (const QModelIndex
        &sourceParent, int sourceColumn, int count, const QModelIndex
        &destinationParent, int destinationChild).
        """
        ...

    def removeColumns(self, column: int, count: int, parent: QModelIndex = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#removeColumns

        **[override virtual] bool QTransposeProxyModel::removeColumns(int column
        , int count , const QModelIndex & parent = QModelIndex())**

        Reimplements: **QAbstractItemModel::removeColumns** (int column, int
        count, const QModelIndex &parent).
        """
        ...

    def insertColumns(self, column: int, count: int, parent: QModelIndex = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#insertColumns

        **[override virtual] bool QTransposeProxyModel::insertColumns(int column
        , int count , const QModelIndex & parent = QModelIndex())**

        Reimplements: **QAbstractItemModel::insertColumns** (int column, int
        count, const QModelIndex &parent).
        """
        ...

    def moveRows(
        self,
        sourceParent: QModelIndex,
        sourceRow: int,
        count: int,
        destinationParent: QModelIndex,
        destinationChild: int,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#moveRows

        **[override virtual] bool QTransposeProxyModel::moveRows(const
        QModelIndex & sourceParent , int sourceRow , int count , const
        QModelIndex & destinationParent , int destinationChild )**

        Reimplements: **QAbstractItemModel::moveRows** (const QModelIndex
        &sourceParent, int sourceRow, int count, const QModelIndex
        &destinationParent, int destinationChild).
        """
        ...

    def removeRows(self, row: int, count: int, parent: QModelIndex = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#removeRows

        **[override virtual] bool QTransposeProxyModel::removeRows(int row , int
        count , const QModelIndex & parent = QModelIndex())**

        Reimplements: **QAbstractItemModel::removeRows** (int row, int count,
        const QModelIndex &parent).
        """
        ...

    def insertRows(self, row: int, count: int, parent: QModelIndex = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#insertRows

        **[override virtual] bool QTransposeProxyModel::insertRows(int row , int
        count , const QModelIndex & parent = QModelIndex())**

        Reimplements: **QAbstractItemModel::insertRows** (int row, int count,
        const QModelIndex &parent).
        """
        ...

    def index(self, row: int, column: int, parent: QModelIndex = ...) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#index

        **[override virtual] QModelIndex QTransposeProxyModel::index(int row ,
        int column , const QModelIndex & parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::index(int row, int column, const
        QModelIndex &parent) const** .
        """
        ...

    def parent(self, index: QModelIndex) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#parent

        **[override virtual] QModelIndex QTransposeProxyModel::parent(const
        QModelIndex & index ) const**

        Reimplements: **QAbstractItemModel::parent(const QModelIndex &index)
        const** .
        """
        ...

    def mapToSource(self, proxyIndex: QModelIndex) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#mapToSource

        **[override virtual] QModelIndex QTransposeProxyModel::mapToSource(const
        QModelIndex & proxyIndex ) const**

        Reimplements: **QAbstractProxyModel::mapToSource(const QModelIndex
        &proxyIndex) const** .
        """
        ...

    def mapFromSource(self, sourceIndex: QModelIndex) -> QModelIndex:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#mapFromSource

        **[override virtual] QModelIndex
        QTransposeProxyModel::mapFromSource(const QModelIndex & sourceIndex )
        const**

        Reimplements: **QAbstractProxyModel::mapFromSource(const QModelIndex
        &sourceIndex) const** .
        """
        ...

    def itemData(self, index: QModelIndex) -> typing.Dict[int, typing.Any]:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#itemData

        **[override virtual] QMap<int, QVariant>
        QTransposeProxyModel::itemData(const QModelIndex & index ) const**

        Reimplements: **QAbstractProxyModel::itemData(const QModelIndex
        &proxyIndex) const** .

        **See also** **setItemData** ().
        """
        ...

    def span(self, index: QModelIndex) -> QSize:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#span

        **[override virtual] QSize QTransposeProxyModel::span(const QModelIndex
        & index ) const**

        Reimplements: **QAbstractProxyModel::span(const QModelIndex &index)
        const** .
        """
        ...

    def setItemData(
        self, index: QModelIndex, roles: typing.Dict[int, typing.Any]
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#setItemData

        **[override virtual] bool QTransposeProxyModel::setItemData(const
        QModelIndex & index , const QMap<int, QVariant> & roles )**

        Reimplements: **QAbstractProxyModel::setItemData** (const QModelIndex
        &index, const QMap<int, QVariant> &roles).

        **See also** **itemData** ().
        """
        ...

    def setHeaderData(
        self,
        section: int,
        orientation: Qt.Orientation,
        value: typing.Any,
        role: int = ...,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#setHeaderData

        **[override virtual] bool QTransposeProxyModel::setHeaderData(int
        section , Qt::Orientation orientation , const QVariant & value , int
        role = Qt::EditRole)**

        Reimplements: **QAbstractProxyModel::setHeaderData** (int section,
        Qt::Orientation orientation, const QVariant &value, int role).

        **See also** **headerData** ().
        """
        ...

    def headerData(
        self, section: int, orientation: Qt.Orientation, role: int = ...
    ) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#headerData

        **[override virtual] QVariant QTransposeProxyModel::headerData(int
        section , Qt::Orientation orientation , int role = Qt::DisplayRole)
        const**

        Reimplements: **QAbstractProxyModel::headerData(int section,
        Qt::Orientation orientation, int role) const** .

        **See also** **setHeaderData** ().
        """
        ...

    def columnCount(self, parent: QModelIndex = ...) -> int:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#columnCount

        **[override virtual] int QTransposeProxyModel::columnCount(const
        QModelIndex & parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::columnCount(const QModelIndex
        &parent) const** .
        """
        ...

    def rowCount(self, parent: QModelIndex = ...) -> int:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#rowCount

        **[override virtual] int QTransposeProxyModel::rowCount(const
        QModelIndex & parent = QModelIndex()) const**

        Reimplements: **QAbstractItemModel::rowCount(const QModelIndex &parent)
        const** .
        """
        ...

    def setSourceModel(self, newSourceModel: QAbstractItemModel) -> None:
        """
        https://doc.qt.io/qt-6/qtransposeproxymodel.html#setSourceModel

        **[override virtual] void
        QTransposeProxyModel::setSourceModel(QAbstractItemModel * newSourceModel
        )**

        Reimplements: **QAbstractProxyModel::setSourceModel**
        (QAbstractItemModel *sourceModel).
        """
        ...
