"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore


class QWindowStateChangeEvent(QtCore.QEvent):
    """
    https://doc.qt.io/qt-6/qwindowstatechangeevent.html

    **Detailed Description**
    """

    def clone(self) -> "QWindowStateChangeEvent":
        ...

    def oldState(self) -> QtCore.Qt.WindowState:
        """
        https://doc.qt.io/qt-6/qwindowstatechangeevent.html#oldState

        **Qt::WindowStates QWindowStateChangeEvent::oldState() const**

        Returns the state of the window before the change.
        """
        ...
