"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtWidgets
from PyQt6 import QtCore
from PyQt6.QtDesigner import *


class QDesignerFormEditorInterface(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qdesignerformeditorinterface.html

    **Detailed Description**

    **Qt Designer** 's current QDesignerFormEditorInterface object holds
    information about all **Qt Designer** 's components: The action editor, the
    object inspector, the property editor, the widget box, and the extension and
    form window managers. QDesignerFormEditorInterface contains a collection of
    functions that provides interfaces to all these components. They are
    typically used to query (and manipulate) the respective component. For
    example:

    **QDesignerObjectInspectorInterface**  *objectInspector = 0;
    objectInspector = formEditor->objectInspector();
    **QDesignerFormWindowManagerInterface**  *manager = 0;
                manager =
    formEditor->formWindowManager();
    objectInspector->setFormWindow(manager->formWindow(0));

    QDesignerFormEditorInterface is not intended to be instantiated directly. A
    pointer to **Qt Designer** 's current QDesignerFormEditorInterface object
    (`formEditor` in the example above) is provided by the
    **QDesignerCustomWidgetInterface::initialize** () function's parameter. When
    implementing a custom widget plugin, you must subclass the
    **QDesignerCustomWidgetInterface**  to expose your plugin to **Qt
    Designer**.

    QDesignerFormEditorInterface also provides functions that can set the action
    editor, property editor, object inspector and widget box. These are only
    useful if you want to provide your own custom components.

    If designer is embedded in another program, one could to provide its own
    settings manager. The manager is used by the components of **Qt Designer**
    to store/retrieve persistent configuration settings. The default manager
    uses **QSettings**  as the backend.

    Finally, QDesignerFormEditorInterface provides the **topLevel** () function
    that returns **Qt Designer** 's top-level widget.

    **See also** **QDesignerCustomWidgetInterface** .
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformeditorinterface.html#QDesignerFormEd
        itorInterface

        **QDesignerFormEditorInterface::QDesignerFormEditorInterface(QObject *
        parent = nullptr)**

        Constructs a QDesignerFormEditorInterface object with the given
        **parent**.
        """
        ...

    def setActionEditor(self, actionEditor: QDesignerActionEditorInterface) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformeditorinterface.html#setActionEditor

        **void QDesignerFormEditorInterface::setActionEditor(QDesignerActionEdit
        orInterface * actionEditor )**

        Sets **Qt Designer** 's action editor to be the specified
        **actionEditor**.

        **See also** **actionEditor** ().
        """
        ...

    def setObjectInspector(
        self, objectInspector: "QDesignerObjectInspectorInterface"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformeditorinterface.html#setObjectInspec
        tor

        **void QDesignerFormEditorInterface::setObjectInspector(QDesignerObjectI
        nspectorInterface * objectInspector )**

        Sets **Qt Designer** 's object inspector to be the specified
        **objectInspector**.

        **See also** **objectInspector** ().
        """
        ...

    def setPropertyEditor(
        self, propertyEditor: "QDesignerPropertyEditorInterface"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformeditorinterface.html#setPropertyEdit
        or

        **void QDesignerFormEditorInterface::setPropertyEditor(QDesignerProperty
        EditorInterface * propertyEditor )**

        Sets **Qt Designer** 's property editor to be the specified
        **propertyEditor**.

        **See also** **propertyEditor** ().
        """
        ...

    def setWidgetBox(self, widgetBox: "QDesignerWidgetBoxInterface") -> None:
        """
        https://doc.qt.io/qt-6/qdesignerformeditorinterface.html#setWidgetBox

        **void
        QDesignerFormEditorInterface::setWidgetBox(QDesignerWidgetBoxInterface *
        widgetBox )**

        Sets **Qt Designer** 's widget box to be the specified **widgetBox**.

        **See also** **widgetBox** ().
        """
        ...

    def actionEditor(self) -> QDesignerActionEditorInterface:
        """
        https://doc.qt.io/qt-6/qdesignerformeditorinterface.html#actionEditor

        **QDesignerActionEditorInterface
        *QDesignerFormEditorInterface::actionEditor() const**

        Returns an interface to **Qt Designer** 's action editor.

        **See also** **setActionEditor** ().
        """
        ...

    def formWindowManager(self) -> "QDesignerFormWindowManagerInterface":
        """
        https://doc.qt.io/qt-6/qdesignerformeditorinterface.html#formWindowManag
        er

        **QDesignerFormWindowManagerInterface
        *QDesignerFormEditorInterface::formWindowManager() const**

        Returns an interface to **Qt Designer** 's form window manager.
        """
        ...

    def objectInspector(self) -> "QDesignerObjectInspectorInterface":
        """
        https://doc.qt.io/qt-6/qdesignerformeditorinterface.html#objectInspector

        **QDesignerObjectInspectorInterface
        *QDesignerFormEditorInterface::objectInspector() const**

        Returns an interface to **Qt Designer** 's object inspector.

        **See also** **setObjectInspector** ().
        """
        ...

    def propertyEditor(self) -> "QDesignerPropertyEditorInterface":
        """
        https://doc.qt.io/qt-6/qdesignerformeditorinterface.html#propertyEditor

        **QDesignerPropertyEditorInterface
        *QDesignerFormEditorInterface::propertyEditor() const**

        Returns an interface to **Qt Designer** 's property editor.

        **See also** **setPropertyEditor** ().
        """
        ...

    def widgetBox(self) -> "QDesignerWidgetBoxInterface":
        """
        https://doc.qt.io/qt-6/qdesignerformeditorinterface.html#widgetBox

        **QDesignerWidgetBoxInterface *QDesignerFormEditorInterface::widgetBox()
        const**

        Returns an interface to **Qt Designer** 's widget box.

        **See also** **setWidgetBox** ().
        """
        ...

    def topLevel(self) -> QtWidgets.QWidget:
        """
        https://doc.qt.io/qt-6/qdesignerformeditorinterface.html#topLevel

        **QWidget *QDesignerFormEditorInterface::topLevel() const**

        Returns **Qt Designer** 's top-level widget.
        """
        ...

    def extensionManager(self) -> "QExtensionManager":
        """
        https://doc.qt.io/qt-6/qdesignerformeditorinterface.html#extensionManage
        r

        **QExtensionManager *QDesignerFormEditorInterface::extensionManager()
        const**

        Returns an interface to **Qt Designer** 's extension manager.
        """
        ...
