"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtCore import *


class pyqtBoundSignal:
    signal: str = ...

    def __getitem__(self, key: object) -> "pyqtBoundSignal":
        ...

    def connect(self, slot: "PYQT_SLOT") -> "QMetaObject.Connection":
        ...

    @typing.overload
    def disconnect(self) -> None:
        ...

    @typing.overload
    def disconnect(
        self, slot: typing.Union["PYQT_SLOT", "QMetaObject.Connection"]
    ) -> None:
        ...

    def emit(self, *args: typing.Any) -> None:
        ...
