"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from ._functions import PYQT_SIGNAL as PYQT_SIGNAL
from ._functions import PYQT_SLOT as PYQT_SLOT
from ._QAudio import QAudio as QAudio
from ._QAudioBuffer import QAudioBuffer as QAudioBuffer
from ._QAudioDecoder import QAudioDecoder as QAudioDecoder
from ._QAudioDevice import QAudioDevice as QAudioDevice
from ._QAudioFormat import QAudioFormat as QAudioFormat
from ._QAudioInput import QAudioInput as QAudioInput
from ._QAudioOutput import QAudioOutput as QAudioOutput
from ._QAudioSink import QAudioSink as QAudioSink
from ._QAudioSource import QAudioSource as QAudioSource
from ._QCamera import QCamera as QCamera
from ._QCameraFormat import QCameraFormat as QCameraFormat
from ._QCameraDevice import QCameraDevice as QCameraDevice
from ._QImageCapture import QImageCapture as QImageCapture
from ._QMediaCaptureSession import QMediaCaptureSession as QMediaCaptureSession
from ._QMediaDevices import QMediaDevices as QMediaDevices
from ._QMediaFormat import QMediaFormat as QMediaFormat
from ._QMediaMetaData import QMediaMetaData as QMediaMetaData
from ._QMediaPlayer import QMediaPlayer as QMediaPlayer
from ._QMediaRecorder import QMediaRecorder as QMediaRecorder
from ._QMediaTimeRange import QMediaTimeRange as QMediaTimeRange
from ._QSoundEffect import QSoundEffect as QSoundEffect
from ._QVideoFrame import QVideoFrame as QVideoFrame
from ._QVideoFrameFormat import QVideoFrameFormat as QVideoFrameFormat
from ._QVideoSink import QVideoSink as QVideoSink
