"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore


class QHideEvent(QtCore.QEvent):
    """
    https://doc.qt.io/qt-6/qhideevent.html

    **Detailed Description**

    This event is sent just before **QWidget::hide** () returns, and also when a
    top-level window has been hidden (iconified) by the user.

    If **spontaneous** () is true, the event originated outside the application.
    In this case, the user hid the window using the window manager controls,
    either by iconifying the window or by switching to another virtual desktop
    where the window is not visible. The window will become hidden but not
    withdrawn. If the window was iconified, **QWidget::isMinimized** () returns
    `true`.

    **See also** **QShowEvent** .
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qhideevent.html#QHideEvent-2

        **QHideEvent::QHideEvent()**

        Constructs a QHideEvent.
        """
        ...
