"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtQuick import *


class QSGTextureProvider(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qsgtextureprovider.html

    **Detailed Description**

    The QSGTextureProvider lives primarily in the scene graph rendering thread.

    **See also** **Scene Graph - Two Texture Providers** .
    """

    def __init__(self) -> None:
        ...

    def texture(self) -> QSGTexture:
        """
        https://doc.qt.io/qt-6/qsgtextureprovider.html#texture

        **[pure virtual] QSGTexture *QSGTextureProvider::texture() const**

        Returns a pointer to the texture object.
        """
        ...

    @property
    def textureChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qsgtextureprovider.html#textureChanged

        **[signal] void QSGTextureProvider::textureChanged()**

        This signal is emitted when the texture changes.
        """
        ...
