"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QOpenGLPixelTransferOptions(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html

    **Detailed Description**
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#QOpenGLPixelTran
        sferOptions

        **QOpenGLPixelTransferOptions::QOpenGLPixelTransferOptions()**

        Constructs a new QOpenGLPixelTransferOptions instance with the default
        settings.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QOpenGLPixelTransferOptions") -> None:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#QOpenGLPixelTran
        sferOptions

        **QOpenGLPixelTransferOptions::QOpenGLPixelTransferOptions()**

        Constructs a new QOpenGLPixelTransferOptions instance with the default
        settings.
        """
        ...

    def isSwapBytesEnabled(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#isSwapBytesEnabl
        ed

        **bool QOpenGLPixelTransferOptions::isSwapBytesEnabled() const**

        Returns `true` if the byte ordering for multibyte components is
        reversed.
        """
        ...

    def setSwapBytesEnabled(self, swapBytes: bool) -> None:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#setSwapBytesEnab
        led

        **void QOpenGLPixelTransferOptions::setSwapBytesEnabled(bool swapBytes
        )**

        **swapBytes** specifies if the byte ordering for multibyte components is
        reversed. The default value is `false`. Corresponds to
        `GL_UNPACK_SWAP_BYTES`.

        **See also** **isSwapBytesEnabled** ().
        """
        ...

    def isLeastSignificantBitFirst(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#isLeastSignifica
        ntBitFirst

        **bool QOpenGLPixelTransferOptions::isLeastSignificantBitFirst() const**

        Returns `true` if bits within a byte are ordered from least to most
        significant.
        """
        ...

    def setLeastSignificantByteFirst(self, lsbFirst: bool) -> None:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#setLeastSignific
        antByteFirst

        **void QOpenGLPixelTransferOptions::setLeastSignificantByteFirst(bool
        lsbFirst )**

        **lsbFirst** specifies if bits within a byte are ordered from least to
        most significat. The default value is `false`, meaning that the first
        bit in each byte is the most significant one. This is significant for
        bitmap data only. Corresponds to `GL_UNPACK_LSB_FIRST`.
        """
        ...

    def rowLength(self) -> int:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#rowLength

        **int QOpenGLPixelTransferOptions::rowLength() const**

        Returns the currently set row length.

        **See also** **setRowLength** ().
        """
        ...

    def setRowLength(self, rowLength: int) -> None:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#setRowLength

        **void QOpenGLPixelTransferOptions::setRowLength(int rowLength )**

        Sets the number of pixels in a row to **rowLength**. Corresponds to
        `GL_UNPACK_ROW_LENGTH`. The default value is 0.

        **See also** **rowLength** ().
        """
        ...

    def imageHeight(self) -> int:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#imageHeight

        **int QOpenGLPixelTransferOptions::imageHeight() const**

        Returns the currently set image height.

        **See also** **setImageHeight** ().
        """
        ...

    def setImageHeight(self, imageHeight: int) -> None:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#setImageHeight

        **void QOpenGLPixelTransferOptions::setImageHeight(int imageHeight )**

        Sets the image height for 3D textures to **imageHeight**. Corresponds to
        `GL_UNPACK_IMAGE_HEIGHT`. The default value is 0.

        **See also** **imageHeight** ().
        """
        ...

    def skipPixels(self) -> int:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#skipPixels

        **int QOpenGLPixelTransferOptions::skipPixels() const**

        Returns the number of pixels that are skipped.

        **See also** **setSkipPixels** ().
        """
        ...

    def setSkipPixels(self, skipPixels: int) -> None:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#setSkipPixels

        **void QOpenGLPixelTransferOptions::setSkipPixels(int skipPixels )**

        Sets the number of pixels that are skipped to **skipPixels**.
        Corresponds to `GL_UNPACK_SKIP_PIXELS`. Equivalent to incrementing the
        pointer passed to **QOpenGLTexture::setData** (). The default value is
        0.

        **See also** **skipPixels** ().
        """
        ...

    def skipRows(self) -> int:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#skipRows

        **int QOpenGLPixelTransferOptions::skipRows() const**

        Returns the number of rows that are skipped.

        **See also** **setSkipRows** ().
        """
        ...

    def setSkipRows(self, skipRows: int) -> None:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#setSkipRows

        **void QOpenGLPixelTransferOptions::setSkipRows(int skipRows )**

        Sets the number of rows that are skipped to **skipRows**. Corresponds to
        `GL_UNPACK_SKIP_ROWS`. Equivalent to incrementing the pointer passed to
        **QOpenGLTexture::setData** (). The default value is 0.

        **See also** **skipRows** ().
        """
        ...

    def skipImages(self) -> int:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#skipImages

        **int QOpenGLPixelTransferOptions::skipImages() const**

        Returns the number of images that are skipped.

        **See also** **setSkipImages** ().
        """
        ...

    def setSkipImages(self, skipImages: int) -> None:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#setSkipImages

        **void QOpenGLPixelTransferOptions::setSkipImages(int skipImages )**

        Sets the number of images that are skipped to **skipImages**.
        Corresponds to `GL_UNPACK_SKIP_IMAGES`. Equivalent to incrementing the
        pointer passed to **QOpenGLTexture::setData** (). The default value is
        0.

        **See also** **skipImages** ().
        """
        ...

    def alignment(self) -> int:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#alignment

        **int QOpenGLPixelTransferOptions::alignment() const**

        Returns the current alignment requirement for each pixel row.

        **See also** **setAlignment** ().
        """
        ...

    def setAlignment(self, alignment: int) -> None:
        """
        https://doc.qt.io/qt-6/qopenglpixeltransferoptions.html#setAlignment

        **void QOpenGLPixelTransferOptions::setAlignment(int alignment )**

        Sets the **alignment** requirements for each pixel row. Corresponds to
        `GL_UNPACK_ALIGNMENT`. The default value is 4, as specified by OpenGL.

        **See also** **alignment** ().
        """
        ...

    def swap(self, other: "QOpenGLPixelTransferOptions") -> None:
        ...
