"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from ._functions import PYQT_SIGNAL as PYQT_SIGNAL
from ._functions import PYQT_SLOT as PYQT_SLOT
from ._functions import PYQT_VERSION as PYQT_VERSION
from ._functions import PYQT_VERSION_STR as PYQT_VERSION_STR
from ._functions import QT_VERSION as QT_VERSION
from ._functions import QT_VERSION_STR as QT_VERSION_STR
from ._functions import qSetRealNumberPrecision as qSetRealNumberPrecision
from ._functions import qSetPadChar as qSetPadChar
from ._functions import qSetFieldWidth as qSetFieldWidth
from ._functions import Q_RETURN_ARG as Q_RETURN_ARG
from ._functions import Q_ARG as Q_ARG
from ._functions import QT_TRANSLATE_NOOP as QT_TRANSLATE_NOOP
from ._functions import QT_TR_NOOP as QT_TR_NOOP
from ._functions import pyqtSlot as pyqtSlot
from ._functions import pyqtEnum as pyqtEnum
from ._functions import pyqtClassInfo as pyqtClassInfo
from ._functions import qFloatDistance as qFloatDistance
from ._functions import qQNaN as qQNaN
from ._functions import qSNaN as qSNaN
from ._functions import qInf as qInf
from ._functions import qIsNaN as qIsNaN
from ._functions import qIsFinite as qIsFinite
from ._functions import qIsInf as qIsInf
from ._functions import qFormatLogMessage as qFormatLogMessage
from ._functions import qSetMessagePattern as qSetMessagePattern
from ._functions import qInstallMessageHandler as qInstallMessageHandler
from ._functions import qWarning as qWarning
from ._functions import qInfo as qInfo
from ._functions import qFatal as qFatal
from ._functions import qDebug as qDebug
from ._functions import qCritical as qCritical
from ._functions import pyqtRestoreInputHook as pyqtRestoreInputHook
from ._functions import pyqtRemoveInputHook as pyqtRemoveInputHook
from ._functions import qAddPreRoutine as qAddPreRoutine
from ._functions import qRemovePostRoutine as qRemovePostRoutine
from ._functions import qAddPostRoutine as qAddPostRoutine
from ._functions import qChecksum as qChecksum
from ._functions import qUncompress as qUncompress
from ._functions import qUncompress as qUncompress
from ._functions import qCompress as qCompress
from ._functions import qCompress as qCompress
from ._functions import qEnvironmentVariableIntValue as qEnvironmentVariableIntValue
from ._functions import qEnvironmentVariable as qEnvironmentVariable
from ._functions import qEnvironmentVariable as qEnvironmentVariable
from ._functions import qEnvironmentVariableIsSet as qEnvironmentVariableIsSet
from ._functions import qEnvironmentVariableIsEmpty as qEnvironmentVariableIsEmpty
from ._functions import pyqtPickleProtocol as pyqtPickleProtocol
from ._functions import pyqtSetPickleProtocol as pyqtSetPickleProtocol
from ._functions import qFuzzyCompare as qFuzzyCompare
from ._functions import qVersion as qVersion
from ._functions import qRound64 as qRound64
from ._functions import qRound as qRound
from ._functions import qAbs as qAbs
from ._pyqtSignal import pyqtSignal as pyqtSignal
from ._pyqtBoundSignal import pyqtBoundSignal as pyqtBoundSignal
from ._QtMsgType import QtMsgType as QtMsgType
from ._QCborKnownTags import QCborKnownTags as QCborKnownTags
from ._QCborSimpleType import QCborSimpleType as QCborSimpleType
from ._Qt import Qt as Qt
from ._QKeyCombination import QKeyCombination as QKeyCombination
from ._QObject import QObject as QObject
from ._QAbstractAnimation import QAbstractAnimation as QAbstractAnimation
from ._QAbstractEventDispatcher import (
    QAbstractEventDispatcher as QAbstractEventDispatcher,
)
from ._QModelIndex import QModelIndex as QModelIndex
from ._QPersistentModelIndex import QPersistentModelIndex as QPersistentModelIndex
from ._QAbstractItemModel import QAbstractItemModel as QAbstractItemModel
from ._QAbstractTableModel import QAbstractTableModel as QAbstractTableModel
from ._QAbstractListModel import QAbstractListModel as QAbstractListModel
from ._QModelRoleData import QModelRoleData as QModelRoleData
from ._QAbstractNativeEventFilter import (
    QAbstractNativeEventFilter as QAbstractNativeEventFilter,
)
from ._QAbstractProxyModel import QAbstractProxyModel as QAbstractProxyModel
from ._QAnimationGroup import QAnimationGroup as QAnimationGroup
from ._QBasicTimer import QBasicTimer as QBasicTimer
from ._QBitArray import QBitArray as QBitArray
from ._QIODeviceBase import QIODeviceBase as QIODeviceBase
from ._QIODevice import QIODevice as QIODevice
from ._QBuffer import QBuffer as QBuffer
from ._QByteArray import QByteArray as QByteArray
from ._QByteArrayMatcher import QByteArrayMatcher as QByteArrayMatcher
from ._QCalendar import QCalendar as QCalendar
from ._QCborError import QCborError as QCborError
from ._QCborStreamReader import QCborStreamReader as QCborStreamReader
from ._QCborStreamWriter import QCborStreamWriter as QCborStreamWriter
from ._QCollatorSortKey import QCollatorSortKey as QCollatorSortKey
from ._QCollator import QCollator as QCollator
from ._QCommandLineOption import QCommandLineOption as QCommandLineOption
from ._QCommandLineParser import QCommandLineParser as QCommandLineParser
from ._QConcatenateTablesProxyModel import (
    QConcatenateTablesProxyModel as QConcatenateTablesProxyModel,
)
from ._QCoreApplication import QCoreApplication as QCoreApplication
from ._QEvent import QEvent as QEvent
from ._QTimerEvent import QTimerEvent as QTimerEvent
from ._QChildEvent import QChildEvent as QChildEvent
from ._QDynamicPropertyChangeEvent import (
    QDynamicPropertyChangeEvent as QDynamicPropertyChangeEvent,
)
from ._QCryptographicHash import QCryptographicHash as QCryptographicHash
from ._QDataStream import QDataStream as QDataStream
from ._QDate import QDate as QDate
from ._QTime import QTime as QTime
from ._QDateTime import QDateTime as QDateTime
from ._QDeadlineTimer import QDeadlineTimer as QDeadlineTimer
from ._QDir import QDir as QDir
from ._QDirIterator import QDirIterator as QDirIterator
from ._QEasingCurve import QEasingCurve as QEasingCurve
from ._QElapsedTimer import QElapsedTimer as QElapsedTimer
from ._QEventLoop import QEventLoop as QEventLoop
from ._QEventLoopLocker import QEventLoopLocker as QEventLoopLocker
from ._QFileDevice import QFileDevice as QFileDevice
from ._QFile import QFile as QFile
from ._QFileInfo import QFileInfo as QFileInfo
from ._QFileSelector import QFileSelector as QFileSelector
from ._QFileSystemWatcher import QFileSystemWatcher as QFileSystemWatcher
from ._QIdentityProxyModel import QIdentityProxyModel as QIdentityProxyModel
from ._QItemSelectionRange import QItemSelectionRange as QItemSelectionRange
from ._QItemSelectionModel import QItemSelectionModel as QItemSelectionModel
from ._QItemSelection import QItemSelection as QItemSelection
from ._QJsonParseError import QJsonParseError as QJsonParseError
from ._QJsonDocument import QJsonDocument as QJsonDocument
from ._QJsonValue import QJsonValue as QJsonValue
from ._QLibrary import QLibrary as QLibrary
from ._QLibraryInfo import QLibraryInfo as QLibraryInfo
from ._QLine import QLine as QLine
from ._QLineF import QLineF as QLineF
from ._QLocale import QLocale as QLocale
from ._QLockFile import QLockFile as QLockFile
from ._QMessageLogContext import QMessageLogContext as QMessageLogContext
from ._QMessageLogger import QMessageLogger as QMessageLogger
from ._QLoggingCategory import QLoggingCategory as QLoggingCategory
from ._QMargins import QMargins as QMargins
from ._QMarginsF import QMarginsF as QMarginsF
from ._QMessageAuthenticationCode import (
    QMessageAuthenticationCode as QMessageAuthenticationCode,
)
from ._QMetaMethod import QMetaMethod as QMetaMethod
from ._QMetaEnum import QMetaEnum as QMetaEnum
from ._QMetaProperty import QMetaProperty as QMetaProperty
from ._QMetaClassInfo import QMetaClassInfo as QMetaClassInfo
from ._QMetaType import QMetaType as QMetaType
from ._QMimeData import QMimeData as QMimeData
from ._QMimeDatabase import QMimeDatabase as QMimeDatabase
from ._QMimeType import QMimeType as QMimeType
from ._QMutex import QMutex as QMutex
from ._QRecursiveMutex import QRecursiveMutex as QRecursiveMutex
from ._QSignalBlocker import QSignalBlocker as QSignalBlocker
from ._QObjectCleanupHandler import QObjectCleanupHandler as QObjectCleanupHandler
from ._QMetaObject import QMetaObject as QMetaObject
from ._QGenericArgument import QGenericArgument as QGenericArgument
from ._QGenericReturnArgument import QGenericReturnArgument as QGenericReturnArgument
from ._QOperatingSystemVersion import QOperatingSystemVersion as QOperatingSystemVersion
from ._QParallelAnimationGroup import QParallelAnimationGroup as QParallelAnimationGroup
from ._QPauseAnimation import QPauseAnimation as QPauseAnimation
from ._QVariantAnimation import QVariantAnimation as QVariantAnimation
from ._QPropertyAnimation import QPropertyAnimation as QPropertyAnimation
from ._QPluginLoader import QPluginLoader as QPluginLoader
from ._QPoint import QPoint as QPoint
from ._QPointF import QPointF as QPointF
from ._QProcess import QProcess as QProcess
from ._QProcessEnvironment import QProcessEnvironment as QProcessEnvironment
from ._QRandomGenerator import QRandomGenerator as QRandomGenerator
from ._QReadWriteLock import QReadWriteLock as QReadWriteLock
from ._QReadLocker import QReadLocker as QReadLocker
from ._QWriteLocker import QWriteLocker as QWriteLocker
from ._QRect import QRect as QRect
from ._QRectF import QRectF as QRectF
from ._QRegularExpression import QRegularExpression as QRegularExpression
from ._QRegularExpressionMatch import QRegularExpressionMatch as QRegularExpressionMatch
from ._QRegularExpressionMatchIterator import (
    QRegularExpressionMatchIterator as QRegularExpressionMatchIterator,
)
from ._QResource import QResource as QResource
from ._QRunnable import QRunnable as QRunnable
from ._QSaveFile import QSaveFile as QSaveFile
from ._QSemaphore import QSemaphore as QSemaphore
from ._QSemaphoreReleaser import QSemaphoreReleaser as QSemaphoreReleaser
from ._QSequentialAnimationGroup import (
    QSequentialAnimationGroup as QSequentialAnimationGroup,
)
from ._QSettings import QSettings as QSettings
from ._QSharedMemory import QSharedMemory as QSharedMemory
from ._QSignalMapper import QSignalMapper as QSignalMapper
from ._QSize import QSize as QSize
from ._QSizeF import QSizeF as QSizeF
from ._QSocketNotifier import QSocketNotifier as QSocketNotifier
from ._QSortFilterProxyModel import QSortFilterProxyModel as QSortFilterProxyModel
from ._QStandardPaths import QStandardPaths as QStandardPaths
from ._QStorageInfo import QStorageInfo as QStorageInfo
from ._QStringConverterBase import QStringConverterBase as QStringConverterBase
from ._QStringConverter import QStringConverter as QStringConverter
from ._QStringEncoder import QStringEncoder as QStringEncoder
from ._QStringDecoder import QStringDecoder as QStringDecoder
from ._QStringListModel import QStringListModel as QStringListModel
from ._QSysInfo import QSysInfo as QSysInfo
from ._QSystemSemaphore import QSystemSemaphore as QSystemSemaphore
from ._QTemporaryDir import QTemporaryDir as QTemporaryDir
from ._QTemporaryFile import QTemporaryFile as QTemporaryFile
from ._QTextBoundaryFinder import QTextBoundaryFinder as QTextBoundaryFinder
from ._QTextStream import QTextStream as QTextStream
from ._QTextStreamManipulator import QTextStreamManipulator as QTextStreamManipulator
from ._QThread import QThread as QThread
from ._QThreadPool import QThreadPool as QThreadPool
from ._QTimeLine import QTimeLine as QTimeLine
from ._QTimer import QTimer as QTimer
from ._QTimeZone import QTimeZone as QTimeZone
from ._QTranslator import QTranslator as QTranslator
from ._QTransposeProxyModel import QTransposeProxyModel as QTransposeProxyModel
from ._QUrl import QUrl as QUrl
from ._QUrlQuery import QUrlQuery as QUrlQuery
from ._QUuid import QUuid as QUuid
from ._QVariant import QVariant as QVariant
from ._QVersionNumber import QVersionNumber as QVersionNumber
from ._QTypeRevision import QTypeRevision as QTypeRevision
from ._QWaitCondition import QWaitCondition as QWaitCondition
from ._QXmlStreamAttribute import QXmlStreamAttribute as QXmlStreamAttribute
from ._QXmlStreamNamespaceDeclaration import (
    QXmlStreamNamespaceDeclaration as QXmlStreamNamespaceDeclaration,
)
from ._QXmlStreamNotationDeclaration import (
    QXmlStreamNotationDeclaration as QXmlStreamNotationDeclaration,
)
from ._QXmlStreamEntityDeclaration import (
    QXmlStreamEntityDeclaration as QXmlStreamEntityDeclaration,
)
from ._QXmlStreamEntityResolver import (
    QXmlStreamEntityResolver as QXmlStreamEntityResolver,
)
from ._QXmlStreamReader import QXmlStreamReader as QXmlStreamReader
from ._QXmlStreamWriter import QXmlStreamWriter as QXmlStreamWriter
from ._QXmlStreamAttributes import QXmlStreamAttributes as QXmlStreamAttributes
from ._QMutexLocker import QMutexLocker as QMutexLocker
from ._QWinEventNotifier import QWinEventNotifier as QWinEventNotifier
