"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import PyQt6.sip
from PyQt6 import QtWidgets


class QHelpIndexWidget(QtWidgets.QListView):
    """
    https://doc.qt.io/qt-6/qhelpindexwidget.html

    **Detailed Description**
    """

    def activateCurrentItem(self) -> None:
        """
        https://doc.qt.io/qt-6/qhelpindexwidget.html#activateCurrentItem

        **[slot] void QHelpIndexWidget::activateCurrentItem()**

        Activates the current item which will result eventually in the emitting
        of a linkActivated() or linksActivated() signal.
        """
        ...

    def filterIndices(self, filter: str, wildcard: str = ...) -> None:
        """
        https://doc.qt.io/qt-6/qhelpindexwidget.html#filterIndices

        **[slot] void QHelpIndexWidget::filterIndices(const QString & filter ,
        const QString & wildcard = QString())**

        Filters the indices according to **filter** or **wildcard**. The item
        with the best match is set as current item.

        **See also** **QHelpIndexModel::filter** ().
        """
        ...

    @property
    def documentActivated(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qhelpindexwidget.html#documentActivated

        **[signal, since 5.15] void QHelpIndexWidget::documentActivated(const
        QHelpLink & document , const QString & keyword )**

        This signal is emitted when an item is activated and its associated
        **document** should be shown. To know where the link belongs to, the
        **keyword** is given as a second parameter.

        This function was introduced in Qt 5.15.
        """
        ...

    @property
    def documentsActivated(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qhelpindexwidget.html#documentsActivated

        **[signal, since 5.15] void QHelpIndexWidget::documentsActivated(const
        QList<QHelpLink> & documents , const QString & keyword )**

        This signal is emitted when the item representing the **keyword** is
        activated and the item has more than one document associated. The
        **documents** consist of the document titles and their URLs.

        This function was introduced in Qt 5.15.
        """
        ...
