"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui


class QQuickGraphicsDevice(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qquickgraphicsdevice.html

    **Detailed Description**

    **See also** **QQuickWindow::setGraphicsDevice** () and
    **QQuickRenderTarget** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qquickgraphicsdevice.html#QQuickGraphicsDevice

        **QQuickGraphicsDevice::QQuickGraphicsDevice()**

        Constructs a default QQuickGraphicsDevice that does not reference any
        native objects.
        """
        ...

    @typing.overload
    def __init__(self, other: "QQuickGraphicsDevice") -> None:
        """
        https://doc.qt.io/qt-6/qquickgraphicsdevice.html#QQuickGraphicsDevice

        **QQuickGraphicsDevice::QQuickGraphicsDevice()**

        Constructs a default QQuickGraphicsDevice that does not reference any
        native objects.
        """
        ...

    @staticmethod
    def fromOpenGLContext(context: QtGui.QOpenGLContext) -> "QQuickGraphicsDevice":
        """
        https://doc.qt.io/qt-6/qquickgraphicsdevice.html#fromOpenGLContext

        **[static] QQuickGraphicsDevice
        QQuickGraphicsDevice::fromOpenGLContext(QOpenGLContext * context )**

        Returns a new **QQuickGraphicsDevice**  referencing an existing OpenGL
        **context**.

        This factory function is suitable for OpenGL.
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qquickgraphicsdevice.html#isNull

        **bool QQuickGraphicsDevice::isNull() const**

        Returns true if this is a default constructed graphics device that does
        not reference any native objects.
        """
        ...
