"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QJsonParseError(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qjsonparseerror.html

    **Detailed Description**

    **See also** **JSON Support in Qt**  and **JSON Save Game Example** .
    """

    class ParseError(enum.Enum):
        NoError: QJsonParseError = ...
        UnterminatedObject: QJsonParseError = ...
        MissingNameSeparator: QJsonParseError = ...
        UnterminatedArray: QJsonParseError = ...
        MissingValueSeparator: QJsonParseError = ...
        IllegalValue: QJsonParseError = ...
        TerminationByNumber: QJsonParseError = ...
        IllegalNumber: QJsonParseError = ...
        IllegalEscapeSequence: QJsonParseError = ...
        IllegalUTF8String: QJsonParseError = ...
        UnterminatedString: QJsonParseError = ...
        MissingObject: QJsonParseError = ...
        DeepNesting: QJsonParseError = ...
        DocumentTooLarge: QJsonParseError = ...
        GarbageAtEnd: QJsonParseError = ...

    error = ...
    offset: int = ...

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QJsonParseError") -> None:
        ...

    def errorString(self) -> str:
        """
        https://doc.qt.io/qt-6/qjsonparseerror.html#errorString

        **QString QJsonParseError::errorString() const**

        Returns the human-readable message appropriate to the reported JSON
        parsing error.

        **See also** **error** .
        """
        ...
