"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtNetwork import *


class QTcpSocket(QAbstractSocket):
    """
    https://doc.qt.io/qt-6/qtcpsocket.html

    **Detailed Description**

    TCP (Transmission Control Protocol) is a reliable, stream-oriented,
    connection-oriented transport protocol. It is especially well suited for
    continuous transmission of data.

    QTcpSocket is a convenience subclass of **QAbstractSocket**  that allows you
    to establish a TCP connection and transfer streams of data. See the
    **QAbstractSocket**  documentation for details.

    **Note:** TCP sockets cannot be opened in QIODevice::Unbuffered mode.

    **See also** **QTcpServer** , **QUdpSocket** , **QNetworkAccessManager** ,
    **Fortune Server Example** , **Fortune Client Example** , **Threaded Fortune
    Server Example** , **Blocking Fortune Client Example** , **Loopback
    Example** , and **Torrent Example** .
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtcpsocket.html#QTcpSocket

        **QTcpSocket::QTcpSocket(QObject * parent = nullptr)**

        Creates a QTcpSocket object in state `UnconnectedState`.

        **parent** is passed on to the **QObject**  constructor.

        **See also** **socketType** ().
        """
        ...
