"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtSensors import *


class QTapSensor(QSensor):
    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        ...

    def returnDoubleTapEventsChanged(self, returnDoubleTapEvents: bool) -> None:
        ...

    def setReturnDoubleTapEvents(self, returnDoubleTapEvents: bool) -> None:
        ...

    def returnDoubleTapEvents(self) -> bool:
        ...

    def reading(self) -> QTapReading:
        ...
