"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QXmlStreamNotationDeclaration(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qxmlstreamnotationdeclaration.html

    **Detailed Description**

    An notation declaration consists of a **name** (), a **systemId** (), and a
    **publicId** ().
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamnotationdeclaration.html#QXmlStreamNota
        tionDeclaration

        **QXmlStreamNotationDeclaration::QXmlStreamNotationDeclaration()**

        Creates an empty notation declaration.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QXmlStreamNotationDeclaration") -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamnotationdeclaration.html#QXmlStreamNota
        tionDeclaration

        **QXmlStreamNotationDeclaration::QXmlStreamNotationDeclaration()**

        Creates an empty notation declaration.
        """
        ...

    def publicId(self) -> str:
        """
        https://doc.qt.io/qt-6/qxmlstreamnotationdeclaration.html#publicId

        **QStringView QXmlStreamNotationDeclaration::publicId() const**

        Returns the public identifier.
        """
        ...

    def systemId(self) -> str:
        """
        https://doc.qt.io/qt-6/qxmlstreamnotationdeclaration.html#systemId

        **QStringView QXmlStreamNotationDeclaration::systemId() const**

        Returns the system identifier.
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qxmlstreamnotationdeclaration.html#name

        **QStringView QXmlStreamNotationDeclaration::name() const**

        Returns the notation name.
        """
        ...
