"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore

PYQT_SIGNAL = typing.Union[QtCore.pyqtSignal, QtCore.pyqtBoundSignal]
PYQT_SLOT = typing.Union[typing.Callable[..., None], QtCore.pyqtBoundSignal]
PYQT_OPENGL_ARRAY = typing.Union[
    typing.Sequence[int], typing.Sequence[float], PyQt6.sip.Buffer, None
]
PYQT_OPENGL_BOUND_ARRAY = typing.Union[
    typing.Sequence[int], typing.Sequence[float], PyQt6.sip.Buffer, int, None
]
PYQT_SHADER_ATTRIBUTE_ARRAY = typing.Union[
    typing.Sequence[QtGui.QVector2D],
    typing.Sequence[QtGui.QVector3D],
    typing.Sequence[QtGui.QVector4D],
    typing.Sequence[typing.Sequence[float]],
]
PYQT_SHADER_UNIFORM_VALUE_ARRAY = typing.Union[
    typing.Sequence[QtGui.QVector2D],
    typing.Sequence[QtGui.QVector3D],
    typing.Sequence[QtGui.QVector4D],
    typing.Sequence[QtGui.QMatrix2x2],
    typing.Sequence[QtGui.QMatrix2x3],
    typing.Sequence[QtGui.QMatrix2x4],
    typing.Sequence[QtGui.QMatrix3x2],
    typing.Sequence[QtGui.QMatrix3x3],
    typing.Sequence[QtGui.QMatrix3x4],
    typing.Sequence[QtGui.QMatrix4x2],
    typing.Sequence[QtGui.QMatrix4x3],
    typing.Sequence[QtGui.QMatrix4x4],
    typing.Sequence[typing.Sequence[float]],
]
