"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtWidgets
from PyQt6 import QtCore
from PyQt6.QtDesigner import *


class QDesignerObjectInspectorInterface(QtWidgets.QWidget):
    """
    https://doc.qt.io/qt-6/qdesignerobjectinspectorinterface.html

    **Detailed Description**

    You can use the QDesignerObjectInspectorInterface to change the current form
    window selection. For example, when implementing a custom widget plugin:

    **QDesignerObjectInspectorInterface**  *objectInspector = 0;
    objectInspector = formEditor->objectInspector();
    **QDesignerFormWindowManagerInterface**  *manager = 0;
                manager =
    formEditor->formWindowManager();
    objectInspector->setFormWindow(manager->formWindow(0));

    The QDesignerObjectInspectorInterface class is not intended to be
    instantiated directly. You can retrieve an interface to **Qt Designer** 's
    object inspector using the **QDesignerFormEditorInterface::objectInspector**
    () function. A pointer to **Qt Designer** 's current
    **QDesignerFormEditorInterface**  object (`formEditor` in the example above)
    is provided by the **QDesignerCustomWidgetInterface::initialize** ()
    function's parameter. When implementing a custom widget plugin, you must
    subclass the **QDesignerCustomWidgetInterface**  to expose your plugin to
    **Qt Designer**.

    The interface provides the **core** () function that you can use to retrieve
    a pointer to **Qt Designer** 's current **QDesignerFormEditorInterface**
    object, and the **setFormWindow** () function that enables you to change the
    current form window selection.

    **See also** **QDesignerFormEditorInterface**  and
    **QDesignerFormWindowInterface** .
    """

    def __init__(
        self, parent: QtWidgets.QWidget, flags: QtCore.Qt.WindowType = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerobjectinspectorinterface.html#QDesignerO
        bjectInspectorInterface

        **QDesignerObjectInspectorInterface::QDesignerObjectInspectorInterface(Q
        Widget * parent , Qt::WindowFlags flags = {})**

        Constructs an object inspector interface with the given **parent** and
        the specified window **flags**.
        """
        ...

    def setFormWindow(self, formWindow: QDesignerFormWindowInterface) -> None:
        """
        https://doc.qt.io/qt-6/qdesignerobjectinspectorinterface.html#setFormWin
        dow

        **[pure virtual slot] void QDesignerObjectInspectorInterface::setFormWin
        dow(QDesignerFormWindowInterface * formWindow )**

        Sets the currently selected form window to **formWindow**.
        """
        ...

    def core(self) -> QDesignerFormEditorInterface:
        """
        https://doc.qt.io/qt-6/qdesignerobjectinspectorinterface.html#core

        **[virtual] QDesignerFormEditorInterface
        *QDesignerObjectInspectorInterface::core() const**

        Returns a pointer to **Qt Designer** 's current
        **QDesignerFormEditorInterface**  object.
        """
        ...
