"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QLibraryInfo(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qlibraryinfo.html

    **Detailed Description**

    Many pieces of information are established when Qt is configured and built.
    This class provides an abstraction for accessing that information. By using
    the static functions of this class, an application can obtain information
    about the instance of the Qt library which the application is using at run-
    time.

    You can also use a `qt.conf` file to override the hard-coded paths that are
    compiled into the Qt library. For more information, see the **Using
    qt.conf**  documentation.

    **See also** **QSysInfo**  and **Using qt.conf** .
    """

    class LibraryPath(enum.Enum):
        PrefixPath: QLibraryInfo = ...
        DocumentationPath: QLibraryInfo = ...
        HeadersPath: QLibraryInfo = ...
        LibrariesPath: QLibraryInfo = ...
        LibraryExecutablesPath: QLibraryInfo = ...
        BinariesPath: QLibraryInfo = ...
        PluginsPath: QLibraryInfo = ...
        Qml2ImportsPath: QLibraryInfo = ...
        ArchDataPath: QLibraryInfo = ...
        DataPath: QLibraryInfo = ...
        TranslationsPath: QLibraryInfo = ...
        ExamplesPath: QLibraryInfo = ...
        TestsPath: QLibraryInfo = ...
        SettingsPath: QLibraryInfo = ...
        QmlImportsPath: QLibraryInfo = ...

    def __init__(self, a0: "QLibraryInfo") -> None:
        ...

    @staticmethod
    def version() -> "QVersionNumber":
        """
        https://doc.qt.io/qt-6/qlibraryinfo.html#version

        **[static, since 5.8] QVersionNumber QLibraryInfo::version()**

        Returns the version of the Qt library.

        This function was introduced in Qt 5.8.

        **See also** **qVersion** ().
        """
        ...

    @staticmethod
    def path(p: "QLibraryInfo.LibraryPath") -> str:
        """
        https://doc.qt.io/qt-6/qlibraryinfo.html#path

        **[static, since 6.0] QString
        QLibraryInfo::path(QLibraryInfo::LibraryPath p )**

        Returns the path specified by **p**.

        This function was introduced in Qt 6.0.
        """
        ...

    @staticmethod
    def isDebugBuild() -> bool:
        """
        https://doc.qt.io/qt-6/qlibraryinfo.html#isDebugBuild

        **[static, since 5.0] bool QLibraryInfo::isDebugBuild()**

        Returns `true` if this build of Qt was built with debugging enabled, or
        false if it was built in release mode.

        This function was introduced in Qt 5.0.
        """
        ...
