"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtGui
from PyQt6.QtWidgets import *
import enum


class QStyleHintReturnMask(QStyleHintReturn):
    """
    https://doc.qt.io/qt-6/qstylehintreturnmask.html

    **Detailed Description**
    """

    class StyleOptionVersion(enum.Enum):
        Version: QStyleHintReturnMask = ...

    class StyleOptionType(enum.Enum):
        Type: QStyleHintReturnMask = ...

    region: QtGui = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qstylehintreturnmask.html#QStyleHintReturnMask

        **QStyleHintReturnMask::QStyleHintReturnMask()**

        Constructs a QStyleHintReturnMask. The member variables are initialized
        to default values.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QStyleHintReturnMask") -> None:
        """
        https://doc.qt.io/qt-6/qstylehintreturnmask.html#QStyleHintReturnMask

        **QStyleHintReturnMask::QStyleHintReturnMask()**

        Constructs a QStyleHintReturnMask. The member variables are initialized
        to default values.
        """
        ...
