"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtWidgets import *
import enum


class QStyleHintReturn(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qstylehintreturn.html

    **Detailed Description**

    QStyleHintReturn and its subclasses are used to pass information from a
    style back to the querying widget. This is most useful when the return value
    from **QStyle::styleHint** () does not provide enough detail; for example,
    when a mask is to be returned.
    """

    class StyleOptionVersion(enum.Enum):
        Version: QStyleHintReturn = ...

    class StyleOptionType(enum.Enum):
        Type: QStyleHintReturn = ...

    class HintReturnType(enum.Enum):
        SH_Default: QStyleHintReturn = ...
        SH_Mask: QStyleHintReturn = ...
        SH_Variant: QStyleHintReturn = ...

    type: int = ...
    version: int = ...

    @typing.overload
    def __init__(self, version: int = ..., type: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qstylehintreturn.html#QStyleHintReturn

        **QStyleHintReturn::QStyleHintReturn(int version =
        QStyleOption::Version, int type = SH_Default)**

        Constructs a QStyleHintReturn with version **version** and type
        **type**.

        The version has no special meaning for QStyleHintReturn; it can be used
        by subclasses to distinguish between different version of the same hint
        type.

        **See also** **QStyleOption::version**  and **QStyleOption::type** .
        """
        ...

    @typing.overload
    def __init__(self, a0: "QStyleHintReturn") -> None:
        """
        https://doc.qt.io/qt-6/qstylehintreturn.html#QStyleHintReturn

        **QStyleHintReturn::QStyleHintReturn(int version =
        QStyleOption::Version, int type = SH_Default)**

        Constructs a QStyleHintReturn with version **version** and type
        **type**.

        The version has no special meaning for QStyleHintReturn; it can be used
        by subclasses to distinguish between different version of the same hint
        type.

        **See also** **QStyleOption::version**  and **QStyleOption::type** .
        """
        ...
