"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import PyQt6.sip


class QGenericReturnArgument(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qgenericreturnargument.html

    **Detailed Description**

    This class should never be used directly. Please use the **Q_RETURN_ARG** ()
    macro instead.

    **See also** **Q_RETURN_ARG** (), **QMetaObject::invokeMethod** (), and
    **QGenericArgument** .
    """

    ...
