"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
from PyQt6.QtSensors import *
import enum


class QTapReading(QSensorReading):
    class TapDirection(enum.Enum):
        Undefined: QTapReading = ...
        X: QTapReading = ...
        Y: QTapReading = ...
        Z: QTapReading = ...
        X_Pos: QTapReading = ...
        Y_Pos: QTapReading = ...
        Z_Pos: QTapReading = ...
        X_Neg: QTapReading = ...
        Y_Neg: QTapReading = ...
        Z_Neg: QTapReading = ...
        X_Both: QTapReading = ...
        Y_Both: QTapReading = ...
        Z_Both: QTapReading = ...

    def setDoubleTap(self, doubleTap: bool) -> None:
        ...

    def isDoubleTap(self) -> bool:
        ...

    def setTapDirection(self, tapDirection: "QTapReading.TapDirection") -> None:
        ...

    def tapDirection(self) -> "QTapReading.TapDirection":
        ...
