"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore


class QHelpFilterData(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qhelpfilterdata.html

    **Detailed Description**

    By using **setComponents** () you may constrain the search results to
    documents that belong only to components specified on the given list. By
    using **setVersions** () you may constrain the search results to documents
    that belong only to versions specified on the given list.

    **See also** **QHelpFilterEngine** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qhelpfilterdata.html#QHelpFilterData

        **QHelpFilterData::QHelpFilterData()**

        Constructs the empty filter.
        """
        ...

    @typing.overload
    def __init__(self, other: "QHelpFilterData") -> None:
        """
        https://doc.qt.io/qt-6/qhelpfilterdata.html#QHelpFilterData-1

        **QHelpFilterData::QHelpFilterData(const QHelpFilterData & other )**

        Constructs a copy of **other**.
        """
        ...

    def versions(self) -> typing.List[QtCore.QVersionNumber]:
        """
        https://doc.qt.io/qt-6/qhelpfilterdata.html#versions

        **QList<QVersionNumber> QHelpFilterData::versions() const**

        Returns the version list that is used for filtering the search results.

        **See also** **setVersions** ().
        """
        ...

    def components(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qhelpfilterdata.html#components

        **QStringList QHelpFilterData::components() const**

        Returns the component list that is used for filtering the search
        results.

        **See also** **setComponents** ().
        """
        ...

    def setVersions(self, versions: typing.Iterable[QtCore.QVersionNumber]) -> None:
        """
        https://doc.qt.io/qt-6/qhelpfilterdata.html#setVersions

        **void QHelpFilterData::setVersions(const QList<QVersionNumber> &
        versions )**

        Specifies the version list that is used for filtering the search
        results. Only results from versions in the list **versions** shall be
        returned.

        **See also** **versions** ().
        """
        ...

    def setComponents(self, components: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qhelpfilterdata.html#setComponents

        **void QHelpFilterData::setComponents(const QStringList & components )**

        Specifies the component list that is used for filtering the search
        results. Only results from components in the list **components** shall
        be returned.

        **See also** **components** ().
        """
        ...

    def swap(self, other: "QHelpFilterData") -> None:
        """
        https://doc.qt.io/qt-6/qhelpfilterdata.html#swap

        **void QHelpFilterData::swap(QHelpFilterData & other )**

        Swaps the filter **other** with this filter. This operation is very fast
        and never fails.
        """
        ...
