"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QColorConstants(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qcolorconstants.html

    **Detailed Description**

    These constants are usable everywhere a **QColor**  object is expected:

    painter.setBrush(QColorConstants::Svg::lightblue);

    Their usage is much cheaper than e.g. passing a string to **QColor** 's
    constructor, as they don't require any parsing of the string, and always
    result in a valid **QColor**  object:

    object.setColor(QColor("lightblue")); // expensive

    **Qt Colors**

    The following colors are defined in the `QColorConstants` namespace:

    NameHexColor
    Color0#000000

    Color1#ffffff

    Black#000000
    White#ffffff

    DarkGray#808080

    Gray#a0a0a4

    LightGray#c0c0c0
    Red#ff0000

    Green#00ff00

    Blue#0000ff

    Cyan#00ffff
    Magenta#ff00ff

    Yellow#ffff00

    DarkRed#800000

    DarkGreen#008000
    DarkBlue#000080

    DarkCyan#008080

    DarkMagenta#800080
    DarkYellow#808000

    Transparent#00000000(transparent)

    **SVG Colors**

    The following table lists the available **SVG colors** . They are available
    in the `QColorConstants::Svg` inner namespace.

    NameHexColor
    aliceblue#f0f8ff

    antiquewhite#faebd7

    aqua#00ffff
    aquamarine#7fffd4

    azure#f0ffff

    beige#f5f5dc

    bisque#ffe4c4
    black#000000

    blanchedalmond#ffebcd

    blue#0000ff
    blueviolet#8a2be2

    brown#a52a2a

    burlywood#deb887
    cadetblue#5f9ea0

    chartreuse#7fff00

    chocolate#d2691e
    coral#ff7f50

    cornflowerblue#6495ed

    cornsilk#fff8dc
    crimson#dc143c

    cyan#00ffff

    darkblue#00008b

    darkcyan#008b8b
    darkgoldenrod#b8860b

    darkgray#a9a9a9

    darkgreen#006400
    darkgrey#a9a9a9

    darkkhaki#bdb76b

    darkmagenta#8b008b
    darkolivegreen#556b2f

    darkorange#ff8c00

    darkorchid#9932cc
    darkred#8b0000

    darksalmon#e9967a

    darkseagreen#8fbc8f
    darkslateblue#483d8b

    darkslategray#2f4f4f

    darkslategrey#2f4f4f
    darkturquoise#00ced1

    darkviolet#9400d3

    deeppink#ff1493
    deepskyblue#00bfff

    dimgray#696969

    dimgrey#696969
    dodgerblue#1e90ff

    firebrick#b22222

    floralwhite#fffaf0
    forestgreen#228b22

    fuchsia#ff00ff

    gainsboro#dcdcdc
    ghostwhite#f8f8ff

    gold#ffd700

    goldenrod#daa520

    gray#808080
    grey#808080

    green#008000

    greenyellow#adff2f

    honeydew#f0fff0
    hotpink#ff69b4

    indianred#cd5c5c

    indigo#4b0082

    ivory#fffff0
    khaki#f0e68c

    lavender#e6e6fa

    lavenderblush#fff0f5
    lawngreen#7cfc00

    lemonchiffon#fffacd

    lightblue#add8e6
    lightcoral#f08080

    lightcyan#e0ffff

    lightgoldenrodyellow#fafad2
    lightgray#d3d3d3

    lightgreen#90ee90

    lightgrey#d3d3d3
    lightpink#ffb6c1

    lightsalmon#ffa07a

    lightseagreen#20b2aa
    lightskyblue#87cefa

    lightslategray#778899

    lightslategrey#778899
    lightsteelblue#b0c4de

    lightyellow#ffffe0

    lime#00ff00
    limegreen#32cd32

    linen#faf0e6

    magenta#ff00ff

    maroon#800000
    mediumaquamarine#66cdaa

    mediumblue#0000cd

    mediumorchid#ba55d3
    mediumpurple#9370db

    mediumseagreen#3cb371

    mediumslateblue#7b68ee
    mediumspringgreen#00fa9a

    mediumturquoise#48d1cc
    mediumvioletred#c71585

    midnightblue#191970

    mintcream#f5fffa
    mistyrose#ffe4e1

    moccasin#ffe4b5

    navajowhite#ffdead
    navy#000080

    oldlace#fdf5e6

    olive#808000

    olivedrab#6b8e23
    orange#ffa500

    orangered#ff4500

    orchid#da70d6
    palegoldenrod#eee8aa

    palegreen#98fb98

    paleturquoise#afeeee
    palevioletred#db7093

    papayawhip#ffefd5

    peachpuff#ffdab9
    peru#cd853f

    pink#ffc0cb

    plum#dda0dd

    powderblue#b0e0e6
    purple#800080

    red#ff0000

    rosybrown#bc8f8f

    royalblue#4169e1
    saddlebrown#8b4513

    salmon#fa8072

    sandybrown#f4a460
    seagreen#2e8b57

    seashell#fff5ee

    sienna#a0522d

    silver#c0c0c0
    skyblue#87ceeb

    slateblue#6a5acd

    slategray#708090
    slategrey#708090

    snow#fffafa

    springgreen#00ff7f
    steelblue#4682b4

    tan#d2b48c

    teal#008080

    thistle#d8bfd8
    tomato#ff6347

    turquoise#40e0d0

    violet#ee82ee

    wheat#f5deb3
    white#ffffff

    whitesmoke#f5f5f5

    yellow#ffff00
    yellowgreen#9acd32

    **See also** **QColor**  and **Qt::GlobalColor** .
    """

    class Svg(PyQt6.sip.simplewrapper):
        aliceblue: typing = ...
        antiquewhite: typing = ...
        aqua: typing = ...
        aquamarine: typing = ...
        azure: typing = ...
        beige: typing = ...
        bisque: typing = ...
        black: typing = ...
        blanchedalmond: typing = ...
        blue: typing = ...
        blueviolet: typing = ...
        brown: typing = ...
        burlywood: typing = ...
        cadetblue: typing = ...
        chartreuse: typing = ...
        chocolate: typing = ...
        coral: typing = ...
        cornflowerblue: typing = ...
        cornsilk: typing = ...
        crimson: typing = ...
        cyan: typing = ...
        darkblue: typing = ...
        darkcyan: typing = ...
        darkgoldenrod: typing = ...
        darkgray: typing = ...
        darkgreen: typing = ...
        darkgrey: typing = ...
        darkkhaki: typing = ...
        darkmagenta: typing = ...
        darkolivegreen: typing = ...
        darkorange: typing = ...
        darkorchid: typing = ...
        darkred: typing = ...
        darksalmon: typing = ...
        darkseagreen: typing = ...
        darkslateblue: typing = ...
        darkslategray: typing = ...
        darkslategrey: typing = ...
        darkturquoise: typing = ...
        darkviolet: typing = ...
        deeppink: typing = ...
        deepskyblue: typing = ...
        dimgray: typing = ...
        dimgrey: typing = ...
        dodgerblue: typing = ...
        firebrick: typing = ...
        floralwhite: typing = ...
        forestgreen: typing = ...
        fuchsia: typing = ...
        gainsboro: typing = ...
        ghostwhite: typing = ...
        gold: typing = ...
        goldenrod: typing = ...
        gray: typing = ...
        green: typing = ...
        greenyellow: typing = ...
        grey: typing = ...
        honeydew: typing = ...
        hotpink: typing = ...
        indianred: typing = ...
        indigo: typing = ...
        ivory: typing = ...
        khaki: typing = ...
        lavender: typing = ...
        lavenderblush: typing = ...
        lawngreen: typing = ...
        lemonchiffon: typing = ...
        lightblue: typing = ...
        lightcoral: typing = ...
        lightcyan: typing = ...
        lightgoldenrodyellow: typing = ...
        lightgray: typing = ...
        lightgreen: typing = ...
        lightgrey: typing = ...
        lightpink: typing = ...
        lightsalmon: typing = ...
        lightseagreen: typing = ...
        lightskyblue: typing = ...
        lightslategray: typing = ...
        lightslategrey: typing = ...
        lightsteelblue: typing = ...
        lightyellow: typing = ...
        lime: typing = ...
        limegreen: typing = ...
        linen: typing = ...
        magenta: typing = ...
        maroon: typing = ...
        mediumaquamarine: typing = ...
        mediumblue: typing = ...
        mediumorchid: typing = ...
        mediumpurple: typing = ...
        mediumseagreen: typing = ...
        mediumslateblue: typing = ...
        mediumspringgreen: typing = ...
        mediumturquoise: typing = ...
        mediumvioletred: typing = ...
        midnightblue: typing = ...
        mintcream: typing = ...
        mistyrose: typing = ...
        moccasin: typing = ...
        navajowhite: typing = ...
        navy: typing = ...
        oldlace: typing = ...
        olive: typing = ...
        olivedrab: typing = ...
        orange: typing = ...
        orangered: typing = ...
        orchid: typing = ...
        palegoldenrod: typing = ...
        palegreen: typing = ...
        paleturquoise: typing = ...
        palevioletred: typing = ...
        papayawhip: typing = ...
        peachpuff: typing = ...
        peru: typing = ...
        pink: typing = ...
        plum: typing = ...
        powderblue: typing = ...
        purple: typing = ...
        red: typing = ...
        rosybrown: typing = ...
        royalblue: typing = ...
        saddlebrown: typing = ...
        salmon: typing = ...
        sandybrown: typing = ...
        seagreen: typing = ...
        seashell: typing = ...
        sienna: typing = ...
        silver: typing = ...
        skyblue: typing = ...
        slateblue: typing = ...
        slategray: typing = ...
        slategrey: typing = ...
        snow: typing = ...
        springgreen: typing = ...
        steelblue: typing = ...
        tan: typing = ...
        teal: typing = ...
        thistle: typing = ...
        tomato: typing = ...
        turquoise: typing = ...
        violet: typing = ...
        wheat: typing = ...
        white: typing = ...
        whitesmoke: typing = ...
        yellow: typing = ...
        yellowgreen: typing = ...

    Black: typing = ...
    Blue: typing = ...
    Color0: typing = ...
    Color1: typing = ...
    Cyan: typing = ...
    DarkBlue: typing = ...
    DarkCyan: typing = ...
    DarkGray: typing = ...
    DarkGreen: typing = ...
    DarkMagenta: typing = ...
    DarkRed: typing = ...
    DarkYellow: typing = ...
    Gray: typing = ...
    Green: typing = ...
    LightGray: typing = ...
    Magenta: typing = ...
    Red: typing = ...
    Transparent: typing = ...
    White: typing = ...
    Yellow: typing = ...
