"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtQuick import *


class QNativeInterface(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qnativeinterface.html

    **Detailed Description**

    For documentation on how to use these interfaces, see the **Native
    Interfaces**  overview.

    **Warning:** There are no source or binary compatibility guarantees for the
    native interface APIs, meaning that an application using these interfaces is
    only guaranteed to work with the Qt version it was developed against.
    """

    class QSGOpenGLTexture(PyQt6.sip.simplewrapper):
        @staticmethod
        def fromNative(
            textureId: int,
            window: QQuickWindow,
            size: QtCore.QSize,
            options: QQuickWindow.CreateTextureOption = ...,
        ) -> QSGTexture:
            ...

        def nativeTexture(self) -> int:
            ...
