"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QDragEnterEvent(QDragMoveEvent):
    """
    https://doc.qt.io/qt-6/qdragenterevent.html

    **Detailed Description**

    A widget must accept this event in order to receive the **drag move events**
    that are sent while the drag and drop action is in progress. The drag enter
    event is always immediately followed by a drag move event.

    QDragEnterEvent inherits most of its functionality from **QDragMoveEvent** ,
    which in turn inherits most of its functionality from **QDropEvent** .

    **See also** **QDragLeaveEvent** , **QDragMoveEvent** , and **QDropEvent** .
    """

    def __init__(
        self,
        pos: QtCore.QPoint,
        actions: QtCore.Qt.DropAction,
        data: QtCore.QMimeData,
        buttons: QtCore.Qt.MouseButton,
        modifiers: QtCore.Qt.KeyboardModifier,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdragenterevent.html#QDragEnterEvent-2

        **QDragEnterEvent::QDragEnterEvent(const QPoint & point ,
        Qt::DropActions actions , const QMimeData * data , Qt::MouseButtons
        buttons , Qt::KeyboardModifiers modifiers )**

        Constructs a QDragEnterEvent that represents a drag entering a widget at
        the given **point** with mouse and keyboard states specified by
        **buttons** and **modifiers**.

        The drag data is passed as MIME-encoded information in **data** , and
        the specified **actions** describe the possible types of drag and drop
        operation that can be performed.

        **Warning:** Do not create a QDragEnterEvent yourself since these
        objects rely on Qt's internal state.
        """
        ...
