"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QWidgetItem(QLayoutItem):
    """
    https://doc.qt.io/qt-6/qwidgetitem.html

    **Detailed Description**

    Normally, you don't need to use this class directly. Qt's built-in layout
    managers provide the following functions for manipulating widgets in
    layouts:

    ClassFunctions
    **QBoxLayout** **addWidget** (), **insertWidget** (),
    **setStretchFactor** ()
    **QGridLayout** **addWidget** ()
    **QStackedLayout** **addWidget** (), **insertWidget** (), **currentWidget**
    (), **setCurrentWidget** (), **widget** ()

    **See also** **QLayout** , **QSpacerItem** , and **QLayoutItem::widget** ().
    """

    def __init__(self, w: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qwidgetitem.html#QWidgetItem-1

        **QWidgetItem::QWidgetItem(QWidget * widget )**

        Creates an item containing the given **widget**.
        """
        ...

    def minimumHeightForWidth(self, a0: int) -> int:
        ...

    def controlTypes(self) -> "QSizePolicy.ControlType":
        """
        https://doc.qt.io/qt-6/qwidgetitem.html#controlTypes

        **[override virtual] QSizePolicy::ControlTypes
        QWidgetItem::controlTypes() const**

        Reimplements: **QLayoutItem::controlTypes() const** .

        Returns the control type associated with the widget for which this size
        policy applies.

        **See also** **QSizePolicy::controlType** ().
        """
        ...

    def heightForWidth(self, a0: int) -> int:
        """
        https://doc.qt.io/qt-6/qwidgetitem.html#heightForWidth

        **[override virtual] int QWidgetItem::heightForWidth(int w ) const**

        Reimplements: **QLayoutItem::heightForWidth(int) const** .
        """
        ...

    def hasHeightForWidth(self) -> bool:
        """
        https://doc.qt.io/qt-6/qwidgetitem.html#hasHeightForWidth

        **[override virtual] bool QWidgetItem::hasHeightForWidth() const**

        Reimplements: **QLayoutItem::hasHeightForWidth() const** .
        """
        ...

    def widget(self) -> QWidget:
        """
        https://doc.qt.io/qt-6/qwidgetitem.html#widget

        **[override virtual] QWidget *QWidgetItem::widget() const**

        Reimplements: **QLayoutItem::widget() const** .

        Returns the widget managed by this item.
        """
        ...

    def geometry(self) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qwidgetitem.html#geometry

        **[override virtual] QRect QWidgetItem::geometry() const**

        Reimplements: **QLayoutItem::geometry() const** .

        **See also** **setGeometry** ().
        """
        ...

    def setGeometry(self, a0: QtCore.QRect) -> None:
        """
        https://doc.qt.io/qt-6/qwidgetitem.html#setGeometry

        **[override virtual] void QWidgetItem::setGeometry(const QRect & rect
        )**

        Reimplements: **QLayoutItem::setGeometry** (const QRect &r).

        **See also** **geometry** ().
        """
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qwidgetitem.html#isEmpty

        **[override virtual] bool QWidgetItem::isEmpty() const**

        Reimplements: **QLayoutItem::isEmpty() const** .

        Returns `true` if the widget is hidden; otherwise returns `false`.

        **See also** **QWidget::isHidden** ().
        """
        ...

    def expandingDirections(self) -> QtCore.Qt.Orientation:
        """
        https://doc.qt.io/qt-6/qwidgetitem.html#expandingDirections

        **[override virtual] Qt::Orientations QWidgetItem::expandingDirections()
        const**

        Reimplements: **QLayoutItem::expandingDirections() const** .
        """
        ...

    def maximumSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qwidgetitem.html#maximumSize

        **[override virtual] QSize QWidgetItem::maximumSize() const**

        Reimplements: **QLayoutItem::maximumSize() const** .
        """
        ...

    def minimumSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qwidgetitem.html#minimumSize

        **[override virtual] QSize QWidgetItem::minimumSize() const**

        Reimplements: **QLayoutItem::minimumSize() const** .
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qwidgetitem.html#sizeHint

        **[override virtual] QSize QWidgetItem::sizeHint() const**

        Reimplements: **QLayoutItem::sizeHint() const** .
        """
        ...
