"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QStyleOptionHeaderV2(QStyleOptionHeader):
    """
    https://doc.qt.io/qt-6/qstyleoptionheaderv2.html

    **Detailed Description**
    """

    class StyleOptionVersion(enum.Enum):
        Version: QStyleOptionHeaderV2 = ...

    class StyleOptionType(enum.Enum):
        Type: QStyleOptionHeaderV2 = ...

    isSectionDragTarget: bool = ...
    textElideMode: QtCore = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qstyleoptionheaderv2.html#QStyleOptionHeaderV2

        **QStyleOptionHeaderV2::QStyleOptionHeaderV2()**

        Constructs a QStyleOptionHeaderV2, initializing the members variables to
        their default values.
        """
        ...

    @typing.overload
    def __init__(self, other: "QStyleOptionHeaderV2") -> None:
        """
        https://doc.qt.io/qt-6/qstyleoptionheaderv2.html#QStyleOptionHeaderV2

        **QStyleOptionHeaderV2::QStyleOptionHeaderV2()**

        Constructs a QStyleOptionHeaderV2, initializing the members variables to
        their default values.
        """
        ...
