"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from typing import Union, overload
from PyQt6.sip import *


class voidptr:
    def __init__(
        addr: Union[int, Buffer], size: int = -1, writeable: bool = True
    ) -> None:
        ...

    def __int__(self) -> int:
        ...

    @overload
    def __getitem__(self, i: int) -> bytes:
        ...

    @overload
    def __getitem__(self, s: slice) -> voidptr:
        ...

    def __hex__(self) -> str:
        ...

    def __len__(self) -> int:
        ...

    def __setitem__(self, i: Union[int, slice], v: Buffer) -> None:
        ...

    def asarray(self, size: int = -1) -> array:
        ...

    def asstring(self, size: int = -1) -> bytes:
        ...

    def getsize(self) -> int:
        ...

    def getwriteable(self) -> bool:
        ...

    def setsize(self, size: int) -> None:
        ...

    def setwriteable(self, bool) -> None:
        ...
