"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtSensors import *


class QMagnetometer(QSensor):
    """
    https://doc.qt.io/qt-6/qmagnetometer.html

    **Detailed Description**

    The only behavioural difference is that this class sets the type properly.

    This class also features a **reading** () function that returns a
    **QMagnetometerReading**  instead of a **QSensorReading** .

    For details about how the sensor works, see **QMagnetometerReading** .

    **See also** **QMagnetometerReading** .
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qmagnetometer.html#QMagnetometer

        **QMagnetometer::QMagnetometer(QObject * parent = nullptr)**

        Construct the sensor as a child of **parent**.
        """
        ...

    def setReturnGeoValues(self, returnGeoValues: bool) -> None:
        """
        https://doc.qt.io/qt-6/qmagnetometer.html#returnGeoValues-prop

        **returnGeoValues : bool**

        This property holds a value indicating if geomagnetic values should be
        returned.

        Set to true to return geomagnetic flux density. Set to false (the
        default) to return raw magnetic flux density.

        The property must be set before calling **start** ().

        **Access functions:**

        bool **returnGeoValues** () const
        void **setReturnGeoValues** (bool
        **returnGeoValues** )

        **Notifier signal:**

        void **returnGeoValuesChanged** (bool **returnGeoValues** )

        **Member Function Documentation**
        """
        ...

    def returnGeoValues(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmagnetometer.html#returnGeoValues-prop

        **returnGeoValues : bool**

        This property holds a value indicating if geomagnetic values should be
        returned.

        Set to true to return geomagnetic flux density. Set to false (the
        default) to return raw magnetic flux density.

        The property must be set before calling **start** ().

        **Access functions:**

        bool **returnGeoValues** () const
        void **setReturnGeoValues** (bool
        **returnGeoValues** )

        **Notifier signal:**

        void **returnGeoValuesChanged** (bool **returnGeoValues** )

        **Member Function Documentation**
        """
        ...

    def reading(self) -> QMagnetometerReading:
        """
        https://doc.qt.io/qt-6/qmagnetometer.html#reading

        **QMagnetometerReading *QMagnetometer::reading() const**

        Returns the reading class for this sensor.

        **See also** **QSensor::reading** ().
        """
        ...

    @property
    def returnGeoValuesChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...
