"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from typing import TypeVar, Union
from PyQt6.sip import *

SIP_VERSION: int = ...
SIP_VERSION_STR: str = ...
T = TypeVar("T")
Buffer = Union[bytes, bytearray, memoryview, array, voidptr]


def assign(obj: simplewrapper, other: simplewrapper) -> None:
    ...


def cast(obj: simplewrapper, type: wrappertype) -> simplewrapper:
    ...


def delete(obj: simplewrapper) -> None:
    ...


def dump(obj: simplewrapper) -> None:
    ...


def enableautoconversion(type: wrappertype, enable: bool) -> bool:
    ...


def isdeleted(obj: simplewrapper) -> bool:
    ...


def ispycreated(obj: simplewrapper) -> bool:
    ...


def ispyowned(obj: simplewrapper) -> bool:
    ...


def setdeleted(obj: simplewrapper) -> None:
    ...


def settracemask(mask: int) -> None:
    ...


def transferback(obj: wrapper) -> None:
    ...


def transferto(obj: wrapper, owner: wrapper) -> None:
    ...


def unwrapinstance(obj: simplewrapper) -> None:
    ...


def wrapinstance(addr: int, type: wrappertype) -> simplewrapper:
    ...
