"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6.QtCore import *


class QDynamicPropertyChangeEvent(QEvent):
    """
    https://doc.qt.io/qt-6/qdynamicpropertychangeevent.html

    **Detailed Description**

    Dynamic property change events are sent to objects when properties are
    dynamically added, changed or removed using **QObject::setProperty** ().
    """

    def __init__(self, name: QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qdynamicpropertychangeevent.html#QDynamicProperty
        ChangeEvent-2

        **QDynamicPropertyChangeEvent::QDynamicPropertyChangeEvent(const
        QByteArray & name )**

        Constructs a dynamic property change event object with the property name
        set to **name**.
        """
        ...

    def clone(self) -> "QDynamicPropertyChangeEvent":
        ...

    def propertyName(self) -> QByteArray:
        """
        https://doc.qt.io/qt-6/qdynamicpropertychangeevent.html#propertyName

        **QByteArray QDynamicPropertyChangeEvent::propertyName() const**

        Returns the name of the dynamic property that was added, changed or
        removed.

        **See also** **QObject::setProperty** () and
        **QObject::dynamicPropertyNames** ().
        """
        ...
