"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QTextBlockUserData(PyQt6.sip.wrapper):
    """
    https://doc.qt.io/qt-6/qtextblockuserdata.html

    **Detailed Description**

    QTextBlockUserData provides an abstract interface for container classes that
    are used to associate application-specific user data with text blocks in a
    **QTextDocument** .

    Generally, subclasses of this class provide functions to allow data to be
    stored and retrieved, and instances are attached to blocks of text using
    **QTextBlock::setUserData** (). This makes it possible to store additional
    data per text block in a way that can be retrieved safely by the
    application.

    Each subclass should provide a reimplementation of the destructor to ensure
    that any private data is automatically cleaned up when user data objects are
    deleted.

    **See also** **QTextBlock** .
    """

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QTextBlockUserData") -> None:
        ...
