"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import PyQt6.sip


class QMessageLogContext(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qmessagelogcontext.html

    **Detailed Description**

    The class provides information about the source code location a **qDebug**
    (), **qInfo** (), **qWarning** (), **qCritical** () or **qFatal** () message
    was generated.

    **Note:** By default, this information is recorded only in debug builds. You
    can overwrite this explicitly by defining `QT_MESSAGELOGCONTEXT` or
    `QT_NO_MESSAGELOGCONTEXT`.

    **See also** **QMessageLogger** , **QtMessageHandler** , and
    **qInstallMessageHandler** ().
    """

    category: str = ...
    file: str = ...
    function: str = ...
    line: int = ...
