"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore


class QFileIconProvider(QtGui.QAbstractFileIconProvider):
    """
    https://doc.qt.io/qt-6/qfileiconprovider.html

    **Detailed Description**
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qfileiconprovider.html#QFileIconProvider

        **QFileIconProvider::QFileIconProvider()**

        Constructs a file icon provider.
        """
        ...

    @typing.overload
    def icon(self, type: QtGui.QAbstractFileIconProvider.IconType) -> QtGui.QIcon:
        """
        https://doc.qt.io/qt-6/qfileiconprovider.html#icon

        **[override virtual] QIcon
        QFileIconProvider::icon(QAbstractFileIconProvider::IconType type )
        const**

        Reimplements:
        **QAbstractFileIconProvider::icon(QAbstractFileIconProvider::IconType
        type) const** .
        """
        ...

    @typing.overload
    def icon(self, info: QtCore.QFileInfo) -> QtGui.QIcon:
        """
        https://doc.qt.io/qt-6/qfileiconprovider.html#icon-1

        **[override virtual] QIcon QFileIconProvider::icon(const QFileInfo &
        info ) const**

        Reimplements: **QAbstractFileIconProvider::icon(const QFileInfo &info)
        const** .
        """
        ...
