"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QStyleOptionSlider(QStyleOptionComplex):
    """
    https://doc.qt.io/qt-6/qstyleoptionslider.html

    **Detailed Description**

    QStyleOptionSlider contains all the information that **QStyle**  functions
    need to draw **QSlider**  and **QScrollBar** .

    For performance reasons, there are few member functions and the access to
    the member variables is direct (i.e., using the `.` or `->` operator). This
    makes the structures straightforward to use and emphasizes that these are
    simply parameters used by the style functions.

    For an example demonstrating how style options can be used, see the
    **Styles**  example.

    **See also** **QStyleOptionComplex** , **QSlider** , and **QScrollBar** .
    """

    class StyleOptionVersion(enum.Enum):
        Version: QStyleOptionSlider = ...

    class StyleOptionType(enum.Enum):
        Type: QStyleOptionSlider = ...

    dialWrapping: bool = ...
    keyboardModifiers: QtCore = ...
    maximum: int = ...
    minimum: int = ...
    notchTarget: float = ...
    orientation: QtCore = ...
    pageStep: int = ...
    singleStep: int = ...
    sliderPosition: int = ...
    sliderValue: int = ...
    tickInterval: int = ...
    tickPosition: QSlider = ...
    upsideDown: bool = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qstyleoptionslider.html#QStyleOptionSlider

        **QStyleOptionSlider::QStyleOptionSlider()**

        Constructs a QStyleOptionSlider, initializing the members variables to
        their default values.
        """
        ...

    @typing.overload
    def __init__(self, other: "QStyleOptionSlider") -> None:
        """
        https://doc.qt.io/qt-6/qstyleoptionslider.html#QStyleOptionSlider-1

        **QStyleOptionSlider::QStyleOptionSlider(const QStyleOptionSlider &
        other )**

        Constructs a copy of the **other** style option.
        """
        ...
