"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QStyleOptionGraphicsItem(QStyleOption):
    """
    https://doc.qt.io/qt-6/qstyleoptiongraphicsitem.html

    **Detailed Description**

    For performance reasons, there are few member functions and the access to
    the member variables is direct (i.e., using the `.` or `->` operator). This
    makes the structures straightforward to use and emphasizes that these are
    simply parameters used by the style functions.

    For an example demonstrating how style options can be used, see the
    **Styles**  example.

    **See also** **QStyleOption**  and **QGraphicsItem::paint** ().
    """

    class StyleOptionVersion(enum.Enum):
        Version: QStyleOptionGraphicsItem = ...

    class StyleOptionType(enum.Enum):
        Type: QStyleOptionGraphicsItem = ...

    exposedRect: QtCore = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qstyleoptiongraphicsitem.html#QStyleOptionGraphic
        sItem

        **QStyleOptionGraphicsItem::QStyleOptionGraphicsItem()**

        Constructs a QStyleOptionGraphicsItem.
        """
        ...

    @typing.overload
    def __init__(self, other: "QStyleOptionGraphicsItem") -> None:
        """
        https://doc.qt.io/qt-6/qstyleoptiongraphicsitem.html#QStyleOptionGraphic
        sItem-1

        **QStyleOptionGraphicsItem::QStyleOptionGraphicsItem(const
        QStyleOptionGraphicsItem & other )**

        Constructs a copy of **other**.
        """
        ...

    @staticmethod
    def levelOfDetailFromTransform(worldTransform: QtGui.QTransform) -> float:
        """
        https://doc.qt.io/qt-6/qstyleoptiongraphicsitem.html#levelOfDetailFromTr
        ansform

        **[static] qreal
        QStyleOptionGraphicsItem::levelOfDetailFromTransform(const QTransform &
        worldTransform )**

        Returns the level of detail from the **worldTransform**.

        Its value represents the maximum value of the height and width of a
        unity rectangle, mapped using the **worldTransform** of the painter used
        to draw the item. By default, if no transformations are applied, its
        value is 1. If zoomed out 1:2, the level of detail will be 0.5, and if
        zoomed in 2:1, its value is 2.

        **See also** **QGraphicsScene::minimumRenderSize** ().
        """
        ...
