"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QDBusObjectPath(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdbusobjectpath.html

    **Detailed Description**

    **See also** **The Qt D-Bus Type System** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdbusobjectpath.html#QDBusObjectPath

        **QDBusObjectPath::QDBusObjectPath()**

        Constructs a new object path.
        """
        ...

    @typing.overload
    def __init__(self, objectPath: str) -> None:
        """
        https://doc.qt.io/qt-6/qdbusobjectpath.html#QDBusObjectPath-1

        **QDBusObjectPath::QDBusObjectPath(const char * path )**

        Constructs a new object path from the given **path**.

        **See also** **setPath** ().
        """
        ...

    @typing.overload
    def __init__(self, a0: "QDBusObjectPath") -> None:
        """
        https://doc.qt.io/qt-6/qdbusobjectpath.html#QDBusObjectPath-2

        **QDBusObjectPath::QDBusObjectPath(QLatin1String path )**

        Constructs a new object path from the given **path**.
        """
        ...

    def swap(self, other: "QDBusObjectPath") -> None:
        """
        https://doc.qt.io/qt-6/qdbusobjectpath.html#swap

        **void QDBusObjectPath::swap(QDBusObjectPath & other )**

        Swaps this **QDBusObjectPath**  instance with **other**.
        """
        ...

    def __hash__(self) -> int:
        ...

    def setPath(self, objectPath: str) -> None:
        """
        https://doc.qt.io/qt-6/qdbusobjectpath.html#setPath

        **void QDBusObjectPath::setPath(const QString & path )**

        Assigns the value of the given **path** to this object path.

        **See also** **path** ().
        """
        ...

    def path(self) -> str:
        """
        https://doc.qt.io/qt-6/qdbusobjectpath.html#path

        **QString QDBusObjectPath::path() const**

        Returns this object path.

        **See also** **setPath** ().
        """
        ...
