"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore


class QShowEvent(QtCore.QEvent):
    """
    https://doc.qt.io/qt-6/qshowevent.html

    **Detailed Description**

    There are two kinds of show events: show events caused by the window system
    (spontaneous), and internal show events. Spontaneous
    (**QEvent::spontaneous** ()) show events are sent just after the window
    system shows the window; they are also sent when a top-level window is
    redisplayed after being iconified. Internal show events are delivered just
    before the widget becomes visible.

    **See also** **QHideEvent** .
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qshowevent.html#QShowEvent-2

        **QShowEvent::QShowEvent()**

        Constructs a QShowEvent.
        """
        ...
