"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QPanGesture(QGesture):
    """
    https://doc.qt.io/qt-6/qpangesture.html

    **Detailed Description**

    ![](images/pangesture.png)

    For an overview of gesture handling in Qt and information on using gestures
    in your applications, see the **Gestures in Widgets and Graphics View**
    document.

    **See also** **QPinchGesture**  and **QSwipeGesture** .
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        ...

    def setAcceleration(self, value: float) -> None:
        """
        https://doc.qt.io/qt-6/qpangesture.html#acceleration-prop

        **acceleration : qreal**

        This property holds the acceleration in the motion of the touch point
        for this gesture

        **Access functions:**

        qreal **acceleration** () const
        void **setAcceleration** (qreal
        **value** )
        """
        ...

    def setOffset(self, value: QtCore.QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qpangesture.html#offset-prop

        **offset : QPointF**

        This property holds the total offset from the first input position to
        the current input position

        The offset measures the total change in position of the user's input
        covered by the gesture on the input device.

        **Access functions:**

        QPointF **offset** () const
        void **setOffset** (const QPointF &
        **value** )

        **Member Function Documentation**
        """
        ...

    def setLastOffset(self, value: QtCore.QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qpangesture.html#lastOffset-prop

        **lastOffset : QPointF**

        This property holds the last offset recorded for this gesture

        The last offset contains the change in position of the user's input as
        reported in the **offset**  property when a previous gesture event was
        delivered for this gesture.

        If no previous event was delivered with information about this gesture
        (i.e., this gesture object contains information about the first movement
        in the gesture) then this property contains a zero size.

        **Access functions:**

        QPointF **lastOffset** () const
        void **setLastOffset** (const QPointF
        & **value** )
        """
        ...

    def acceleration(self) -> float:
        """
        https://doc.qt.io/qt-6/qpangesture.html#acceleration-prop

        **acceleration : qreal**

        This property holds the acceleration in the motion of the touch point
        for this gesture

        **Access functions:**

        qreal **acceleration** () const
        void **setAcceleration** (qreal
        **value** )
        """
        ...

    def delta(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qpangesture.html#delta-prop

        **[read-only] delta : const QPointF**

        This property holds the offset from the previous input position to the
        current input

        This is essentially the same as the difference between **offset** () and
        **lastOffset** ().

        **Access functions:**

        QPointF **delta** () const
        """
        ...

    def offset(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qpangesture.html#offset-prop

        **offset : QPointF**

        This property holds the total offset from the first input position to
        the current input position

        The offset measures the total change in position of the user's input
        covered by the gesture on the input device.

        **Access functions:**

        QPointF **offset** () const
        void **setOffset** (const QPointF &
        **value** )

        **Member Function Documentation**
        """
        ...

    def lastOffset(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qpangesture.html#lastOffset-prop

        **lastOffset : QPointF**

        This property holds the last offset recorded for this gesture

        The last offset contains the change in position of the user's input as
        reported in the **offset**  property when a previous gesture event was
        delivered for this gesture.

        If no previous event was delivered with information about this gesture
        (i.e., this gesture object contains information about the first movement
        in the gesture) then this property contains a zero size.

        **Access functions:**

        QPointF **lastOffset** () const
        void **setLastOffset** (const QPointF
        & **value** )
        """
        ...
