"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import PyQt6.sip
from PyQt6 import QtCore


class QHelpContentItem(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qhelpcontentitem.html

    **Detailed Description**
    """

    def childPosition(self, child: "QHelpContentItem") -> int:
        """
        https://doc.qt.io/qt-6/qhelpcontentitem.html#childPosition

        **int QHelpContentItem::childPosition(QHelpContentItem * child ) const**

        Returns the position of a given **child**.
        """
        ...

    def parent(self) -> "QHelpContentItem":
        """
        https://doc.qt.io/qt-6/qhelpcontentitem.html#parent

        **QHelpContentItem *QHelpContentItem::parent() const**

        Returns the parent content item.
        """
        ...

    def row(self) -> int:
        """
        https://doc.qt.io/qt-6/qhelpcontentitem.html#row

        **int QHelpContentItem::row() const**

        Returns the row of this item from its parents view.
        """
        ...

    def url(self) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qhelpcontentitem.html#url

        **QUrl QHelpContentItem::url() const**

        Returns the URL of this content item.
        """
        ...

    def title(self) -> str:
        """
        https://doc.qt.io/qt-6/qhelpcontentitem.html#title

        **QString QHelpContentItem::title() const**

        Returns the title of the content item.
        """
        ...

    def childCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qhelpcontentitem.html#childCount

        **int QHelpContentItem::childCount() const**

        Returns the number of child items.
        """
        ...

    def child(self, row: int) -> "QHelpContentItem":
        """
        https://doc.qt.io/qt-6/qhelpcontentitem.html#child

        **QHelpContentItem *QHelpContentItem::child(int row ) const**

        Returns the child of the content item in the give **row**.

        **See also** **parent** ().
        """
        ...
