"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QDBusSignature(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdbussignature.html

    **Detailed Description**

    **See also** **The Qt D-Bus Type System** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdbussignature.html#QDBusSignature

        **QDBusSignature::QDBusSignature()**

        Constructs a new signature.

        **See also** **setSignature** ().
        """
        ...

    @typing.overload
    def __init__(self, dBusSignature: str) -> None:
        """
        https://doc.qt.io/qt-6/qdbussignature.html#QDBusSignature-1

        **QDBusSignature::QDBusSignature(const char * signature )**

        Constructs a new signature from the given **signature**.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QDBusSignature") -> None:
        """
        https://doc.qt.io/qt-6/qdbussignature.html#QDBusSignature-2

        **QDBusSignature::QDBusSignature(QLatin1String signature )**

        Constructs a new signature from the given **signature**.
        """
        ...

    def swap(self, other: "QDBusSignature") -> None:
        """
        https://doc.qt.io/qt-6/qdbussignature.html#swap

        **void QDBusSignature::swap(QDBusSignature & other )**

        Swaps this **QDBusSignature**  instance with **other**.
        """
        ...

    def __hash__(self) -> int:
        ...

    def setSignature(self, dBusSignature: str) -> None:
        """
        https://doc.qt.io/qt-6/qdbussignature.html#setSignature

        **void QDBusSignature::setSignature(const QString & signature )**

        Assigns the value of the given **signature** to this signature.

        **See also** **signature** ().
        """
        ...

    def signature(self) -> str:
        """
        https://doc.qt.io/qt-6/qdbussignature.html#signature

        **QString QDBusSignature::signature() const**

        Returns this signature.

        **See also** **setSignature** ().
        """
        ...
