"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
from PyQt6.QtNetwork import *
import enum


class QOcspRevocationReason(enum.Enum):
    None_: QOcspRevocationReason = ...
    Unspecified: QOcspRevocationReason = ...
    KeyCompromise: QOcspRevocationReason = ...
    CACompromise: QOcspRevocationReason = ...
    AffiliationChanged: QOcspRevocationReason = ...
    Superseded: QOcspRevocationReason = ...
    CessationOfOperation: QOcspRevocationReason = ...
    CertificateHold: QOcspRevocationReason = ...
    RemoveFromCRL: QOcspRevocationReason = ...
