"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import PyQt6.sip
from PyQt6.QtWebSockets import *
import enum


class QWebSocketProtocol(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qwebsocketprotocol.html

    **Detailed Description**
    """

    class CloseCode(enum.Enum):
        CloseCodeNormal: QWebSocketProtocol = ...
        CloseCodeGoingAway: QWebSocketProtocol = ...
        CloseCodeProtocolError: QWebSocketProtocol = ...
        CloseCodeDatatypeNotSupported: QWebSocketProtocol = ...
        CloseCodeReserved1004: QWebSocketProtocol = ...
        CloseCodeMissingStatusCode: QWebSocketProtocol = ...
        CloseCodeAbnormalDisconnection: QWebSocketProtocol = ...
        CloseCodeWrongDatatype: QWebSocketProtocol = ...
        CloseCodePolicyViolated: QWebSocketProtocol = ...
        CloseCodeTooMuchData: QWebSocketProtocol = ...
        CloseCodeMissingExtension: QWebSocketProtocol = ...
        CloseCodeBadOperation: QWebSocketProtocol = ...
        CloseCodeTlsHandshakeFailed: QWebSocketProtocol = ...

    class Version(enum.Enum):
        VersionUnknown: QWebSocketProtocol = ...
        Version0: QWebSocketProtocol = ...
        Version4: QWebSocketProtocol = ...
        Version5: QWebSocketProtocol = ...
        Version6: QWebSocketProtocol = ...
        Version7: QWebSocketProtocol = ...
        Version8: QWebSocketProtocol = ...
        Version13: QWebSocketProtocol = ...
        VersionLatest: QWebSocketProtocol = ...
