"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QOpenGLContextGroup(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qopenglcontextgroup.html

    **Detailed Description**

    QOpenGLContextGroup is automatically created and managed by
    **QOpenGLContext**  instances. Its purpose is to identify all the contexts
    that are sharing resources.

    **See also** **QOpenGLContext::shareGroup** ().
    """

    @staticmethod
    def currentContextGroup() -> "QOpenGLContextGroup":
        """
        https://doc.qt.io/qt-6/qopenglcontextgroup.html#currentContextGroup

        **[static] QOpenGLContextGroup
        *QOpenGLContextGroup::currentContextGroup()**

        Returns the **QOpenGLContextGroup**  corresponding to the current
        context.

        **See also** **QOpenGLContext::currentContext** ().
        """
        ...

    def shares(self) -> typing.List["QOpenGLContext"]:
        """
        https://doc.qt.io/qt-6/qopenglcontextgroup.html#shares

        **QList<QOpenGLContext *> QOpenGLContextGroup::shares() const**

        Returns all the **QOpenGLContext**  objects in this share group.
        """
        ...
