"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6.QtSensors import *


class QLightReading(QSensorReading):
    """
    https://doc.qt.io/qt-6/qlightreading.html

    **Detailed Description**

    **QLightReading Units**

    The light sensor returns the intensity of the light in lux.
    """

    def setLux(self, lux: float) -> None:
        """
        https://doc.qt.io/qt-6/qlightreading.html#setLux

        **void QLightReading::setLux(qreal lux )**

        Sets the light level to **lux**.

        **See also** **lux** ().
        """
        ...

    def lux(self) -> float:
        """
        https://doc.qt.io/qt-6/qlightreading.html#lux-prop

        **[read-only] lux : const qreal**

        This property holds the light level.

        Measured as lux.

        **Access functions:**

        qreal **lux** () const

        **See also** **QLightReading Units** .

        **Member Function Documentation**
        """
        ...
