"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6.QtSensors import *


class QLidReading(QSensorReading):
    def frontLidChanged(self, closed: bool) -> None:
        ...

    def backLidChanged(self, closed: bool) -> None:
        ...

    def setFrontLidClosed(self, closed: bool) -> None:
        ...

    def frontLidClosed(self) -> bool:
        ...

    def setBackLidClosed(self, closed: bool) -> None:
        ...

    def backLidClosed(self) -> bool:
        ...
