"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore


class QDragLeaveEvent(QtCore.QEvent):
    """
    https://doc.qt.io/qt-6/qdragleaveevent.html

    **Detailed Description**

    This event is always preceded by a **QDragEnterEvent**  and a series of
    **QDragMoveEvent** s. It is not sent if a **QDropEvent**  is sent instead.

    **See also** **QDragEnterEvent** , **QDragMoveEvent** , and **QDropEvent** .
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdragleaveevent.html#QDragLeaveEvent-2

        **QDragLeaveEvent::QDragLeaveEvent()**

        Constructs a QDragLeaveEvent.

        **Warning:** Do not create a QDragLeaveEvent yourself since these
        objects rely on Qt's internal state.
        """
        ...
