"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore


class QWhatsThisClickedEvent(QtCore.QEvent):
    """
    https://doc.qt.io/qt-6/qwhatsthisclickedevent.html

    **Detailed Description**

    **See also** **QWhatsThis** , **QHelpEvent** , and **QStatusTipEvent** .
    """

    def __init__(self, href: str) -> None:
        """
        https://doc.qt.io/qt-6/qwhatsthisclickedevent.html#QWhatsThisClickedEven
        t-2

        **QWhatsThisClickedEvent::QWhatsThisClickedEvent(const QString & href
        )**

        Constructs an event containing a URL specified by **href** when a link
        is clicked in a "What's This?" message.

        **See also** **href** ().
        """
        ...

    def clone(self) -> "QWhatsThisClickedEvent":
        ...

    def href(self) -> str:
        """
        https://doc.qt.io/qt-6/qwhatsthisclickedevent.html#href

        **QString QWhatsThisClickedEvent::href() const**

        Returns the URL that was clicked by the user in the "What's This?" text.
        """
        ...
