"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
from PyQt6 import QtCore
from PyQt6.QtQml import *
import enum


class QQmlImageProviderBase(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qqmlimageproviderbase.html

    **Detailed Description**

    Image providers must be registered with the QML engine. The only information
    the QML engine knows about image providers is the type of image data they
    provide. To use an image provider to acquire image data, you must cast the
    QQmlImageProviderBase pointer to a **QQuickImageProvider**  pointer.

    **See also** **QQuickImageProvider**  and **QQuickTextureFactory** .
    """

    class Flag(enum.Flag):
        ForceAsynchronousImageLoading: QQmlImageProviderBase = ...

    class ImageType(enum.Enum):
        Image: QQmlImageProviderBase = ...
        Pixmap: QQmlImageProviderBase = ...
        Texture: QQmlImageProviderBase = ...
        ImageResponse: QQmlImageProviderBase = ...

    def flags(self) -> "QQmlImageProviderBase.Flag":
        """
        https://doc.qt.io/qt-6/qqmlimageproviderbase.html#flags

        **[pure virtual] QQmlImageProviderBase::Flags
        QQmlImageProviderBase::flags() const**

        Implement this to return the properties of this image provider.
        """
        ...

    def imageType(self) -> "QQmlImageProviderBase.ImageType":
        """
        https://doc.qt.io/qt-6/qqmlimageproviderbase.html#imageType

        **[pure virtual] QQmlImageProviderBase::ImageType
        QQmlImageProviderBase::imageType() const**

        Implement this method to return the image type supported by this image
        provider.
        """
        ...
