"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore


class QDnsTextRecord(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdnstextrecord.html

    **Detailed Description**

    When performing a text lookup, zero or more records will be returned. Each
    record is represented by a QDnsTextRecord instance.

    The meaning of the fields is defined in **RFC 1035** .

    **See also** **QDnsLookup** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdnstextrecord.html#QDnsTextRecord

        **QDnsTextRecord::QDnsTextRecord()**

        Constructs an empty text record object.
        """
        ...

    @typing.overload
    def __init__(self, other: "QDnsTextRecord") -> None:
        """
        https://doc.qt.io/qt-6/qdnstextrecord.html#QDnsTextRecord-1

        **QDnsTextRecord::QDnsTextRecord(const QDnsTextRecord & other )**

        Constructs a copy of **other**.
        """
        ...

    def values(self) -> typing.List[QtCore.QByteArray]:
        """
        https://doc.qt.io/qt-6/qdnstextrecord.html#values

        **QList<QByteArray> QDnsTextRecord::values() const**

        Returns the values for this text record.
        """
        ...

    def timeToLive(self) -> int:
        """
        https://doc.qt.io/qt-6/qdnstextrecord.html#timeToLive

        **quint32 QDnsTextRecord::timeToLive() const**

        Returns the duration in seconds for which this record is valid.
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qdnstextrecord.html#name

        **QString QDnsTextRecord::name() const**

        Returns the name for this text record.
        """
        ...

    def swap(self, other: "QDnsTextRecord") -> None:
        """
        https://doc.qt.io/qt-6/qdnstextrecord.html#swap

        **void QDnsTextRecord::swap(QDnsTextRecord & other )**

        Swaps this text record instance with **other**. This function is very
        fast and never fails.
        """
        ...
