"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtQuick import *


class QSGRectangleNode(QSGGeometryNode):
    """
    https://doc.qt.io/qt-6/qsgrectanglenode.html

    **Detailed Description**
    """

    def color(self) -> QtGui.QColor:
        """
        https://doc.qt.io/qt-6/qsgrectanglenode.html#color

        **[pure virtual] QColor QSGRectangleNode::color() const**

        Returns the color of this rectangle.

        **See also** **setColor** ().
        """
        ...

    def setColor(
        self, color: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor, int]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsgrectanglenode.html#setColor

        **[pure virtual] void QSGRectangleNode::setColor(const QColor & color
        )**

        Sets the color of this rectangle to **color**. The default color will be
        white.

        **See also** **color** ().
        """
        ...

    def rect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qsgrectanglenode.html#rect

        **[pure virtual] QRectF QSGRectangleNode::rect() const**

        Returns the rectangle that this rect node covers.

        **See also** **setRect** ().
        """
        ...

    @typing.overload
    def setRect(self, rect: QtCore.QRectF) -> None:
        """
        https://doc.qt.io/qt-6/qsgrectanglenode.html#setRect

        **[pure virtual] void QSGRectangleNode::setRect(const QRectF & rect )**

        Sets the rectangle of this rect node to **rect**.

        **See also** **rect** ().
        """
        ...

    @typing.overload
    def setRect(self, x: float, y: float, w: float, h: float) -> None:
        """
        https://doc.qt.io/qt-6/qsgrectanglenode.html#setRect-1

        **void QSGRectangleNode::setRect(qreal x , qreal y , qreal w , qreal h
        )**

        This is an overloaded function.

        Sets the rectangle of this rect node to begin at ( **x** , **y** ) and
        have width **w** and height **h**.
        """
        ...
