"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtHelp import *
import enum


class QHelpSearchQuery(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qhelpsearchquery.html

    **Detailed Description**

    The QHelpSearchQuery class contains the field name and the associated search
    term. Depending on the field the search term might get split up into
    separate terms to be parsed differently by the search engine.

    **Note:** This class has been deprecated in favor of **QString** .

    **See also** **QHelpSearchQueryWidget** .
    """

    class FieldName(enum.Enum):
        DEFAULT: QHelpSearchQuery = ...
        FUZZY: QHelpSearchQuery = ...
        WITHOUT: QHelpSearchQuery = ...
        PHRASE: QHelpSearchQuery = ...
        ALL: QHelpSearchQuery = ...
        ATLEAST: QHelpSearchQuery = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qhelpsearchquery.html#QHelpSearchQuery

        **QHelpSearchQuery::QHelpSearchQuery()**

        Constructs a new empty QHelpSearchQuery.
        """
        ...

    @typing.overload
    def __init__(
        self, field: "QHelpSearchQuery.FieldName", wordList: typing.Iterable[str]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qhelpsearchquery.html#QHelpSearchQuery-1

        **QHelpSearchQuery::QHelpSearchQuery(QHelpSearchQuery::FieldName field ,
        const QStringList & wordList )**

        Constructs a new QHelpSearchQuery and initializes it with the given
        **field** and **wordList**.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QHelpSearchQuery") -> None:
        """
        https://doc.qt.io/qt-6/qhelpsearchquery.html#QHelpSearchQuery

        **QHelpSearchQuery::QHelpSearchQuery()**

        Constructs a new empty QHelpSearchQuery.
        """
        ...
