"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import PyQt6.sip
from PyQt6.QtSql import *
import enum


class QSql(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qsql.html

    **Detailed Description**

    **See also** **Qt SQL** .
    """

    class NumericalPrecisionPolicy(enum.Enum):
        LowPrecisionInt32: QSql = ...
        LowPrecisionInt64: QSql = ...
        LowPrecisionDouble: QSql = ...
        HighPrecision: QSql = ...

    class TableType(enum.Enum):
        Tables: QSql = ...
        SystemTables: QSql = ...
        Views: QSql = ...
        AllTables: QSql = ...

    class ParamTypeFlag(enum.Flag):
        In: QSql = ...
        Out: QSql = ...
        InOut: QSql = ...
        Binary: QSql = ...

    class Location(enum.Enum):
        BeforeFirstRow: QSql = ...
        AfterLastRow: QSql = ...
