"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QSizeGrip(QWidget):
    """
    https://doc.qt.io/qt-6/qsizegrip.html

    **Detailed Description**

    This widget works like the standard Windows resize handle. In the X11
    version this resize handle generally works differently from the one provided
    by the system if the X11 window manager does not support necessary modern
    post-ICCCM specifications.

    Put this widget anywhere in a widget tree and the user can use it to resize
    the top-level window or any widget with the **Qt::SubWindow**  flag set.
    Generally, this should be in the lower right-hand corner.

    Note that **QStatusBar**  already uses this widget, so if you have a status
    bar (e.g., you are using **QMainWindow** ), then you don't need to use this
    widget explicitly. The same goes for **QDialog** , for which you can just
    call **QDialog::setSizeGripEnabled** ().

    On some platforms the size grip automatically hides itself when the window
    is shown full screen or maximised.

    **Note:** On macOS, size grips are no longer part of the human interface
    guideline, and won't show unless used in a **QMdiSubWindow** . Set another
    style on size grips that you want to be visible in main windows.

    ![Screenshot of a Fusion style size grip](images/fusion-statusbar-
    sizegrip.png)A size grip widget at the bottom-right corner of a main window,
    shown in the **Fusion widget style** .

    The QSizeGrip class inherits **QWidget**  and reimplements the
    **mousePressEvent** () and **mouseMoveEvent** () functions to feature the
    resize functionality, and the **paintEvent** () function to render the size
    grip widget.

    **See also** **QStatusBar**  and **QWidget::windowState** ().
    """

    def __init__(self, parent: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qsizegrip.html#QSizeGrip

        **QSizeGrip::QSizeGrip(QWidget * parent )**

        Constructs a resize corner as a child widget of the given **parent**.
        """
        ...

    def hideEvent(self, hideEvent: QtGui.QHideEvent) -> None:
        """
        https://doc.qt.io/qt-6/qsizegrip.html#hideEvent

        **[override virtual protected] void QSizeGrip::hideEvent(QHideEvent *
        hideEvent )**

        Reimplements: **QWidget::hideEvent** (QHideEvent *event).
        """
        ...

    def showEvent(self, showEvent: QtGui.QShowEvent) -> None:
        """
        https://doc.qt.io/qt-6/qsizegrip.html#showEvent

        **[override virtual protected] void QSizeGrip::showEvent(QShowEvent *
        showEvent )**

        Reimplements: **QWidget::showEvent** (QShowEvent *event).
        """
        ...

    def moveEvent(self, moveEvent: QtGui.QMoveEvent) -> None:
        """
        https://doc.qt.io/qt-6/qsizegrip.html#moveEvent

        **[override virtual protected] void QSizeGrip::moveEvent(QMoveEvent *
        moveEvent )**

        Reimplements: **QWidget::moveEvent** (QMoveEvent *event).
        """
        ...

    def event(self, a0: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qsizegrip.html#event

        **[override virtual protected] bool QSizeGrip::event(QEvent * event )**

        Reimplements: **QWidget::event** (QEvent *event).
        """
        ...

    def eventFilter(self, a0: QtCore.QObject, a1: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qsizegrip.html#eventFilter

        **[override virtual protected] bool QSizeGrip::eventFilter(QObject * o ,
        QEvent * e )**

        Reimplements: **QObject::eventFilter** (QObject *watched, QEvent
        *event).
        """
        ...

    def mouseMoveEvent(self, a0: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qsizegrip.html#mouseMoveEvent

        **[override virtual protected] void
        QSizeGrip::mouseMoveEvent(QMouseEvent * event )**

        Reimplements: **QWidget::mouseMoveEvent** (QMouseEvent *event).

        Resizes the top-level widget containing this widget. The mouse move
        event is passed in the **event** parameter.
        """
        ...

    def mouseReleaseEvent(self, mouseEvent: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qsizegrip.html#mouseReleaseEvent

        **[override virtual protected] void
        QSizeGrip::mouseReleaseEvent(QMouseEvent * mouseEvent )**

        Reimplements: **QWidget::mouseReleaseEvent** (QMouseEvent *event).
        """
        ...

    def mousePressEvent(self, a0: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qsizegrip.html#mousePressEvent

        **[override virtual protected] void
        QSizeGrip::mousePressEvent(QMouseEvent * event )**

        Reimplements: **QWidget::mousePressEvent** (QMouseEvent *event).

        Receives the mouse press events for the widget, and primes the resize
        operation. The mouse press event is passed in the **event** parameter.
        """
        ...

    def paintEvent(self, a0: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qsizegrip.html#paintEvent

        **[override virtual protected] void QSizeGrip::paintEvent(QPaintEvent *
        event )**

        Reimplements: **QWidget::paintEvent** (QPaintEvent *event).

        Paints the resize grip.

        Resize grips are usually rendered as small diagonal textured lines in
        the lower-right corner. The paint event is passed in the **event**
        parameter.
        """
        ...

    def setVisible(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsizegrip.html#setVisible

        **[override virtual] void QSizeGrip::setVisible(bool visible )**

        Reimplements an access function for property: **QWidget::visible** .
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qsizegrip.html#sizeHint

        **[override virtual] QSize QSizeGrip::sizeHint() const**

        Reimplements an access function for property: **QWidget::sizeHint** .
        """
        ...
