"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtSensors import *


class QTiltSensor(QSensor):
    """
    https://doc.qt.io/qt-6/qtiltsensor.html

    **Detailed Description**

    The only behavioural difference is that this class sets the type properly.

    This class also features a **reading** () function that returns a
    **QTiltReading**  instead of a **QSensorReading** .

    For details about how the sensor works, see **QTiltReading** .

    **See also** **QTiltReading** .
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtiltsensor.html#QTiltSensor

        **QTiltSensor::QTiltSensor(QObject * parent = nullptr)**

        Construct the sensor as a child of **parent**.
        """
        ...

    def calibrate(self) -> None:
        """
        https://doc.qt.io/qt-6/qtiltsensor.html#calibrate

        **[invokable] void QTiltSensor::calibrate()**

        Calibrates the tilt sensor. Uses the current tilt angles as 0 degrees.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def reading(self) -> QTiltReading:
        """
        https://doc.qt.io/qt-6/qtiltsensor.html#reading

        **QTiltReading *QTiltSensor::reading() const**

        Returns the reading class for this sensor.

        **See also** **QSensor::reading** ().
        """
        ...
