"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from ._functions import PYQT_SIGNAL as PYQT_SIGNAL
from ._functions import PYQT_SLOT as PYQT_SLOT
from ._functions import qGray as qGray
from ._functions import qGray as qGray
from ._functions import qRgba as qRgba
from ._functions import qRgb as qRgb
from ._functions import qAlpha as qAlpha
from ._functions import qAlpha as qAlpha
from ._functions import qBlue as qBlue
from ._functions import qBlue as qBlue
from ._functions import qGreen as qGreen
from ._functions import qGreen as qGreen
from ._functions import qRed as qRed
from ._functions import qRed as qRed
from ._functions import qUnpremultiply as qUnpremultiply
from ._functions import qUnpremultiply as qUnpremultiply
from ._functions import qPremultiply as qPremultiply
from ._functions import qPremultiply as qPremultiply
from ._functions import qRgba64 as qRgba64
from ._functions import qRgba64 as qRgba64
from ._functions import qPixelFormatAlpha as qPixelFormatAlpha
from ._functions import qPixelFormatYuv as qPixelFormatYuv
from ._functions import qPixelFormatHsv as qPixelFormatHsv
from ._functions import qPixelFormatHsl as qPixelFormatHsl
from ._functions import qPixelFormatCmyk as qPixelFormatCmyk
from ._functions import qPixelFormatGrayscale as qPixelFormatGrayscale
from ._functions import qPixelFormatRgba as qPixelFormatRgba
from ._functions import qFuzzyCompare as qFuzzyCompare
from ._functions import qFuzzyCompare as qFuzzyCompare
from ._functions import qFuzzyCompare as qFuzzyCompare
from ._functions import qFuzzyCompare as qFuzzyCompare
from ._functions import qFuzzyCompare as qFuzzyCompare
from ._functions import qFuzzyCompare as qFuzzyCompare
from ._functions import qt_set_sequence_auto_mnemonic as qt_set_sequence_auto_mnemonic
from ._QAbstractFileIconProvider import (
    QAbstractFileIconProvider as QAbstractFileIconProvider,
)
from ._QAbstractTextDocumentLayout import (
    QAbstractTextDocumentLayout as QAbstractTextDocumentLayout,
)
from ._QTextObjectInterface import QTextObjectInterface as QTextObjectInterface
from ._QAction import QAction as QAction
from ._QActionGroup import QActionGroup as QActionGroup
from ._QBackingStore import QBackingStore as QBackingStore
from ._QPaintDevice import QPaintDevice as QPaintDevice
from ._QPixmap import QPixmap as QPixmap
from ._QBitmap import QBitmap as QBitmap
from ._QColor import QColor as QColor
from ._QColorConstants import QColorConstants as QColorConstants
from ._QBrush import QBrush as QBrush
from ._QGradient import QGradient as QGradient
from ._QLinearGradient import QLinearGradient as QLinearGradient
from ._QRadialGradient import QRadialGradient as QRadialGradient
from ._QConicalGradient import QConicalGradient as QConicalGradient
from ._QClipboard import QClipboard as QClipboard
from ._QColorSpace import QColorSpace as QColorSpace
from ._QColorTransform import QColorTransform as QColorTransform
from ._QCursor import QCursor as QCursor
from ._QDesktopServices import QDesktopServices as QDesktopServices
from ._QDrag import QDrag as QDrag
from ._QInputEvent import QInputEvent as QInputEvent
from ._QKeyEvent import QKeyEvent as QKeyEvent
from ._QFocusEvent import QFocusEvent as QFocusEvent
from ._QPaintEvent import QPaintEvent as QPaintEvent
from ._QMoveEvent import QMoveEvent as QMoveEvent
from ._QResizeEvent import QResizeEvent as QResizeEvent
from ._QCloseEvent import QCloseEvent as QCloseEvent
from ._QIconDragEvent import QIconDragEvent as QIconDragEvent
from ._QShowEvent import QShowEvent as QShowEvent
from ._QHideEvent import QHideEvent as QHideEvent
from ._QContextMenuEvent import QContextMenuEvent as QContextMenuEvent
from ._QInputMethodEvent import QInputMethodEvent as QInputMethodEvent
from ._QInputMethodQueryEvent import QInputMethodQueryEvent as QInputMethodQueryEvent
from ._QDropEvent import QDropEvent as QDropEvent
from ._QDragMoveEvent import QDragMoveEvent as QDragMoveEvent
from ._QDragEnterEvent import QDragEnterEvent as QDragEnterEvent
from ._QDragLeaveEvent import QDragLeaveEvent as QDragLeaveEvent
from ._QHelpEvent import QHelpEvent as QHelpEvent
from ._QStatusTipEvent import QStatusTipEvent as QStatusTipEvent
from ._QWhatsThisClickedEvent import QWhatsThisClickedEvent as QWhatsThisClickedEvent
from ._QActionEvent import QActionEvent as QActionEvent
from ._QFileOpenEvent import QFileOpenEvent as QFileOpenEvent
from ._QShortcutEvent import QShortcutEvent as QShortcutEvent
from ._QWindowStateChangeEvent import QWindowStateChangeEvent as QWindowStateChangeEvent
from ._QExposeEvent import QExposeEvent as QExposeEvent
from ._QScrollPrepareEvent import QScrollPrepareEvent as QScrollPrepareEvent
from ._QScrollEvent import QScrollEvent as QScrollEvent
from ._QPlatformSurfaceEvent import QPlatformSurfaceEvent as QPlatformSurfaceEvent
from ._QPointerEvent import QPointerEvent as QPointerEvent
from ._QSinglePointEvent import QSinglePointEvent as QSinglePointEvent
from ._QEnterEvent import QEnterEvent as QEnterEvent
from ._QMouseEvent import QMouseEvent as QMouseEvent
from ._QHoverEvent import QHoverEvent as QHoverEvent
from ._QWheelEvent import QWheelEvent as QWheelEvent
from ._QTabletEvent import QTabletEvent as QTabletEvent
from ._QNativeGestureEvent import QNativeGestureEvent as QNativeGestureEvent
from ._QTouchEvent import QTouchEvent as QTouchEvent
from ._QEventPoint import QEventPoint as QEventPoint
from ._QFileSystemModel import QFileSystemModel as QFileSystemModel
from ._QFont import QFont as QFont
from ._QFontDatabase import QFontDatabase as QFontDatabase
from ._QFontInfo import QFontInfo as QFontInfo
from ._QFontMetrics import QFontMetrics as QFontMetrics
from ._QFontMetricsF import QFontMetricsF as QFontMetricsF
from ._QMatrix4x3 import QMatrix4x3 as QMatrix4x3
from ._QMatrix4x2 import QMatrix4x2 as QMatrix4x2
from ._QMatrix3x4 import QMatrix3x4 as QMatrix3x4
from ._QMatrix3x3 import QMatrix3x3 as QMatrix3x3
from ._QMatrix3x2 import QMatrix3x2 as QMatrix3x2
from ._QMatrix2x4 import QMatrix2x4 as QMatrix2x4
from ._QMatrix2x3 import QMatrix2x3 as QMatrix2x3
from ._QMatrix2x2 import QMatrix2x2 as QMatrix2x2
from ._QGlyphRun import QGlyphRun as QGlyphRun
from ._QGuiApplication import QGuiApplication as QGuiApplication
from ._QIcon import QIcon as QIcon
from ._QIconEngine import QIconEngine as QIconEngine
from ._QImage import QImage as QImage
from ._QImageIOHandler import QImageIOHandler as QImageIOHandler
from ._QImageReader import QImageReader as QImageReader
from ._QImageWriter import QImageWriter as QImageWriter
from ._QInputDevice import QInputDevice as QInputDevice
from ._QInputMethod import QInputMethod as QInputMethod
from ._QKeySequence import QKeySequence as QKeySequence
from ._QMatrix4x4 import QMatrix4x4 as QMatrix4x4
from ._QMovie import QMovie as QMovie
from ._QSurface import QSurface as QSurface
from ._QOffscreenSurface import QOffscreenSurface as QOffscreenSurface
from ._QOpenGLContextGroup import QOpenGLContextGroup as QOpenGLContextGroup
from ._QOpenGLContext import QOpenGLContext as QOpenGLContext
from ._QPagedPaintDevice import QPagedPaintDevice as QPagedPaintDevice
from ._QPageLayout import QPageLayout as QPageLayout
from ._QPageRanges import QPageRanges as QPageRanges
from ._QPageSize import QPageSize as QPageSize
from ._QWindow import QWindow as QWindow
from ._QPaintDeviceWindow import QPaintDeviceWindow as QPaintDeviceWindow
from ._QTextItem import QTextItem as QTextItem
from ._QPaintEngine import QPaintEngine as QPaintEngine
from ._QPaintEngineState import QPaintEngineState as QPaintEngineState
from ._QPainter import QPainter as QPainter
from ._QPainterPath import QPainterPath as QPainterPath
from ._QPainterPathStroker import QPainterPathStroker as QPainterPathStroker
from ._QPalette import QPalette as QPalette
from ._QPdfWriter import QPdfWriter as QPdfWriter
from ._QPen import QPen as QPen
from ._QPicture import QPicture as QPicture
from ._QPixelFormat import QPixelFormat as QPixelFormat
from ._QPixmapCache import QPixmapCache as QPixmapCache
from ._QPointingDeviceUniqueId import QPointingDeviceUniqueId as QPointingDeviceUniqueId
from ._QPointingDevice import QPointingDevice as QPointingDevice
from ._QPolygon import QPolygon as QPolygon
from ._QPolygonF import QPolygonF as QPolygonF
from ._QQuaternion import QQuaternion as QQuaternion
from ._QRasterWindow import QRasterWindow as QRasterWindow
from ._QRawFont import QRawFont as QRawFont
from ._QRegion import QRegion as QRegion
from ._QRgba64 import QRgba64 as QRgba64
from ._QScreen import QScreen as QScreen
from ._QSessionManager import QSessionManager as QSessionManager
from ._QShortcut import QShortcut as QShortcut
from ._QStandardItemModel import QStandardItemModel as QStandardItemModel
from ._QStandardItem import QStandardItem as QStandardItem
from ._QStaticText import QStaticText as QStaticText
from ._QStyleHints import QStyleHints as QStyleHints
from ._QSurfaceFormat import QSurfaceFormat as QSurfaceFormat
from ._QSyntaxHighlighter import QSyntaxHighlighter as QSyntaxHighlighter
from ._QTextCursor import QTextCursor as QTextCursor
from ._QTextDocument import QTextDocument as QTextDocument
from ._QTextDocumentFragment import QTextDocumentFragment as QTextDocumentFragment
from ._QTextDocumentWriter import QTextDocumentWriter as QTextDocumentWriter
from ._QTextLength import QTextLength as QTextLength
from ._QTextFormat import QTextFormat as QTextFormat
from ._QTextCharFormat import QTextCharFormat as QTextCharFormat
from ._QTextBlockFormat import QTextBlockFormat as QTextBlockFormat
from ._QTextListFormat import QTextListFormat as QTextListFormat
from ._QTextImageFormat import QTextImageFormat as QTextImageFormat
from ._QTextFrameFormat import QTextFrameFormat as QTextFrameFormat
from ._QTextTableFormat import QTextTableFormat as QTextTableFormat
from ._QTextTableCellFormat import QTextTableCellFormat as QTextTableCellFormat
from ._QTextInlineObject import QTextInlineObject as QTextInlineObject
from ._QTextLayout import QTextLayout as QTextLayout
from ._QTextLine import QTextLine as QTextLine
from ._QTextObject import QTextObject as QTextObject
from ._QTextBlockGroup import QTextBlockGroup as QTextBlockGroup
from ._QTextList import QTextList as QTextList
from ._QTextFrame import QTextFrame as QTextFrame
from ._QTextBlock import QTextBlock as QTextBlock
from ._QTextFragment import QTextFragment as QTextFragment
from ._QTextBlockUserData import QTextBlockUserData as QTextBlockUserData
from ._QTextOption import QTextOption as QTextOption
from ._QTextTableCell import QTextTableCell as QTextTableCell
from ._QTextTable import QTextTable as QTextTable
from ._QTransform import QTransform as QTransform
from ._QUndoGroup import QUndoGroup as QUndoGroup
from ._QUndoCommand import QUndoCommand as QUndoCommand
from ._QUndoStack import QUndoStack as QUndoStack
from ._QValidator import QValidator as QValidator
from ._QIntValidator import QIntValidator as QIntValidator
from ._QDoubleValidator import QDoubleValidator as QDoubleValidator
from ._QRegularExpressionValidator import (
    QRegularExpressionValidator as QRegularExpressionValidator,
)
from ._QVector2D import QVector2D as QVector2D
from ._QVector3D import QVector3D as QVector3D
from ._QVector4D import QVector4D as QVector4D
