"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QAxObjectInterface(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qaxobjectinterface.html

    **Detailed Description**
    """

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QAxObjectInterface") -> None:
        ...

    def resetControl(self) -> None:
        """
        https://doc.qt.io/qt-6/qaxobjectinterface.html#resetControl

        **[pure virtual] void QAxObjectInterface::resetControl()**

        Disconnects and destroys the COM object.

        **See also** **QAxBaseWidget::control**  and **QAxBaseObject::control**
        .
        """
        ...

    def setControl(self, c: str) -> bool:
        """
        https://doc.qt.io/qt-6/qaxobjectinterface.html#setControl

        **[pure virtual] bool QAxObjectInterface::setControl(const QString & c
        )**

        Returns whether setting the COM object succeeded.

        Sets the name of the COM object wrapped by this **QAxBase**  object to
        **c**.

        **See also** **QAxBaseWidget::control**  and **QAxBaseObject::control**
        .
        """
        ...

    def control(self) -> str:
        """
        https://doc.qt.io/qt-6/qaxobjectinterface.html#control

        **[pure virtual] QString QAxObjectInterface::control() const**

        Returns the name of the COM object wrapped by this **QAxBase**  object.

        **See also** **setControl** (), **QAxBaseWidget::control** , and
        **QAxBaseObject::control** .
        """
        ...

    def setClassContext(self, classContext: int) -> None:
        """
        https://doc.qt.io/qt-6/qaxobjectinterface.html#setClassContext

        **[pure virtual] void QAxObjectInterface::setClassContext(ulong
        classContext )**

        Sets the context the ActiveX control will run in to **classContext**

        Affects the "dwClsContext" argument when calling CoCreateInstance. This
        can be used to control in-proc vs. out-of-proc startup for controls
        supporting both alternatives. Also, it can be used to modify/reduce
        control permissions when used with CLSCTX_ENABLE_CLOAKING and an
        impersonation token.

        Note that this function must be called before **setControl** () to have
        any effect.

        **See also** **QAxBaseWidget::classContext**  and
        **QAxBaseObject::classContext** .
        """
        ...

    def classContext(self) -> int:
        """
        https://doc.qt.io/qt-6/qaxobjectinterface.html#classContext

        **[pure virtual] ulong QAxObjectInterface::classContext() const**

        Returns the context the ActiveX control will run in (default
        CLSCTX_SERVER).

        **See also** **setClassContext** (), **QAxBaseWidget::classContext** ,
        and **QAxBaseObject::classContext** .
        """
        ...
