"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QXmlStreamEntityDeclaration(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qxmlstreamentitydeclaration.html

    **Detailed Description**

    An entity declaration consists of a **name** (), a **notationName** (), a
    **systemId** (), a **publicId** (), and a **value** ().
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamentitydeclaration.html#QXmlStreamEntity
        Declaration

        **QXmlStreamEntityDeclaration::QXmlStreamEntityDeclaration()**

        Creates an empty entity declaration.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QXmlStreamEntityDeclaration") -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamentitydeclaration.html#QXmlStreamEntity
        Declaration

        **QXmlStreamEntityDeclaration::QXmlStreamEntityDeclaration()**

        Creates an empty entity declaration.
        """
        ...

    def value(self) -> str:
        """
        https://doc.qt.io/qt-6/qxmlstreamentitydeclaration.html#value

        **QStringView QXmlStreamEntityDeclaration::value() const**

        Returns the entity's value.
        """
        ...

    def publicId(self) -> str:
        """
        https://doc.qt.io/qt-6/qxmlstreamentitydeclaration.html#publicId

        **QStringView QXmlStreamEntityDeclaration::publicId() const**

        Returns the public identifier.
        """
        ...

    def systemId(self) -> str:
        """
        https://doc.qt.io/qt-6/qxmlstreamentitydeclaration.html#systemId

        **QStringView QXmlStreamEntityDeclaration::systemId() const**

        Returns the system identifier.
        """
        ...

    def notationName(self) -> str:
        """
        https://doc.qt.io/qt-6/qxmlstreamentitydeclaration.html#notationName

        **QStringView QXmlStreamEntityDeclaration::notationName() const**

        Returns the notation name.
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qxmlstreamentitydeclaration.html#name

        **QStringView QXmlStreamEntityDeclaration::name() const**

        Returns the entity name.
        """
        ...
