"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import PyQt6.sip
from PyQt6 import QtWidgets
from PyQt6 import QtCore


class QHelpSearchResultWidget(QtWidgets.QWidget):
    """
    https://doc.qt.io/qt-6/qhelpsearchresultwidget.html

    **Detailed Description**
    """

    def linkAt(self, point: QtCore.QPoint) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qhelpsearchresultwidget.html#linkAt

        **QUrl QHelpSearchResultWidget::linkAt(const QPoint & point )**

        Returns a reference of the URL that the item at **point** owns, or an
        empty URL if no item exists at that point.
        """
        ...

    @property
    def requestShowLink(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qhelpsearchresultwidget.html#requestShowLink

        **[signal] void QHelpSearchResultWidget::requestShowLink(const QUrl &
        link )**

        This signal is emitted when a item is activated and its associated
        **link** should be shown.
        """
        ...
