"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
from PyQt6.QtCore import *
import enum


class QCborKnownTags(enum.Enum):
    DateTimeString: QCborKnownTags = ...
    UnixTime_t: QCborKnownTags = ...
    PositiveBignum: QCborKnownTags = ...
    NegativeBignum: QCborKnownTags = ...
    Decimal: QCborKnownTags = ...
    Bigfloat: QCborKnownTags = ...
    COSE_Encrypt0: QCborKnownTags = ...
    COSE_Mac0: QCborKnownTags = ...
    COSE_Sign1: QCborKnownTags = ...
    ExpectedBase64url: QCborKnownTags = ...
    ExpectedBase64: QCborKnownTags = ...
    ExpectedBase16: QCborKnownTags = ...
    EncodedCbor: QCborKnownTags = ...
    Url: QCborKnownTags = ...
    Base64url: QCborKnownTags = ...
    Base64: QCborKnownTags = ...
    RegularExpression: QCborKnownTags = ...
    MimeMessage: QCborKnownTags = ...
    Uuid: QCborKnownTags = ...
    COSE_Encrypt: QCborKnownTags = ...
    COSE_Mac: QCborKnownTags = ...
    COSE_Sign: QCborKnownTags = ...
    Signature: QCborKnownTags = ...
