"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class Qt(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qt.html

    **Detailed Description**
    """

    class HighDpiScaleFactorRoundingPolicy(enum.Enum):
        Round: Qt = ...
        Ceil: Qt = ...
        Floor: Qt = ...
        RoundPreferFloor: Qt = ...
        PassThrough: Qt = ...

    class ChecksumType(enum.Enum):
        ChecksumIso3309: Qt = ...
        ChecksumItuV41: Qt = ...

    class EnterKeyType(enum.Enum):
        EnterKeyDefault: Qt = ...
        EnterKeyReturn: Qt = ...
        EnterKeyDone: Qt = ...
        EnterKeyGo: Qt = ...
        EnterKeySend: Qt = ...
        EnterKeySearch: Qt = ...
        EnterKeyNext: Qt = ...
        EnterKeyPrevious: Qt = ...

    class ItemSelectionOperation(enum.Enum):
        ReplaceSelection: Qt = ...
        AddToSelection: Qt = ...

    class TabFocusBehavior(enum.Enum):
        NoTabFocus: Qt = ...
        TabFocusTextControls: Qt = ...
        TabFocusListControls: Qt = ...
        TabFocusAllControls: Qt = ...

    class MouseEventFlag(enum.Flag):
        MouseEventCreatedDoubleClick: Qt = ...

    class MouseEventSource(enum.Enum):
        MouseEventNotSynthesized: Qt = ...
        MouseEventSynthesizedBySystem: Qt = ...
        MouseEventSynthesizedByQt: Qt = ...
        MouseEventSynthesizedByApplication: Qt = ...

    class ScrollPhase(enum.Enum):
        ScrollBegin: Qt = ...
        ScrollUpdate: Qt = ...
        ScrollEnd: Qt = ...
        NoScrollPhase: Qt = ...
        ScrollMomentum: Qt = ...

    class NativeGestureType(enum.Enum):
        BeginNativeGesture: Qt = ...
        EndNativeGesture: Qt = ...
        PanNativeGesture: Qt = ...
        ZoomNativeGesture: Qt = ...
        SmartZoomNativeGesture: Qt = ...
        RotateNativeGesture: Qt = ...
        SwipeNativeGesture: Qt = ...

    class Edge(enum.Flag):
        TopEdge: Qt = ...
        LeftEdge: Qt = ...
        RightEdge: Qt = ...
        BottomEdge: Qt = ...

    class ApplicationState(enum.Flag):
        ApplicationSuspended: Qt = ...
        ApplicationHidden: Qt = ...
        ApplicationInactive: Qt = ...
        ApplicationActive: Qt = ...

    class HitTestAccuracy(enum.Enum):
        ExactHit: Qt = ...
        FuzzyHit: Qt = ...

    class WhiteSpaceMode(enum.Enum):
        WhiteSpaceNormal: Qt = ...
        WhiteSpacePre: Qt = ...
        WhiteSpaceNoWrap: Qt = ...
        WhiteSpaceModeUndefined: Qt = ...

    class FindChildOption(enum.Flag):
        FindDirectChildrenOnly: Qt = ...
        FindChildrenRecursively: Qt = ...

    class ScreenOrientation(enum.Flag):
        PrimaryOrientation: Qt = ...
        PortraitOrientation: Qt = ...
        LandscapeOrientation: Qt = ...
        InvertedPortraitOrientation: Qt = ...
        InvertedLandscapeOrientation: Qt = ...

    class CursorMoveStyle(enum.Enum):
        LogicalMoveStyle: Qt = ...
        VisualMoveStyle: Qt = ...

    class NavigationMode(enum.Enum):
        NavigationModeNone: Qt = ...
        NavigationModeKeypadTabOrder: Qt = ...
        NavigationModeKeypadDirectional: Qt = ...
        NavigationModeCursorAuto: Qt = ...
        NavigationModeCursorForceVisible: Qt = ...

    class GestureFlag(enum.Flag):
        DontStartGestureOnChildren: Qt = ...
        ReceivePartialGestures: Qt = ...
        IgnoredGesturesPropagateToParent: Qt = ...

    class GestureType(enum.Enum):
        TapGesture: Qt = ...
        TapAndHoldGesture: Qt = ...
        PanGesture: Qt = ...
        PinchGesture: Qt = ...
        SwipeGesture: Qt = ...
        CustomGesture: Qt = ...

    class GestureState(enum.Enum):
        GestureStarted: Qt = ...
        GestureUpdated: Qt = ...
        GestureFinished: Qt = ...
        GestureCanceled: Qt = ...

    class TouchPointState(enum.Flag):
        TouchPointUnknownState: Qt = ...
        TouchPointPressed: Qt = ...
        TouchPointMoved: Qt = ...
        TouchPointStationary: Qt = ...
        TouchPointReleased: Qt = ...

    class CoordinateSystem(enum.Enum):
        DeviceCoordinates: Qt = ...
        LogicalCoordinates: Qt = ...

    class AnchorPoint(enum.Enum):
        AnchorLeft: Qt = ...
        AnchorHorizontalCenter: Qt = ...
        AnchorRight: Qt = ...
        AnchorTop: Qt = ...
        AnchorVerticalCenter: Qt = ...
        AnchorBottom: Qt = ...

    class InputMethodHint(enum.Flag):
        ImhNone: Qt = ...
        ImhHiddenText: Qt = ...
        ImhNoAutoUppercase: Qt = ...
        ImhPreferNumbers: Qt = ...
        ImhPreferUppercase: Qt = ...
        ImhPreferLowercase: Qt = ...
        ImhNoPredictiveText: Qt = ...
        ImhDigitsOnly: Qt = ...
        ImhFormattedNumbersOnly: Qt = ...
        ImhUppercaseOnly: Qt = ...
        ImhLowercaseOnly: Qt = ...
        ImhDialableCharactersOnly: Qt = ...
        ImhEmailCharactersOnly: Qt = ...
        ImhUrlCharactersOnly: Qt = ...
        ImhExclusiveInputMask: Qt = ...
        ImhSensitiveData: Qt = ...
        ImhDate: Qt = ...
        ImhTime: Qt = ...
        ImhPreferLatin: Qt = ...
        ImhLatinOnly: Qt = ...
        ImhMultiLine: Qt = ...
        ImhNoEditMenu: Qt = ...
        ImhNoTextHandles: Qt = ...

    class TileRule(enum.Enum):
        StretchTile: Qt = ...
        RepeatTile: Qt = ...
        RoundTile: Qt = ...

    class WindowFrameSection(enum.Enum):
        NoSection: Qt = ...
        LeftSection: Qt = ...
        TopLeftSection: Qt = ...
        TopSection: Qt = ...
        TopRightSection: Qt = ...
        RightSection: Qt = ...
        BottomRightSection: Qt = ...
        BottomSection: Qt = ...
        BottomLeftSection: Qt = ...
        TitleBarArea: Qt = ...

    class SizeHint(enum.Enum):
        MinimumSize: Qt = ...
        PreferredSize: Qt = ...
        MaximumSize: Qt = ...
        MinimumDescent: Qt = ...

    class SizeMode(enum.Enum):
        AbsoluteSize: Qt = ...
        RelativeSize: Qt = ...

    class EventPriority(enum.Enum):
        HighEventPriority: Qt = ...
        NormalEventPriority: Qt = ...
        LowEventPriority: Qt = ...

    class Axis(enum.Enum):
        XAxis: Qt = ...
        YAxis: Qt = ...
        ZAxis: Qt = ...

    class MaskMode(enum.Enum):
        MaskInColor: Qt = ...
        MaskOutColor: Qt = ...

    class TextInteractionFlag(enum.Flag):
        NoTextInteraction: Qt = ...
        TextSelectableByMouse: Qt = ...
        TextSelectableByKeyboard: Qt = ...
        LinksAccessibleByMouse: Qt = ...
        LinksAccessibleByKeyboard: Qt = ...
        TextEditable: Qt = ...
        TextEditorInteraction: Qt = ...
        TextBrowserInteraction: Qt = ...

    class ItemSelectionMode(enum.Enum):
        ContainsItemShape: Qt = ...
        IntersectsItemShape: Qt = ...
        ContainsItemBoundingRect: Qt = ...
        IntersectsItemBoundingRect: Qt = ...

    class ApplicationAttribute(enum.Enum):
        AA_DontShowIconsInMenus: Qt = ...
        AA_NativeWindows: Qt = ...
        AA_DontCreateNativeWidgetSiblings: Qt = ...
        AA_DontUseNativeMenuBar: Qt = ...
        AA_MacDontSwapCtrlAndMeta: Qt = ...
        AA_Use96Dpi: Qt = ...
        AA_SynthesizeTouchForUnhandledMouseEvents: Qt = ...
        AA_SynthesizeMouseForUnhandledTouchEvents: Qt = ...
        AA_ForceRasterWidgets: Qt = ...
        AA_UseDesktopOpenGL: Qt = ...
        AA_UseOpenGLES: Qt = ...
        AA_UseSoftwareOpenGL: Qt = ...
        AA_ShareOpenGLContexts: Qt = ...
        AA_SetPalette: Qt = ...
        AA_PluginApplication: Qt = ...
        AA_UseStyleSheetPropagationInWidgetStyles: Qt = ...
        AA_DontUseNativeDialogs: Qt = ...
        AA_SynthesizeMouseForUnhandledTabletEvents: Qt = ...
        AA_CompressHighFrequencyEvents: Qt = ...
        AA_DontCheckOpenGLContextThreadAffinity: Qt = ...
        AA_DisableShaderDiskCache: Qt = ...
        AA_DontShowShortcutsInContextMenus: Qt = ...
        AA_CompressTabletEvents: Qt = ...
        AA_DisableSessionManager: Qt = ...
        AA_DisableNativeVirtualKeyboard: Qt = ...

    class WindowModality(enum.Enum):
        NonModal: Qt = ...
        WindowModal: Qt = ...
        ApplicationModal: Qt = ...

    class MatchFlag(enum.Flag):
        MatchExactly: Qt = ...
        MatchFixedString: Qt = ...
        MatchContains: Qt = ...
        MatchStartsWith: Qt = ...
        MatchEndsWith: Qt = ...
        MatchWildcard: Qt = ...
        MatchCaseSensitive: Qt = ...
        MatchWrap: Qt = ...
        MatchRecursive: Qt = ...
        MatchRegularExpression: Qt = ...

    class ItemFlag(enum.Flag):
        NoItemFlags: Qt = ...
        ItemIsSelectable: Qt = ...
        ItemIsEditable: Qt = ...
        ItemIsDragEnabled: Qt = ...
        ItemIsDropEnabled: Qt = ...
        ItemIsUserCheckable: Qt = ...
        ItemIsEnabled: Qt = ...
        ItemNeverHasChildren: Qt = ...
        ItemIsUserTristate: Qt = ...
        ItemIsAutoTristate: Qt = ...

    class ItemDataRole(enum.IntEnum):
        DisplayRole: Qt = ...
        DecorationRole: Qt = ...
        EditRole: Qt = ...
        ToolTipRole: Qt = ...
        StatusTipRole: Qt = ...
        WhatsThisRole: Qt = ...
        FontRole: Qt = ...
        TextAlignmentRole: Qt = ...
        BackgroundRole: Qt = ...
        ForegroundRole: Qt = ...
        CheckStateRole: Qt = ...
        AccessibleTextRole: Qt = ...
        AccessibleDescriptionRole: Qt = ...
        SizeHintRole: Qt = ...
        InitialSortOrderRole: Qt = ...
        UserRole: Qt = ...

    class CheckState(enum.Enum):
        Unchecked: Qt = ...
        PartiallyChecked: Qt = ...
        Checked: Qt = ...

    class DropAction(enum.Flag):
        CopyAction: Qt = ...
        MoveAction: Qt = ...
        LinkAction: Qt = ...
        ActionMask: Qt = ...
        TargetMoveAction: Qt = ...
        IgnoreAction: Qt = ...

    class LayoutDirection(enum.Enum):
        LeftToRight: Qt = ...
        RightToLeft: Qt = ...
        LayoutDirectionAuto: Qt = ...

    class ToolButtonStyle(enum.Enum):
        ToolButtonIconOnly: Qt = ...
        ToolButtonTextOnly: Qt = ...
        ToolButtonTextBesideIcon: Qt = ...
        ToolButtonTextUnderIcon: Qt = ...
        ToolButtonFollowStyle: Qt = ...

    class InputMethodQuery(enum.Flag):
        ImFont: Qt = ...
        ImCursorPosition: Qt = ...
        ImSurroundingText: Qt = ...
        ImCurrentSelection: Qt = ...
        ImMaximumTextLength: Qt = ...
        ImAnchorPosition: Qt = ...
        ImEnabled: Qt = ...
        ImCursorRectangle: Qt = ...
        ImHints: Qt = ...
        ImPreferredLanguage: Qt = ...
        ImPlatformData: Qt = ...
        ImQueryInput: Qt = ...
        ImQueryAll: Qt = ...
        ImAbsolutePosition: Qt = ...
        ImTextBeforeCursor: Qt = ...
        ImTextAfterCursor: Qt = ...
        ImEnterKeyType: Qt = ...
        ImAnchorRectangle: Qt = ...
        ImInputItemClipRectangle: Qt = ...
        ImReadOnly: Qt = ...

    class ContextMenuPolicy(enum.Enum):
        NoContextMenu: Qt = ...
        PreventContextMenu: Qt = ...
        DefaultContextMenu: Qt = ...
        ActionsContextMenu: Qt = ...
        CustomContextMenu: Qt = ...

    class FocusReason(enum.Enum):
        MouseFocusReason: Qt = ...
        TabFocusReason: Qt = ...
        BacktabFocusReason: Qt = ...
        ActiveWindowFocusReason: Qt = ...
        PopupFocusReason: Qt = ...
        ShortcutFocusReason: Qt = ...
        MenuBarFocusReason: Qt = ...
        OtherFocusReason: Qt = ...
        NoFocusReason: Qt = ...

    class TransformationMode(enum.Enum):
        FastTransformation: Qt = ...
        SmoothTransformation: Qt = ...

    class ClipOperation(enum.Enum):
        NoClip: Qt = ...
        ReplaceClip: Qt = ...
        IntersectClip: Qt = ...

    class FillRule(enum.Enum):
        OddEvenFill: Qt = ...
        WindingFill: Qt = ...

    class ShortcutContext(enum.Enum):
        WidgetShortcut: Qt = ...
        WindowShortcut: Qt = ...
        ApplicationShortcut: Qt = ...
        WidgetWithChildrenShortcut: Qt = ...

    class ConnectionType(enum.Enum):
        AutoConnection: Qt = ...
        DirectConnection: Qt = ...
        QueuedConnection: Qt = ...
        BlockingQueuedConnection: Qt = ...
        UniqueConnection: Qt = ...
        SingleShotConnection: Qt = ...

    class Corner(enum.Enum):
        TopLeftCorner: Qt = ...
        TopRightCorner: Qt = ...
        BottomLeftCorner: Qt = ...
        BottomRightCorner: Qt = ...

    class CaseSensitivity(enum.Enum):
        CaseInsensitive: Qt = ...
        CaseSensitive: Qt = ...

    class ScrollBarPolicy(enum.Enum):
        ScrollBarAsNeeded: Qt = ...
        ScrollBarAlwaysOff: Qt = ...
        ScrollBarAlwaysOn: Qt = ...

    class DayOfWeek(enum.Enum):
        Monday: Qt = ...
        Tuesday: Qt = ...
        Wednesday: Qt = ...
        Thursday: Qt = ...
        Friday: Qt = ...
        Saturday: Qt = ...
        Sunday: Qt = ...

    class TimeSpec(enum.Enum):
        LocalTime: Qt = ...
        UTC: Qt = ...
        OffsetFromUTC: Qt = ...
        TimeZone: Qt = ...

    class DateFormat(enum.Enum):
        TextDate: Qt = ...
        ISODate: Qt = ...
        ISODateWithMs: Qt = ...
        RFC2822Date: Qt = ...

    class ToolBarArea(enum.Flag):
        LeftToolBarArea: Qt = ...
        RightToolBarArea: Qt = ...
        TopToolBarArea: Qt = ...
        BottomToolBarArea: Qt = ...
        AllToolBarAreas: Qt = ...
        NoToolBarArea: Qt = ...

    class TimerType(enum.Enum):
        PreciseTimer: Qt = ...
        CoarseTimer: Qt = ...
        VeryCoarseTimer: Qt = ...

    class DockWidgetArea(enum.Flag):
        LeftDockWidgetArea: Qt = ...
        RightDockWidgetArea: Qt = ...
        TopDockWidgetArea: Qt = ...
        BottomDockWidgetArea: Qt = ...
        AllDockWidgetAreas: Qt = ...
        NoDockWidgetArea: Qt = ...

    class AspectRatioMode(enum.Enum):
        IgnoreAspectRatio: Qt = ...
        KeepAspectRatio: Qt = ...
        KeepAspectRatioByExpanding: Qt = ...

    class TextFormat(enum.Enum):
        PlainText: Qt = ...
        RichText: Qt = ...
        AutoText: Qt = ...
        MarkdownText: Qt = ...

    class CursorShape(enum.Enum):
        ArrowCursor: Qt = ...
        UpArrowCursor: Qt = ...
        CrossCursor: Qt = ...
        WaitCursor: Qt = ...
        IBeamCursor: Qt = ...
        SizeVerCursor: Qt = ...
        SizeHorCursor: Qt = ...
        SizeBDiagCursor: Qt = ...
        SizeFDiagCursor: Qt = ...
        SizeAllCursor: Qt = ...
        BlankCursor: Qt = ...
        SplitVCursor: Qt = ...
        SplitHCursor: Qt = ...
        PointingHandCursor: Qt = ...
        ForbiddenCursor: Qt = ...
        OpenHandCursor: Qt = ...
        ClosedHandCursor: Qt = ...
        WhatsThisCursor: Qt = ...
        BusyCursor: Qt = ...
        LastCursor: Qt = ...
        BitmapCursor: Qt = ...
        CustomCursor: Qt = ...
        DragCopyCursor: Qt = ...
        DragMoveCursor: Qt = ...
        DragLinkCursor: Qt = ...

    class UIEffect(enum.Enum):
        UI_General: Qt = ...
        UI_AnimateMenu: Qt = ...
        UI_FadeMenu: Qt = ...
        UI_AnimateCombo: Qt = ...
        UI_AnimateTooltip: Qt = ...
        UI_FadeTooltip: Qt = ...
        UI_AnimateToolBox: Qt = ...

    class BrushStyle(enum.Enum):
        NoBrush: Qt = ...
        SolidPattern: Qt = ...
        Dense1Pattern: Qt = ...
        Dense2Pattern: Qt = ...
        Dense3Pattern: Qt = ...
        Dense4Pattern: Qt = ...
        Dense5Pattern: Qt = ...
        Dense6Pattern: Qt = ...
        Dense7Pattern: Qt = ...
        HorPattern: Qt = ...
        VerPattern: Qt = ...
        CrossPattern: Qt = ...
        BDiagPattern: Qt = ...
        FDiagPattern: Qt = ...
        DiagCrossPattern: Qt = ...
        LinearGradientPattern: Qt = ...
        RadialGradientPattern: Qt = ...
        ConicalGradientPattern: Qt = ...
        TexturePattern: Qt = ...

    class PenJoinStyle(enum.Enum):
        MiterJoin: Qt = ...
        BevelJoin: Qt = ...
        RoundJoin: Qt = ...
        MPenJoinStyle: Qt = ...
        SvgMiterJoin: Qt = ...

    class PenCapStyle(enum.Enum):
        FlatCap: Qt = ...
        SquareCap: Qt = ...
        RoundCap: Qt = ...

    class PenStyle(enum.Enum):
        NoPen: Qt = ...
        SolidLine: Qt = ...
        DashLine: Qt = ...
        DotLine: Qt = ...
        DashDotLine: Qt = ...
        DashDotDotLine: Qt = ...
        CustomDashLine: Qt = ...

    class ArrowType(enum.Enum):
        NoArrow: Qt = ...
        UpArrow: Qt = ...
        DownArrow: Qt = ...
        LeftArrow: Qt = ...
        RightArrow: Qt = ...

    class Key(enum.IntEnum):
        Key_Escape: Qt = ...
        Key_Tab: Qt = ...
        Key_Backtab: Qt = ...
        Key_Backspace: Qt = ...
        Key_Return: Qt = ...
        Key_Enter: Qt = ...
        Key_Insert: Qt = ...
        Key_Delete: Qt = ...
        Key_Pause: Qt = ...
        Key_Print: Qt = ...
        Key_SysReq: Qt = ...
        Key_Clear: Qt = ...
        Key_Home: Qt = ...
        Key_End: Qt = ...
        Key_Left: Qt = ...
        Key_Up: Qt = ...
        Key_Right: Qt = ...
        Key_Down: Qt = ...
        Key_PageUp: Qt = ...
        Key_PageDown: Qt = ...
        Key_Shift: Qt = ...
        Key_Control: Qt = ...
        Key_Meta: Qt = ...
        Key_Alt: Qt = ...
        Key_CapsLock: Qt = ...
        Key_NumLock: Qt = ...
        Key_ScrollLock: Qt = ...
        Key_F1: Qt = ...
        Key_F2: Qt = ...
        Key_F3: Qt = ...
        Key_F4: Qt = ...
        Key_F5: Qt = ...
        Key_F6: Qt = ...
        Key_F7: Qt = ...
        Key_F8: Qt = ...
        Key_F9: Qt = ...
        Key_F10: Qt = ...
        Key_F11: Qt = ...
        Key_F12: Qt = ...
        Key_F13: Qt = ...
        Key_F14: Qt = ...
        Key_F15: Qt = ...
        Key_F16: Qt = ...
        Key_F17: Qt = ...
        Key_F18: Qt = ...
        Key_F19: Qt = ...
        Key_F20: Qt = ...
        Key_F21: Qt = ...
        Key_F22: Qt = ...
        Key_F23: Qt = ...
        Key_F24: Qt = ...
        Key_F25: Qt = ...
        Key_F26: Qt = ...
        Key_F27: Qt = ...
        Key_F28: Qt = ...
        Key_F29: Qt = ...
        Key_F30: Qt = ...
        Key_F31: Qt = ...
        Key_F32: Qt = ...
        Key_F33: Qt = ...
        Key_F34: Qt = ...
        Key_F35: Qt = ...
        Key_Super_L: Qt = ...
        Key_Super_R: Qt = ...
        Key_Menu: Qt = ...
        Key_Hyper_L: Qt = ...
        Key_Hyper_R: Qt = ...
        Key_Help: Qt = ...
        Key_Direction_L: Qt = ...
        Key_Direction_R: Qt = ...
        Key_Space: Qt = ...
        Key_Any: Qt = ...
        Key_Exclam: Qt = ...
        Key_QuoteDbl: Qt = ...
        Key_NumberSign: Qt = ...
        Key_Dollar: Qt = ...
        Key_Percent: Qt = ...
        Key_Ampersand: Qt = ...
        Key_Apostrophe: Qt = ...
        Key_ParenLeft: Qt = ...
        Key_ParenRight: Qt = ...
        Key_Asterisk: Qt = ...
        Key_Plus: Qt = ...
        Key_Comma: Qt = ...
        Key_Minus: Qt = ...
        Key_Period: Qt = ...
        Key_Slash: Qt = ...
        Key_0: Qt = ...
        Key_1: Qt = ...
        Key_2: Qt = ...
        Key_3: Qt = ...
        Key_4: Qt = ...
        Key_5: Qt = ...
        Key_6: Qt = ...
        Key_7: Qt = ...
        Key_8: Qt = ...
        Key_9: Qt = ...
        Key_Colon: Qt = ...
        Key_Semicolon: Qt = ...
        Key_Less: Qt = ...
        Key_Equal: Qt = ...
        Key_Greater: Qt = ...
        Key_Question: Qt = ...
        Key_At: Qt = ...
        Key_A: Qt = ...
        Key_B: Qt = ...
        Key_C: Qt = ...
        Key_D: Qt = ...
        Key_E: Qt = ...
        Key_F: Qt = ...
        Key_G: Qt = ...
        Key_H: Qt = ...
        Key_I: Qt = ...
        Key_J: Qt = ...
        Key_K: Qt = ...
        Key_L: Qt = ...
        Key_M: Qt = ...
        Key_N: Qt = ...
        Key_O: Qt = ...
        Key_P: Qt = ...
        Key_Q: Qt = ...
        Key_R: Qt = ...
        Key_S: Qt = ...
        Key_T: Qt = ...
        Key_U: Qt = ...
        Key_V: Qt = ...
        Key_W: Qt = ...
        Key_X: Qt = ...
        Key_Y: Qt = ...
        Key_Z: Qt = ...
        Key_BracketLeft: Qt = ...
        Key_Backslash: Qt = ...
        Key_BracketRight: Qt = ...
        Key_AsciiCircum: Qt = ...
        Key_Underscore: Qt = ...
        Key_QuoteLeft: Qt = ...
        Key_BraceLeft: Qt = ...
        Key_Bar: Qt = ...
        Key_BraceRight: Qt = ...
        Key_AsciiTilde: Qt = ...
        Key_nobreakspace: Qt = ...
        Key_exclamdown: Qt = ...
        Key_cent: Qt = ...
        Key_sterling: Qt = ...
        Key_currency: Qt = ...
        Key_yen: Qt = ...
        Key_brokenbar: Qt = ...
        Key_section: Qt = ...
        Key_diaeresis: Qt = ...
        Key_copyright: Qt = ...
        Key_ordfeminine: Qt = ...
        Key_guillemotleft: Qt = ...
        Key_notsign: Qt = ...
        Key_hyphen: Qt = ...
        Key_registered: Qt = ...
        Key_macron: Qt = ...
        Key_degree: Qt = ...
        Key_plusminus: Qt = ...
        Key_twosuperior: Qt = ...
        Key_threesuperior: Qt = ...
        Key_acute: Qt = ...
        Key_mu: Qt = ...
        Key_paragraph: Qt = ...
        Key_periodcentered: Qt = ...
        Key_cedilla: Qt = ...
        Key_onesuperior: Qt = ...
        Key_masculine: Qt = ...
        Key_guillemotright: Qt = ...
        Key_onequarter: Qt = ...
        Key_onehalf: Qt = ...
        Key_threequarters: Qt = ...
        Key_questiondown: Qt = ...
        Key_Agrave: Qt = ...
        Key_Aacute: Qt = ...
        Key_Acircumflex: Qt = ...
        Key_Atilde: Qt = ...
        Key_Adiaeresis: Qt = ...
        Key_Aring: Qt = ...
        Key_AE: Qt = ...
        Key_Ccedilla: Qt = ...
        Key_Egrave: Qt = ...
        Key_Eacute: Qt = ...
        Key_Ecircumflex: Qt = ...
        Key_Ediaeresis: Qt = ...
        Key_Igrave: Qt = ...
        Key_Iacute: Qt = ...
        Key_Icircumflex: Qt = ...
        Key_Idiaeresis: Qt = ...
        Key_ETH: Qt = ...
        Key_Ntilde: Qt = ...
        Key_Ograve: Qt = ...
        Key_Oacute: Qt = ...
        Key_Ocircumflex: Qt = ...
        Key_Otilde: Qt = ...
        Key_Odiaeresis: Qt = ...
        Key_multiply: Qt = ...
        Key_Ooblique: Qt = ...
        Key_Ugrave: Qt = ...
        Key_Uacute: Qt = ...
        Key_Ucircumflex: Qt = ...
        Key_Udiaeresis: Qt = ...
        Key_Yacute: Qt = ...
        Key_THORN: Qt = ...
        Key_ssharp: Qt = ...
        Key_division: Qt = ...
        Key_ydiaeresis: Qt = ...
        Key_AltGr: Qt = ...
        Key_Multi_key: Qt = ...
        Key_Codeinput: Qt = ...
        Key_SingleCandidate: Qt = ...
        Key_MultipleCandidate: Qt = ...
        Key_PreviousCandidate: Qt = ...
        Key_Mode_switch: Qt = ...
        Key_Kanji: Qt = ...
        Key_Muhenkan: Qt = ...
        Key_Henkan: Qt = ...
        Key_Romaji: Qt = ...
        Key_Hiragana: Qt = ...
        Key_Katakana: Qt = ...
        Key_Hiragana_Katakana: Qt = ...
        Key_Zenkaku: Qt = ...
        Key_Hankaku: Qt = ...
        Key_Zenkaku_Hankaku: Qt = ...
        Key_Touroku: Qt = ...
        Key_Massyo: Qt = ...
        Key_Kana_Lock: Qt = ...
        Key_Kana_Shift: Qt = ...
        Key_Eisu_Shift: Qt = ...
        Key_Eisu_toggle: Qt = ...
        Key_Hangul: Qt = ...
        Key_Hangul_Start: Qt = ...
        Key_Hangul_End: Qt = ...
        Key_Hangul_Hanja: Qt = ...
        Key_Hangul_Jamo: Qt = ...
        Key_Hangul_Romaja: Qt = ...
        Key_Hangul_Jeonja: Qt = ...
        Key_Hangul_Banja: Qt = ...
        Key_Hangul_PreHanja: Qt = ...
        Key_Hangul_PostHanja: Qt = ...
        Key_Hangul_Special: Qt = ...
        Key_Dead_Grave: Qt = ...
        Key_Dead_Acute: Qt = ...
        Key_Dead_Circumflex: Qt = ...
        Key_Dead_Tilde: Qt = ...
        Key_Dead_Macron: Qt = ...
        Key_Dead_Breve: Qt = ...
        Key_Dead_Abovedot: Qt = ...
        Key_Dead_Diaeresis: Qt = ...
        Key_Dead_Abovering: Qt = ...
        Key_Dead_Doubleacute: Qt = ...
        Key_Dead_Caron: Qt = ...
        Key_Dead_Cedilla: Qt = ...
        Key_Dead_Ogonek: Qt = ...
        Key_Dead_Iota: Qt = ...
        Key_Dead_Voiced_Sound: Qt = ...
        Key_Dead_Semivoiced_Sound: Qt = ...
        Key_Dead_Belowdot: Qt = ...
        Key_Dead_Hook: Qt = ...
        Key_Dead_Horn: Qt = ...
        Key_Back: Qt = ...
        Key_Forward: Qt = ...
        Key_Stop: Qt = ...
        Key_Refresh: Qt = ...
        Key_VolumeDown: Qt = ...
        Key_VolumeMute: Qt = ...
        Key_VolumeUp: Qt = ...
        Key_BassBoost: Qt = ...
        Key_BassUp: Qt = ...
        Key_BassDown: Qt = ...
        Key_TrebleUp: Qt = ...
        Key_TrebleDown: Qt = ...
        Key_MediaPlay: Qt = ...
        Key_MediaStop: Qt = ...
        Key_MediaPrevious: Qt = ...
        Key_MediaNext: Qt = ...
        Key_MediaRecord: Qt = ...
        Key_HomePage: Qt = ...
        Key_Favorites: Qt = ...
        Key_Search: Qt = ...
        Key_Standby: Qt = ...
        Key_OpenUrl: Qt = ...
        Key_LaunchMail: Qt = ...
        Key_LaunchMedia: Qt = ...
        Key_Launch0: Qt = ...
        Key_Launch1: Qt = ...
        Key_Launch2: Qt = ...
        Key_Launch3: Qt = ...
        Key_Launch4: Qt = ...
        Key_Launch5: Qt = ...
        Key_Launch6: Qt = ...
        Key_Launch7: Qt = ...
        Key_Launch8: Qt = ...
        Key_Launch9: Qt = ...
        Key_LaunchA: Qt = ...
        Key_LaunchB: Qt = ...
        Key_LaunchC: Qt = ...
        Key_LaunchD: Qt = ...
        Key_LaunchE: Qt = ...
        Key_LaunchF: Qt = ...
        Key_MediaLast: Qt = ...
        Key_Select: Qt = ...
        Key_Yes: Qt = ...
        Key_No: Qt = ...
        Key_Context1: Qt = ...
        Key_Context2: Qt = ...
        Key_Context3: Qt = ...
        Key_Context4: Qt = ...
        Key_Call: Qt = ...
        Key_Hangup: Qt = ...
        Key_Flip: Qt = ...
        Key_unknown: Qt = ...
        Key_Execute: Qt = ...
        Key_Printer: Qt = ...
        Key_Play: Qt = ...
        Key_Sleep: Qt = ...
        Key_Zoom: Qt = ...
        Key_Cancel: Qt = ...
        Key_MonBrightnessUp: Qt = ...
        Key_MonBrightnessDown: Qt = ...
        Key_KeyboardLightOnOff: Qt = ...
        Key_KeyboardBrightnessUp: Qt = ...
        Key_KeyboardBrightnessDown: Qt = ...
        Key_PowerOff: Qt = ...
        Key_WakeUp: Qt = ...
        Key_Eject: Qt = ...
        Key_ScreenSaver: Qt = ...
        Key_WWW: Qt = ...
        Key_Memo: Qt = ...
        Key_LightBulb: Qt = ...
        Key_Shop: Qt = ...
        Key_History: Qt = ...
        Key_AddFavorite: Qt = ...
        Key_HotLinks: Qt = ...
        Key_BrightnessAdjust: Qt = ...
        Key_Finance: Qt = ...
        Key_Community: Qt = ...
        Key_AudioRewind: Qt = ...
        Key_BackForward: Qt = ...
        Key_ApplicationLeft: Qt = ...
        Key_ApplicationRight: Qt = ...
        Key_Book: Qt = ...
        Key_CD: Qt = ...
        Key_Calculator: Qt = ...
        Key_ToDoList: Qt = ...
        Key_ClearGrab: Qt = ...
        Key_Close: Qt = ...
        Key_Copy: Qt = ...
        Key_Cut: Qt = ...
        Key_Display: Qt = ...
        Key_DOS: Qt = ...
        Key_Documents: Qt = ...
        Key_Excel: Qt = ...
        Key_Explorer: Qt = ...
        Key_Game: Qt = ...
        Key_Go: Qt = ...
        Key_iTouch: Qt = ...
        Key_LogOff: Qt = ...
        Key_Market: Qt = ...
        Key_Meeting: Qt = ...
        Key_MenuKB: Qt = ...
        Key_MenuPB: Qt = ...
        Key_MySites: Qt = ...
        Key_News: Qt = ...
        Key_OfficeHome: Qt = ...
        Key_Option: Qt = ...
        Key_Paste: Qt = ...
        Key_Phone: Qt = ...
        Key_Calendar: Qt = ...
        Key_Reply: Qt = ...
        Key_Reload: Qt = ...
        Key_RotateWindows: Qt = ...
        Key_RotationPB: Qt = ...
        Key_RotationKB: Qt = ...
        Key_Save: Qt = ...
        Key_Send: Qt = ...
        Key_Spell: Qt = ...
        Key_SplitScreen: Qt = ...
        Key_Support: Qt = ...
        Key_TaskPane: Qt = ...
        Key_Terminal: Qt = ...
        Key_Tools: Qt = ...
        Key_Travel: Qt = ...
        Key_Video: Qt = ...
        Key_Word: Qt = ...
        Key_Xfer: Qt = ...
        Key_ZoomIn: Qt = ...
        Key_ZoomOut: Qt = ...
        Key_Away: Qt = ...
        Key_Messenger: Qt = ...
        Key_WebCam: Qt = ...
        Key_MailForward: Qt = ...
        Key_Pictures: Qt = ...
        Key_Music: Qt = ...
        Key_Battery: Qt = ...
        Key_Bluetooth: Qt = ...
        Key_WLAN: Qt = ...
        Key_UWB: Qt = ...
        Key_AudioForward: Qt = ...
        Key_AudioRepeat: Qt = ...
        Key_AudioRandomPlay: Qt = ...
        Key_Subtitle: Qt = ...
        Key_AudioCycleTrack: Qt = ...
        Key_Time: Qt = ...
        Key_Hibernate: Qt = ...
        Key_View: Qt = ...
        Key_TopMenu: Qt = ...
        Key_PowerDown: Qt = ...
        Key_Suspend: Qt = ...
        Key_ContrastAdjust: Qt = ...
        Key_MediaPause: Qt = ...
        Key_MediaTogglePlayPause: Qt = ...
        Key_LaunchG: Qt = ...
        Key_LaunchH: Qt = ...
        Key_ToggleCallHangup: Qt = ...
        Key_VoiceDial: Qt = ...
        Key_LastNumberRedial: Qt = ...
        Key_Camera: Qt = ...
        Key_CameraFocus: Qt = ...
        Key_TouchpadToggle: Qt = ...
        Key_TouchpadOn: Qt = ...
        Key_TouchpadOff: Qt = ...
        Key_MicMute: Qt = ...
        Key_Red: Qt = ...
        Key_Green: Qt = ...
        Key_Yellow: Qt = ...
        Key_Blue: Qt = ...
        Key_ChannelUp: Qt = ...
        Key_ChannelDown: Qt = ...
        Key_Guide: Qt = ...
        Key_Info: Qt = ...
        Key_Settings: Qt = ...
        Key_Exit: Qt = ...
        Key_MicVolumeUp: Qt = ...
        Key_MicVolumeDown: Qt = ...
        Key_New: Qt = ...
        Key_Open: Qt = ...
        Key_Find: Qt = ...
        Key_Undo: Qt = ...
        Key_Redo: Qt = ...
        Key_Dead_Stroke: Qt = ...
        Key_Dead_Abovecomma: Qt = ...
        Key_Dead_Abovereversedcomma: Qt = ...
        Key_Dead_Doublegrave: Qt = ...
        Key_Dead_Belowring: Qt = ...
        Key_Dead_Belowmacron: Qt = ...
        Key_Dead_Belowcircumflex: Qt = ...
        Key_Dead_Belowtilde: Qt = ...
        Key_Dead_Belowbreve: Qt = ...
        Key_Dead_Belowdiaeresis: Qt = ...
        Key_Dead_Invertedbreve: Qt = ...
        Key_Dead_Belowcomma: Qt = ...
        Key_Dead_Currency: Qt = ...
        Key_Dead_a: Qt = ...
        Key_Dead_A: Qt = ...
        Key_Dead_e: Qt = ...
        Key_Dead_E: Qt = ...
        Key_Dead_i: Qt = ...
        Key_Dead_I: Qt = ...
        Key_Dead_o: Qt = ...
        Key_Dead_O: Qt = ...
        Key_Dead_u: Qt = ...
        Key_Dead_U: Qt = ...
        Key_Dead_Small_Schwa: Qt = ...
        Key_Dead_Capital_Schwa: Qt = ...
        Key_Dead_Greek: Qt = ...
        Key_Dead_Lowline: Qt = ...
        Key_Dead_Aboveverticalline: Qt = ...
        Key_Dead_Belowverticalline: Qt = ...
        Key_Dead_Longsolidusoverlay: Qt = ...

    class BGMode(enum.Enum):
        TransparentMode: Qt = ...
        OpaqueMode: Qt = ...

    class ImageConversionFlag(enum.Flag):
        AutoColor: Qt = ...
        ColorOnly: Qt = ...
        MonoOnly: Qt = ...
        ThresholdAlphaDither: Qt = ...
        OrderedAlphaDither: Qt = ...
        DiffuseAlphaDither: Qt = ...
        DiffuseDither: Qt = ...
        OrderedDither: Qt = ...
        ThresholdDither: Qt = ...
        AutoDither: Qt = ...
        PreferDither: Qt = ...
        AvoidDither: Qt = ...
        NoOpaqueDetection: Qt = ...
        NoFormatConversion: Qt = ...

    class WidgetAttribute(enum.Enum):
        WA_Disabled: Qt = ...
        WA_UnderMouse: Qt = ...
        WA_MouseTracking: Qt = ...
        WA_OpaquePaintEvent: Qt = ...
        WA_StaticContents: Qt = ...
        WA_LaidOut: Qt = ...
        WA_PaintOnScreen: Qt = ...
        WA_NoSystemBackground: Qt = ...
        WA_UpdatesDisabled: Qt = ...
        WA_Mapped: Qt = ...
        WA_InputMethodEnabled: Qt = ...
        WA_WState_Visible: Qt = ...
        WA_WState_Hidden: Qt = ...
        WA_ForceDisabled: Qt = ...
        WA_KeyCompression: Qt = ...
        WA_PendingMoveEvent: Qt = ...
        WA_PendingResizeEvent: Qt = ...
        WA_SetPalette: Qt = ...
        WA_SetFont: Qt = ...
        WA_SetCursor: Qt = ...
        WA_NoChildEventsFromChildren: Qt = ...
        WA_WindowModified: Qt = ...
        WA_Resized: Qt = ...
        WA_Moved: Qt = ...
        WA_PendingUpdate: Qt = ...
        WA_InvalidSize: Qt = ...
        WA_CustomWhatsThis: Qt = ...
        WA_LayoutOnEntireRect: Qt = ...
        WA_OutsideWSRange: Qt = ...
        WA_GrabbedShortcut: Qt = ...
        WA_TransparentForMouseEvents: Qt = ...
        WA_PaintUnclipped: Qt = ...
        WA_SetWindowIcon: Qt = ...
        WA_NoMouseReplay: Qt = ...
        WA_DeleteOnClose: Qt = ...
        WA_RightToLeft: Qt = ...
        WA_SetLayoutDirection: Qt = ...
        WA_NoChildEventsForParent: Qt = ...
        WA_ForceUpdatesDisabled: Qt = ...
        WA_WState_Created: Qt = ...
        WA_WState_CompressKeys: Qt = ...
        WA_WState_InPaintEvent: Qt = ...
        WA_WState_Reparented: Qt = ...
        WA_WState_ConfigPending: Qt = ...
        WA_WState_Polished: Qt = ...
        WA_WState_OwnSizePolicy: Qt = ...
        WA_WState_ExplicitShowHide: Qt = ...
        WA_MouseNoMask: Qt = ...
        WA_NoMousePropagation: Qt = ...
        WA_Hover: Qt = ...
        WA_InputMethodTransparent: Qt = ...
        WA_QuitOnClose: Qt = ...
        WA_KeyboardFocusChange: Qt = ...
        WA_AcceptDrops: Qt = ...
        WA_WindowPropagation: Qt = ...
        WA_NoX11EventCompression: Qt = ...
        WA_TintedBackground: Qt = ...
        WA_X11OpenGLOverlay: Qt = ...
        WA_AttributeCount: Qt = ...
        WA_AlwaysShowToolTips: Qt = ...
        WA_MacOpaqueSizeGrip: Qt = ...
        WA_SetStyle: Qt = ...
        WA_SetLocale: Qt = ...
        WA_MacShowFocusRect: Qt = ...
        WA_MacNormalSize: Qt = ...
        WA_MacSmallSize: Qt = ...
        WA_MacMiniSize: Qt = ...
        WA_LayoutUsesWidgetRect: Qt = ...
        WA_StyledBackground: Qt = ...
        WA_MacAlwaysShowToolWindow: Qt = ...
        WA_StyleSheet: Qt = ...
        WA_ShowWithoutActivating: Qt = ...
        WA_NativeWindow: Qt = ...
        WA_DontCreateNativeAncestors: Qt = ...
        WA_DontShowOnScreen: Qt = ...
        WA_X11NetWmWindowTypeDesktop: Qt = ...
        WA_X11NetWmWindowTypeDock: Qt = ...
        WA_X11NetWmWindowTypeToolBar: Qt = ...
        WA_X11NetWmWindowTypeMenu: Qt = ...
        WA_X11NetWmWindowTypeUtility: Qt = ...
        WA_X11NetWmWindowTypeSplash: Qt = ...
        WA_X11NetWmWindowTypeDialog: Qt = ...
        WA_X11NetWmWindowTypeDropDownMenu: Qt = ...
        WA_X11NetWmWindowTypePopupMenu: Qt = ...
        WA_X11NetWmWindowTypeToolTip: Qt = ...
        WA_X11NetWmWindowTypeNotification: Qt = ...
        WA_X11NetWmWindowTypeCombo: Qt = ...
        WA_X11NetWmWindowTypeDND: Qt = ...
        WA_TranslucentBackground: Qt = ...
        WA_AcceptTouchEvents: Qt = ...
        WA_TouchPadAcceptSingleTouchEvents: Qt = ...
        WA_X11DoNotAcceptFocus: Qt = ...
        WA_AlwaysStackOnTop: Qt = ...
        WA_TabletTracking: Qt = ...
        WA_ContentsMarginsRespectsSafeArea: Qt = ...
        WA_StyleSheetTarget: Qt = ...

    class WindowState(enum.Flag):
        WindowNoState: Qt = ...
        WindowMinimized: Qt = ...
        WindowMaximized: Qt = ...
        WindowFullScreen: Qt = ...
        WindowActive: Qt = ...

    class WindowType(enum.IntFlag):
        Widget: Qt = ...
        Window: Qt = ...
        Dialog: Qt = ...
        Sheet: Qt = ...
        Drawer: Qt = ...
        Popup: Qt = ...
        Tool: Qt = ...
        ToolTip: Qt = ...
        SplashScreen: Qt = ...
        Desktop: Qt = ...
        SubWindow: Qt = ...
        WindowType_Mask: Qt = ...
        MSWindowsFixedSizeDialogHint: Qt = ...
        MSWindowsOwnDC: Qt = ...
        X11BypassWindowManagerHint: Qt = ...
        FramelessWindowHint: Qt = ...
        CustomizeWindowHint: Qt = ...
        WindowTitleHint: Qt = ...
        WindowSystemMenuHint: Qt = ...
        WindowMinimizeButtonHint: Qt = ...
        WindowMaximizeButtonHint: Qt = ...
        WindowMinMaxButtonsHint: Qt = ...
        WindowContextHelpButtonHint: Qt = ...
        WindowShadeButtonHint: Qt = ...
        WindowStaysOnTopHint: Qt = ...
        WindowStaysOnBottomHint: Qt = ...
        WindowCloseButtonHint: Qt = ...
        MacWindowToolBarButtonHint: Qt = ...
        BypassGraphicsProxyWidget: Qt = ...
        WindowTransparentForInput: Qt = ...
        WindowOverridesSystemGestures: Qt = ...
        WindowDoesNotAcceptFocus: Qt = ...
        NoDropShadowWindowHint: Qt = ...
        WindowFullscreenButtonHint: Qt = ...
        ForeignWindow: Qt = ...
        BypassWindowManagerHint: Qt = ...
        CoverWindow: Qt = ...
        MaximizeUsingFullscreenGeometryHint: Qt = ...

    class TextElideMode(enum.Enum):
        ElideLeft: Qt = ...
        ElideRight: Qt = ...
        ElideMiddle: Qt = ...
        ElideNone: Qt = ...

    class TextFlag(enum.IntFlag):
        TextSingleLine: Qt = ...
        TextDontClip: Qt = ...
        TextExpandTabs: Qt = ...
        TextShowMnemonic: Qt = ...
        TextWordWrap: Qt = ...
        TextWrapAnywhere: Qt = ...
        TextDontPrint: Qt = ...
        TextIncludeTrailingSpaces: Qt = ...
        TextHideMnemonic: Qt = ...
        TextJustificationForced: Qt = ...

    class AlignmentFlag(enum.IntFlag):
        AlignLeft: Qt = ...
        AlignLeading: Qt = ...
        AlignRight: Qt = ...
        AlignTrailing: Qt = ...
        AlignHCenter: Qt = ...
        AlignJustify: Qt = ...
        AlignAbsolute: Qt = ...
        AlignHorizontal_Mask: Qt = ...
        AlignTop: Qt = ...
        AlignBottom: Qt = ...
        AlignVCenter: Qt = ...
        AlignVertical_Mask: Qt = ...
        AlignCenter: Qt = ...
        AlignBaseline: Qt = ...

    class SortOrder(enum.Enum):
        AscendingOrder: Qt = ...
        DescendingOrder: Qt = ...

    class FocusPolicy(enum.Flag):
        NoFocus: Qt = ...
        TabFocus: Qt = ...
        ClickFocus: Qt = ...
        StrongFocus: Qt = ...
        WheelFocus: Qt = ...

    class Orientation(enum.Flag):
        Horizontal: Qt = ...
        Vertical: Qt = ...

    class MouseButton(enum.Flag):
        NoButton: Qt = ...
        AllButtons: Qt = ...
        LeftButton: Qt = ...
        RightButton: Qt = ...
        MiddleButton: Qt = ...
        XButton1: Qt = ...
        XButton2: Qt = ...
        BackButton: Qt = ...
        ExtraButton1: Qt = ...
        ForwardButton: Qt = ...
        ExtraButton2: Qt = ...
        TaskButton: Qt = ...
        ExtraButton3: Qt = ...
        ExtraButton4: Qt = ...
        ExtraButton5: Qt = ...
        ExtraButton6: Qt = ...
        ExtraButton7: Qt = ...
        ExtraButton8: Qt = ...
        ExtraButton9: Qt = ...
        ExtraButton10: Qt = ...
        ExtraButton11: Qt = ...
        ExtraButton12: Qt = ...
        ExtraButton13: Qt = ...
        ExtraButton14: Qt = ...
        ExtraButton15: Qt = ...
        ExtraButton16: Qt = ...
        ExtraButton17: Qt = ...
        ExtraButton18: Qt = ...
        ExtraButton19: Qt = ...
        ExtraButton20: Qt = ...
        ExtraButton21: Qt = ...
        ExtraButton22: Qt = ...
        ExtraButton23: Qt = ...
        ExtraButton24: Qt = ...

    class Modifier(enum.Flag):
        META: Qt = ...
        SHIFT: Qt = ...
        CTRL: Qt = ...
        ALT: Qt = ...
        MODIFIER_MASK: Qt = ...

    class KeyboardModifier(enum.Flag):
        NoModifier: Qt = ...
        ShiftModifier: Qt = ...
        ControlModifier: Qt = ...
        AltModifier: Qt = ...
        MetaModifier: Qt = ...
        KeypadModifier: Qt = ...
        GroupSwitchModifier: Qt = ...
        KeyboardModifierMask: Qt = ...

    class GlobalColor(enum.Enum):
        color0: Qt = ...
        color1: Qt = ...
        black: Qt = ...
        white: Qt = ...
        darkGray: Qt = ...
        gray: Qt = ...
        lightGray: Qt = ...
        red: Qt = ...
        green: Qt = ...
        blue: Qt = ...
        cyan: Qt = ...
        magenta: Qt = ...
        yellow: Qt = ...
        darkRed: Qt = ...
        darkGreen: Qt = ...
        darkBlue: Qt = ...
        darkCyan: Qt = ...
        darkMagenta: Qt = ...
        darkYellow: Qt = ...
        transparent: Qt = ...

    def ws(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#ws

        **[since 5.14] QTextStream &Qt::ws(QTextStream & stream )**

        Calls **skipWhiteSpace** () on **stream** and returns **stream**.

        This function was introduced in Qt 5.14.

        **See also** **QTextStream manipulators** .
        """
        ...

    def bom(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#bom

        **[since 5.14] QTextStream &Qt::bom(QTextStream & stream )**

        Toggles insertion of the Byte Order Mark on **stream** when
        **QTextStream**  is used with a UTF encoding.

        This function was introduced in Qt 5.14.

        **See also** **QTextStream::setGenerateByteOrderMark** () and
        **QTextStream manipulators** .
        """
        ...

    def reset(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#reset

        **[since 5.14] QTextStream &Qt::reset(QTextStream & stream )**

        Calls **QTextStream::reset** () on **stream** and returns **stream**.

        This function was introduced in Qt 5.14.

        **See also** **flush** () and **QTextStream manipulators** .
        """
        ...

    def flush(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#flush

        **[since 5.14] QTextStream &Qt::flush(QTextStream & stream )**

        Calls **QTextStream::flush** () on **stream** and returns **stream**.

        This function was introduced in Qt 5.14.

        **See also** **endl** (), **reset** (), and **QTextStream manipulators**
        .
        """
        ...

    def endl(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#endl

        **[since 5.14] QTextStream &Qt::endl(QTextStream & stream )**

        Writes '\\n' to the **stream** and flushes the stream.

        Equivalent to

        stream << '\\n' << Qt::flush;

        Note: On Windows, all '\\n' characters are written as '\\r\\n' if
        **QTextStream** 's device or string is opened using the QIODevice::Text
        flag.

        This function was introduced in Qt 5.14.

        **See also** **flush** (), **reset** (), and **QTextStream
        manipulators** .
        """
        ...

    def center(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#center

        **[since 5.14] QTextStream &Qt::center(QTextStream & stream )**

        Calls **QTextStream::setFieldAlignment** (**QTextStream::AlignCenter** )
        on **stream** and returns **stream**.

        This function was introduced in Qt 5.14.

        **See also** **left** (), **right** (), and **QTextStream manipulators**
        .
        """
        ...

    def right(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#right

        **[since 5.14] QTextStream &Qt::right(QTextStream & stream )**

        Calls **QTextStream::setFieldAlignment** (**QTextStream::AlignRight** )
        on **stream** and returns **stream**.

        This function was introduced in Qt 5.14.

        **See also** **left** (), **center** (), and **QTextStream
        manipulators** .
        """
        ...

    def left(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#left

        **[since 5.14] QTextStream &Qt::left(QTextStream & stream )**

        Calls **QTextStream::setFieldAlignment** (**QTextStream::AlignLeft** )
        on **stream** and returns **stream**.

        This function was introduced in Qt 5.14.

        **See also** **right** (), **center** (), and **QTextStream
        manipulators** .
        """
        ...

    def scientific(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#scientific

        **[since 5.14] QTextStream &Qt::scientific(QTextStream & stream )**

        Calls **QTextStream::setRealNumberNotation**
        (**QTextStream::ScientificNotation** ) on **stream** and returns
        **stream**.

        This function was introduced in Qt 5.14.

        **See also** **fixed** () and **QTextStream manipulators** .
        """
        ...

    def fixed(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#fixed

        **[since 5.14] QTextStream &Qt::fixed(QTextStream & stream )**

        Calls **QTextStream::setRealNumberNotation**
        (**QTextStream::FixedNotation** ) on **stream** and returns **stream**.

        This function was introduced in Qt 5.14.

        **See also** **scientific** () and **QTextStream manipulators** .
        """
        ...

    def lowercasedigits(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#lowercasedigits

        **[since 5.14] QTextStream &Qt::lowercasedigits(QTextStream & stream )**

        Calls **QTextStream::setNumberFlags** (**QTextStream::numberFlags** () &
        ~**QTextStream::UppercaseDigits** ) on **stream** and returns
        **stream**.

        This function was introduced in Qt 5.14.

        **See also** **uppercasedigits** (), **lowercasebase** (), and
        **QTextStream manipulators** .
        """
        ...

    def lowercasebase(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#lowercasebase

        **[since 5.14] QTextStream &Qt::lowercasebase(QTextStream & stream )**

        Calls **QTextStream::setNumberFlags** (**QTextStream::numberFlags** () &
        ~**QTextStream::UppercaseBase** ) on **stream** and returns **stream**.

        This function was introduced in Qt 5.14.

        **See also** **uppercasebase** (), **lowercasedigits** (), and
        **QTextStream manipulators** .
        """
        ...

    def uppercasedigits(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#uppercasedigits

        **[since 5.14] QTextStream &Qt::uppercasedigits(QTextStream & stream )**

        Calls **QTextStream::setNumberFlags** (**QTextStream::numberFlags** () |
        **QTextStream::UppercaseDigits** ) on **stream** and returns **stream**.

        This function was introduced in Qt 5.14.

        **See also** **lowercasedigits** (), **uppercasebase** (), and
        **QTextStream manipulators** .
        """
        ...

    def uppercasebase(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#uppercasebase

        **[since 5.14] QTextStream &Qt::uppercasebase(QTextStream & stream )**

        Calls **QTextStream::setNumberFlags** (**QTextStream::numberFlags** () |
        **QTextStream::UppercaseBase** ) on **stream** and returns **stream**.

        This function was introduced in Qt 5.14.

        **See also** **lowercasebase** (), **uppercasedigits** (), and
        **QTextStream manipulators** .
        """
        ...

    def noforcepoint(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#noforcepoint

        **[since 5.14] QTextStream &Qt::noforcepoint(QTextStream & stream )**

        Calls **QTextStream::setNumberFlags** (**QTextStream::numberFlags** () &
        ~**QTextStream::ForcePoint** ) on **stream** and returns **stream**.

        This function was introduced in Qt 5.14.

        **See also** **forcepoint** (), **noforcesign** (), **noshowbase** (),
        and **QTextStream manipulators** .
        """
        ...

    def noforcesign(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#noforcesign

        **[since 5.14] QTextStream &Qt::noforcesign(QTextStream & stream )**

        Calls **QTextStream::setNumberFlags** (**QTextStream::numberFlags** () &
        ~**QTextStream::ForceSign** ) on **stream** and returns **stream**.

        This function was introduced in Qt 5.14.

        **See also** **forcesign** (), **noforcepoint** (), **noshowbase** (),
        and **QTextStream manipulators** .
        """
        ...

    def noshowbase(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#noshowbase

        **[since 5.14] QTextStream &Qt::noshowbase(QTextStream & stream )**

        Calls **QTextStream::setNumberFlags** (**QTextStream::numberFlags** () &
        ~**QTextStream::ShowBase** ) on **stream** and returns **stream**.

        This function was introduced in Qt 5.14.

        **See also** **showbase** (), **noforcesign** (), **noforcepoint** (),
        and **QTextStream manipulators** .
        """
        ...

    def forcepoint(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#forcepoint

        **[since 5.14] QTextStream &Qt::forcepoint(QTextStream & stream )**

        Calls **QTextStream::setNumberFlags** (**QTextStream::numberFlags** () |
        **QTextStream::ForcePoint** ) on **stream** and returns **stream**.

        This function was introduced in Qt 5.14.

        **See also** **noforcepoint** (), **forcesign** (), **showbase** (), and
        **QTextStream manipulators** .
        """
        ...

    def forcesign(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#forcesign

        **[since 5.14] QTextStream &Qt::forcesign(QTextStream & stream )**

        Calls **QTextStream::setNumberFlags** (**QTextStream::numberFlags** () |
        **QTextStream::ForceSign** ) on **stream** and returns **stream**.

        This function was introduced in Qt 5.14.

        **See also** **noforcesign** (), **forcepoint** (), **showbase** (), and
        **QTextStream manipulators** .
        """
        ...

    def showbase(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#showbase

        **[since 5.14] QTextStream &Qt::showbase(QTextStream & stream )**

        Calls **QTextStream::setNumberFlags** (**QTextStream::numberFlags** () |
        **QTextStream::ShowBase** ) on **stream** and returns **stream**.

        This function was introduced in Qt 5.14.

        **See also** **noshowbase** (), **forcesign** (), **forcepoint** (), and
        **QTextStream manipulators** .
        """
        ...

    def hex(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#hex

        **[since 5.14] QTextStream &Qt::hex(QTextStream & stream )**

        Calls **QTextStream::setIntegerBase** (16) on **stream** and returns
        **stream**.

        **Note:** The hex modifier can only be used for writing to streams.

        This function was introduced in Qt 5.14.

        **See also** **bin** (), **oct** (), **dec** (), and **QTextStream
        manipulators** .
        """
        ...

    def dec(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#dec

        **[since 5.14] QTextStream &Qt::dec(QTextStream & stream )**

        Calls **QTextStream::setIntegerBase** (10) on **stream** and returns
        **stream**.

        This function was introduced in Qt 5.14.

        **See also** **bin** (), **oct** (), **hex** (), and **QTextStream
        manipulators** .
        """
        ...

    def oct(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#oct

        **[since 5.14] QTextStream &Qt::oct(QTextStream & stream )**

        Calls **QTextStream::setIntegerBase** (8) on **stream** and returns
        **stream**.

        This function was introduced in Qt 5.14.

        **See also** **bin** (), **dec** (), **hex** (), and **QTextStream
        manipulators** .
        """
        ...

    def bin(self, s: "QTextStream") -> "QTextStream":
        """
        https://doc.qt.io/qt-6/qt.html#bin

        **[since 5.14] QTextStream &Qt::bin(QTextStream & stream )**

        Calls **QTextStream::setIntegerBase** (2) on **stream** and returns
        **stream**.

        This function was introduced in Qt 5.14.

        **See also** **oct** (), **dec** (), **hex** (), and **QTextStream
        manipulators** .
        """
        ...
