"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QGraphicsSceneMoveEvent(QGraphicsSceneEvent):
    """
    https://doc.qt.io/qt-6/qgraphicsscenemoveevent.html

    **Detailed Description**

    A **QGraphicsWidget**  sends itself a QGraphicsSceneMoveEvent immediately
    when its local position changes. The delivery is implemented as part of
    **QGraphicsItem::itemChange** ().

    It's similar to **QMoveEvent** , but its positions, **oldPos** () and
    **newPos** (), use **QPointF**  instead of **QPoint** .

    **See also** **QGraphicsItem::setPos** (),
    **QGraphicsItem::ItemPositionChange** , and
    **QGraphicsItem::ItemPositionHasChanged** .
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicsscenemoveevent.html#QGraphicsSceneMoveEv
        ent-1

        **QGraphicsSceneMoveEvent::QGraphicsSceneMoveEvent()**

        Constructs a QGraphicsSceneMoveEvent.
        """
        ...

    def newPos(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qgraphicsscenemoveevent.html#newPos

        **QPointF QGraphicsSceneMoveEvent::newPos() const**

        Returns the new position (i.e., the current position).

        **See also** **oldPos** () and **QGraphicsItem::setPos** ().
        """
        ...

    def oldPos(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qgraphicsscenemoveevent.html#oldPos

        **QPointF QGraphicsSceneMoveEvent::oldPos() const**

        Returns the old position (i.e., the position immediately before the
        widget was moved).

        **See also** **newPos** () and **QGraphicsItem::setPos** ().
        """
        ...
