"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtSensors import *


class QLightFilter(QSensorFilter):
    """
    https://doc.qt.io/qt-6/qlightfilter.html

    **Detailed Description**

    The only difference is that the **filter** () method features a pointer to
    **QLightReading**  instead of **QSensorReading** .
    """

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QLightFilter") -> None:
        ...

    def filter(self, reading: QLightReading) -> bool:
        """
        https://doc.qt.io/qt-6/qlightfilter.html#filter

        **[pure virtual] bool QLightFilter::filter(QLightReading * reading )**

        Called when **reading** changes. Returns false to prevent the reading
        from propagating.

        **See also** **QSensorFilter::filter** ().
        """
        ...
