"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6.QtQuick import *


class QSGBasicGeometryNode(QSGNode):
    """
    https://doc.qt.io/qt-6/qsgbasicgeometrynode.html

    **Detailed Description**

    The QSGBasicGeometryNode class should not be used by itself. It is only
    encapsulates shared functionality between the **QSGGeometryNode**  and
    **QSGClipNode**  classes.

    **Note:** All classes with QSG prefix should be used solely on the scene
    graph's rendering thread. See **Scene Graph and Rendering**  for more
    information.
    """

    def geometry(self) -> QSGGeometry:
        """
        https://doc.qt.io/qt-6/qsgbasicgeometrynode.html#geometry

        **const QSGGeometry *QSGBasicGeometryNode::geometry() const**

        Returns this node's geometry.

        The geometry is null by default.

        **See also** **setGeometry** ().
        """
        ...

    def setGeometry(self, geometry: QSGGeometry) -> None:
        """
        https://doc.qt.io/qt-6/qsgbasicgeometrynode.html#setGeometry

        **void QSGBasicGeometryNode::setGeometry(QSGGeometry * geometry )**

        Sets the geometry of this node to **geometry**.

        If the node has the flag **QSGNode::OwnsGeometry**  set, it will also
        delete the geometry object it is pointing to. This flag is not set by
        default.

        If the geometry is changed without calling setGeometry() again, the user
        must also mark the geometry as dirty using **QSGNode::markDirty** ().

        **See also** **geometry** () and **markDirty** ().
        """
        ...
