"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import PyQt6.sip
from PyQt6 import QtWidgets
from PyQt6 import QtCore


class QHelpContentWidget(QtWidgets.QTreeView):
    """
    https://doc.qt.io/qt-6/qhelpcontentwidget.html

    **Detailed Description**
    """

    def indexOf(self, link: QtCore.QUrl) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qhelpcontentwidget.html#indexOf

        **QModelIndex QHelpContentWidget::indexOf(const QUrl & link )**

        Returns the index of the content item with the **link**. An invalid
        index is returned if no such an item exists.
        """
        ...

    @property
    def linkActivated(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qhelpcontentwidget.html#linkActivated

        **[signal] void QHelpContentWidget::linkActivated(const QUrl & link )**

        This signal is emitted when a content item is activated and its
        associated **link** should be shown.
        """
        ...
