"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QMetaClassInfo(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qmetaclassinfo.html

    **Detailed Description**

    Class information items are simple **name** \\-- **value** pairs that are
    specified using **Q_CLASSINFO** () in the source code. The information can
    be retrieved using **name** () and **value** (). For example:

    class MyClass
        {
            Q_OBJECT
            Q_CLASSINFO("author", "Sabrina
    Schweinsteiger")
            Q_CLASSINFO("url",
    "http://doc.moosesoft.co.uk/1.0/")

        public:
            ...
        };

    This mechanism is free for you to use in your Qt applications. Qt doesn't
    use it for any of its classes.

    **See also** **QMetaObject** .
    """

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QMetaClassInfo") -> None:
        ...

    def value(self) -> str:
        """
        https://doc.qt.io/qt-6/qmetaclassinfo.html#value

        **const char *QMetaClassInfo::value() const**

        Returns the value of this item.

        **See also** **name** ().
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qmetaclassinfo.html#name

        **const char *QMetaClassInfo::name() const**

        Returns the name of this item.

        **See also** **value** ().
        """
        ...
