"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtGui import *


class QMatrix3x4(PyQt6.sip.simplewrapper):
    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, other: "QMatrix3x4") -> None:
        ...

    @typing.overload
    def __init__(self, values: typing.Sequence[float]) -> None:
        ...

    def transposed(self) -> QMatrix4x3:
        ...

    def fill(self, value: float) -> None:
        ...

    def setToIdentity(self) -> None:
        ...

    def isIdentity(self) -> bool:
        ...

    def __setitem__(self, a0: typing.Any, a1: float) -> None:
        ...

    def __getitem__(self, a0: typing.Any) -> typing.Any:
        ...

    def copyDataTo(self) -> typing.List[float]:
        ...

    def data(self) -> typing.List[float]:
        ...

    def __repr__(self) -> str:
        ...
