"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore


class QIconDragEvent(QtCore.QEvent):
    """
    https://doc.qt.io/qt-6/qicondragevent.html

    **Detailed Description**

    Icon drag events are sent to widgets when the main icon of a window has been
    dragged away. On macOS, this happens when the proxy icon of a window is
    dragged off the title bar.

    It is normal to begin using drag and drop in response to this event.

    **See also** **Drag and Drop** , **QMimeData** , and **QDrag** .
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qicondragevent.html#QIconDragEvent-2

        **QIconDragEvent::QIconDragEvent()**

        Constructs an icon drag event object with the accept flag set to false.

        **See also** **accept** ().
        """
        ...
