"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtHelp import *


class QHelpEngine(QHelpEngineCore):
    """
    https://doc.qt.io/qt-6/qhelpengine.html

    **Detailed Description**
    """

    def __init__(
        self, collectionFile: str, parent: typing.Optional[QtCore.QObject] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qhelpengine.html#QHelpEngine

        **QHelpEngine::QHelpEngine(const QString & collectionFile , QObject *
        parent = nullptr)**

        Constructs a new help engine with the given **parent**. The help engine
        uses the information stored in the **collectionFile** for providing
        help. If the collection file does not already exist, it will be created.
        """
        ...

    def searchEngine(self) -> "QHelpSearchEngine":
        """
        https://doc.qt.io/qt-6/qhelpengine.html#searchEngine

        **QHelpSearchEngine *QHelpEngine::searchEngine()**

        Returns the default search engine.
        """
        ...

    def indexWidget(self) -> "QHelpIndexWidget":
        """
        https://doc.qt.io/qt-6/qhelpengine.html#indexWidget

        **QHelpIndexWidget *QHelpEngine::indexWidget()**

        Returns the index widget.
        """
        ...

    def contentWidget(self) -> QHelpContentWidget:
        """
        https://doc.qt.io/qt-6/qhelpengine.html#contentWidget

        **QHelpContentWidget *QHelpEngine::contentWidget()**

        Returns the content widget.
        """
        ...

    def indexModel(self) -> "QHelpIndexModel":
        """
        https://doc.qt.io/qt-6/qhelpengine.html#indexModel

        **QHelpIndexModel *QHelpEngine::indexModel() const**

        Returns the index model.
        """
        ...

    def contentModel(self) -> QHelpContentModel:
        """
        https://doc.qt.io/qt-6/qhelpengine.html#contentModel

        **QHelpContentModel *QHelpEngine::contentModel() const**

        Returns the content model.
        """
        ...
