"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QStyleOptionProgressBar(QStyleOption):
    """
    https://doc.qt.io/qt-6/qstyleoptionprogressbar.html

    **Detailed Description**

    An instance of the QStyleOptionProgressBar class has type SO_ProgressBar and
    version 2.

    The type is used internally by **QStyleOption** , its subclasses, and
    **qstyleoption_cast** () to determine the type of style option. In general
    you do not need to worry about this unless you want to create your own
    **QStyleOption**  subclass and your own styles. The version is used by
    **QStyleOption**  subclasses to implement extensions without breaking
    compatibility. If you use **qstyleoption_cast** (), you normally do not need
    to check it.

    For performance reasons, there are few member functions and the access to
    the member variables is direct (i.e., using the `.` or `->` operator). This
    makes the structures straightforward to use and emphasizes that these are
    simply parameters used by the style functions.

    For an example demonstrating how style options can be used, see the
    **Styles**  example.

    **See also** **QStyleOption** .
    """

    class StyleOptionVersion(enum.Enum):
        Version: QStyleOptionProgressBar = ...

    class StyleOptionType(enum.Enum):
        Type: QStyleOptionProgressBar = ...

    bottomToTop: bool = ...
    invertedAppearance: bool = ...
    maximum: int = ...
    minimum: int = ...
    progress: int = ...
    text: str = ...
    textAlignment: QtCore = ...
    textVisible: bool = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qstyleoptionprogressbar.html#QStyleOptionProgress
        Bar

        **QStyleOptionProgressBar::QStyleOptionProgressBar()**

        Constructs a QStyleOptionProgressBar, initializing the members variables
        to their default values.
        """
        ...

    @typing.overload
    def __init__(self, other: "QStyleOptionProgressBar") -> None:
        """
        https://doc.qt.io/qt-6/qstyleoptionprogressbar.html#QStyleOptionProgress
        Bar-1

        **QStyleOptionProgressBar::QStyleOptionProgressBar(const
        QStyleOptionProgressBar & other )**

        Constructs a copy of the **other** style option.
        """
        ...
