"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip


class QXmlStreamNamespaceDeclaration(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qxmlstreamnamespacedeclaration.html

    **Detailed Description**

    An namespace declaration consists of a **prefix** () and a **namespaceUri**
    ().
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamnamespacedeclaration.html#QXmlStreamNam
        espaceDeclaration

        **QXmlStreamNamespaceDeclaration::QXmlStreamNamespaceDeclaration()**

        Creates an empty namespace declaration.
        """
        ...

    @typing.overload
    def __init__(self, prefix: str, namespaceUri: str) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamnamespacedeclaration.html#QXmlStreamNam
        espaceDeclaration-1

        **QXmlStreamNamespaceDeclaration::QXmlStreamNamespaceDeclaration(const
        QString & prefix , const QString & namespaceUri )**

        Creates a namespace declaration with **prefix** and **namespaceUri**.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QXmlStreamNamespaceDeclaration") -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamnamespacedeclaration.html#QXmlStreamNam
        espaceDeclaration

        **QXmlStreamNamespaceDeclaration::QXmlStreamNamespaceDeclaration()**

        Creates an empty namespace declaration.
        """
        ...

    def namespaceUri(self) -> str:
        """
        https://doc.qt.io/qt-6/qxmlstreamnamespacedeclaration.html#namespaceUri

        **QStringView QXmlStreamNamespaceDeclaration::namespaceUri() const**

        Returns the namespaceUri.
        """
        ...

    def prefix(self) -> str:
        """
        https://doc.qt.io/qt-6/qxmlstreamnamespacedeclaration.html#prefix

        **QStringView QXmlStreamNamespaceDeclaration::prefix() const**

        Returns the prefix.
        """
        ...
