"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QExposeEvent(QtCore.QEvent):
    """
    https://doc.qt.io/qt-6/qexposeevent.html

    **Detailed Description**

    Expose events are sent to windows when they move between the un-exposed and
    exposed states.

    An exposed window is potentially visible to the user. If the window is moved
    off screen, is made totally obscured by another window, is minimized, or
    similar, an expose event is sent to the window, and isExposed() might change
    to false.

    Expose events should not be used to paint. Handle **QPaintEvent**  instead.

    The event handler **QWindow::exposeEvent** () receives expose events.
    """

    def __init__(self, rgn: "QRegion") -> None:
        """
        https://doc.qt.io/qt-6/qexposeevent.html#QExposeEvent-2

        **QExposeEvent::QExposeEvent(const QRegion & exposeRegion )**

        Constructs an expose event for the given **exposeRegion** which must be
        in local coordinates.
        """
        ...

    def clone(self) -> "QExposeEvent":
        ...
