"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtQml import *


class QQmlPropertyValueSource(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qqmlpropertyvaluesource.html

    **Detailed Description**

    See **Property Value Sources**  for information on writing custom property
    value sources.
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qqmlpropertyvaluesource.html#QQmlPropertyValueSou
        rce

        **QQmlPropertyValueSource::QQmlPropertyValueSource()**

        Constructs a QQmlPropertyValueSource.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QQmlPropertyValueSource") -> None:
        """
        https://doc.qt.io/qt-6/qqmlpropertyvaluesource.html#QQmlPropertyValueSou
        rce

        **QQmlPropertyValueSource::QQmlPropertyValueSource()**

        Constructs a QQmlPropertyValueSource.
        """
        ...

    def setTarget(self, a0: QQmlProperty) -> None:
        """
        https://doc.qt.io/qt-6/qqmlpropertyvaluesource.html#setTarget

        **[pure virtual] void QQmlPropertyValueSource::setTarget(const
        QQmlProperty & property )**

        Set the target **property** for the value source. This method will be
        called by the QML engine when assigning a value source.
        """
        ...
