"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QCborError(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qcborerror.html

    **Detailed Description**

    **See also** **QCborStreamReader** , **QCborValue** , and
    **QCborParserError** .
    """

    class Code(enum.Enum):
        UnknownError: QCborError = ...
        AdvancePastEnd: QCborError = ...
        InputOutputError: QCborError = ...
        GarbageAtEnd: QCborError = ...
        EndOfFile: QCborError = ...
        UnexpectedBreak: QCborError = ...
        UnknownType: QCborError = ...
        IllegalType: QCborError = ...
        IllegalNumber: QCborError = ...
        IllegalSimpleType: QCborError = ...
        InvalidUtf8String: QCborError = ...
        DataTooLarge: QCborError = ...
        NestingTooDeep: QCborError = ...
        UnsupportedType: QCborError = ...
        NoError: QCborError = ...

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(self, a0: "QCborError") -> None:
        ...

    def toString(self) -> str:
        """
        https://doc.qt.io/qt-6/qcborerror.html#toString

        **QString QCborError::toString() const**

        Returns a text string that matches the error code in this **QCborError**
        object.

        Note: the string is not translated. Applications whose interface allow
        users to parse CBOR streams need to provide their own, translated
        strings.

        **See also** **QCborError::Code** .
        """
        ...

    def code(self) -> "QCborError.Code":
        ...
